--
-- PostgreSQL database dump
--

INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'Hepatitis B', 'Hep B', false, '00:01', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'diptheria-tetanus-acellular pertussis infant/child formulation', 'DTPa', false, '2 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'diptheria-tetanus-acellular pertussis adult/adolescent formulation', 'dTpa', false, '12 years', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'Haemophilius influenzae type b', 'PRP-OMP', false, '2 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'Haemophilius influenzae type b(PRP-T)', 'PRP-T', false, '2 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'Haemophilius influenzae type b(HbOC)', 'HbOC', false, '2 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'inactivated poliomyelitis vaccine', 'IPV', false, '2 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (2, 'varicella-zoster vaccine', 'VZV', true, '1 year', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, '7-valent pneumococcal conjugate vaccine', '7vPCV', false, '2 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, '23-valent pneumococcal polysaccharide vaccine', '23vPPV', false, '1 year 6 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'meningococcal C conjugate vaccine', 'menCCV', false, '2 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (1, 'adult diptheria-tetanus', 'dT', false, '8 years', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (3, 'oral poliomyelitis vaccine', 'OPV', true, '2 mons', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (2, 'measles-mumps-rubella vaccine', 'MMR', true, '1 year', '5555 years'::interval, NULL);
INSERT INTO clin.vaccine ( id_route, trade_name, short_name, is_live, min_age, max_age, "comment") VALUES (2, 'influenza vaccine', 'influenza', false, '6 mons', '5555 years'::interval, NULL);
