-- GNUmed database string translations exported 2015-10-25 17:23
-- - contains translations for each of [nl_NL, de, ru, ru_RU, es_ES, fr_CA, fr, pap_AN, fr_FR, de_DE]
-- - user database language is set to [de_DE]

-- Please email this file to <gnumed-devel@gnu.org>.
-- ----------------------------------------------------------------------------------------------
\set ON_ERROR_STOP

--set default_transaction_read_only to off;
--set client_encoding to 'utf-8';

-- ----------------------------------------------------------------------------------------------
select i18n.upd_tx(E'de', E'active', E'aktiv');
select i18n.upd_tx(E'de', E'Administrative', E'Administrativ');
select i18n.upd_tx(E'de', E'adopted daughter', E'Adoptivtochter');
select i18n.upd_tx(E'de', E'adopted son', E'Adoptivsohn');
select i18n.upd_tx(E'de', E'adoptive father', E'Adoptivvater');
select i18n.upd_tx(E'de', E'adoptive mother', E'Adoptivmutter');
select i18n.upd_tx(E'de', E'AOE', E'BE');
select i18n.upd_tx(E'de', E'aunt', E'Tante');
select i18n.upd_tx(E'de', E'aunt (maternal)', E'Tante (mütterlicherseits)');
select i18n.upd_tx(E'de', E'aunt (paternal)', E'Tante (väterlicherseits)');
select i18n.upd_tx(E'de', E'bill receiver', E'Rechnungsempfänger');
select i18n.upd_tx(E'de', E'billing', E'Rechnungsanschrift');
select i18n.upd_tx(E'de', E'Blood, Blood forming organs, Immune mechanism', E'Blut, blutbildende Organe, Immunsystem');
select i18n.upd_tx(E'de', E'branch', E'Zweigstelle');
select i18n.upd_tx(E'de', E'brother', E'Bruder');
select i18n.upd_tx(E'de', E'Cardivascular', E'Kreislauf');
select i18n.upd_tx(E'de', E'cause of death', E'Todesursache');
select i18n.upd_tx(E'de', E'choleric', E'cholerisch');
select i18n.upd_tx(E'de', E'clinically not relevant', E'medizinisch nicht relevant');
select i18n.upd_tx(E'de', E'clinically relevant', E'medizinisch relevant');
select i18n.upd_tx(E'de', E'closed', E'abgeschlossen');
select i18n.upd_tx(E'de', E'confidential', E'vertraulich');
select i18n.upd_tx(E'de', E'cousin', E'Cousin(e)');
select i18n.upd_tx(E'de', E'cousin (maternal)', E'Cousin(e) (mütterlicherseits)');
select i18n.upd_tx(E'de', E'cousin (paternal)', E'Cousin(e) (väterlicherseits)');
select i18n.upd_tx(E'de', E'daughter', E'Tochter');
select i18n.upd_tx(E'de', E'defacto husband', E'de facto Ehemann');
select i18n.upd_tx(E'de', E'defacto wife', E'de facto Ehefrau');
select i18n.upd_tx(E'de', E'Deletion of', E'Löschung:');
select i18n.upd_tx(E'de', E'Diagnosis, disease', E'Diagnosen, Krankheiten');
select i18n.upd_tx(E'de', E'Diagnostic screening, prevention', E'Diagnostik, Screening, Prävention');
select i18n.upd_tx(E'de', E'Digestive', E'Darm: Verdauungssystem');
select i18n.upd_tx(E'de', E'Ear ("Hearing")', E'Hören: Ohr');
select i18n.upd_tx(E'de', E'Encounter', E'Kontakt');
select i18n.upd_tx(E'de', E'Endocrine/Metabolic and Nutritional ("Thyroid")', E'Thyroidea: Endokrin, metabolisch, Ernährung');
select i18n.upd_tx(E'de', E'Extra care !', E'Vorsicht');
select i18n.upd_tx(E'de', E'Eye ("Focal")', E'Fokus: Auge');
select i18n.upd_tx(E'de', E'father', E'Vater');
select i18n.upd_tx(E'de', E'Female genital ("X-chromosome")', E'X-Chromosom: Weibliches Genitale, Brust');
select i18n.upd_tx(E'de', E'form header', E'Formularkopf');
select i18n.upd_tx(E'de', E'General and Unspecified', E'Allgmein und unspezifisch');
select i18n.upd_tx(E'de', E'General Family History', E'Familienanamnese');
select i18n.upd_tx(E'de', E'General History (maternal)', E'Familienananmese (mütterlicherseits)');
select i18n.upd_tx(E'de', E'General History (paternal)', E'Familienananmese (väterlicherseits)');
select i18n.upd_tx(E'de', E'generic praxis', E'generische Praxis');
select i18n.upd_tx(E'de', E'generic praxis branch', E'generische Zweigstelle');
select i18n.upd_tx(E'de', E'Government Agency', E'Regierungsabteilung');
select i18n.upd_tx(E'de', E'granddaughter', E'Enkelin');
select i18n.upd_tx(E'de', E'grandfather', E'Großvater');
select i18n.upd_tx(E'de', E'grandfather (maternal)', E'Großvater (mütterlicherseits)');
select i18n.upd_tx(E'de', E'grandfather (paternal)', E'Großvater (väterlicherseits)');
select i18n.upd_tx(E'de', E'grandmother', E'Großmutter');
select i18n.upd_tx(E'de', E'grandmother (maternal)', E'Großmutter (mütterlicherseits)');
select i18n.upd_tx(E'de', E'grandmother (paternal)', E'Großmutter (väterlicherseits)');
select i18n.upd_tx(E'de', E'grandson', E'Enkel');
select i18n.upd_tx(E'de', E'great grandfather (maternal)', E'Urgroßvater (mütterlicherseits)');
select i18n.upd_tx(E'de', E'great grandfather (paternal)', E'Urgroßvater (väterlicherseits)');
select i18n.upd_tx(E'de', E'great grandmother (maternal)', E'Urgroßmutter (mütterlicherseits)');
select i18n.upd_tx(E'de', E'great grandmother (paternal)', E'Urgroßmutter (väterlicherseits)');
select i18n.upd_tx(E'de', E'Health Issue', E'Grunderkrankung');
select i18n.upd_tx(E'de', E'Hospital', E'Krankenhaus');
select i18n.upd_tx(E'de', E'husband', E'Ehemann');
select i18n.upd_tx(E'de', E'inactive', E'inaktiv');
select i18n.upd_tx(E'de', E'influenza (H3N2)', E'Influenza (H3N2)');
select i18n.upd_tx(E'de', E'influenza (seasonal)', E'Influenza (sais.)');
select i18n.upd_tx(E'de', E'invoice', E'Rechnungsbeleg');
select i18n.upd_tx(E'de', E'Laboratory', E'Labor');
select i18n.upd_tx(E'de', E'Laterality', E'Seite');
select i18n.upd_tx(E'de', E'major depression', E'Depression');
select i18n.upd_tx(E'de', E'Male genital ("Y-chromosome")', E'Y-Chromosom: Männliches Genitale, Brust');
select i18n.upd_tx(E'de', E'Medical Practice', E'Praxis');
select i18n.upd_tx(E'de', E'Medication history', E'Medikamentenanamnese');
select i18n.upd_tx(E'de', E'meningococcus A', E'Meningokokken Typ A');
select i18n.upd_tx(E'de', E'meningococcus W', E'Meningokokken Typ W');
select i18n.upd_tx(E'de', E'meningococcus Y', E'Meningokokken Typ Y');
select i18n.upd_tx(E'de', E'Ministry of Public Health', E'Gesundheitsministerium');
select i18n.upd_tx(E'de', E'minor depression', E'depressoid');
select i18n.upd_tx(E'de', E'mobility impairment', E'Gehbehinderung');
select i18n.upd_tx(E'de', E'mother', E'Mutter');
select i18n.upd_tx(E'de', E'Musculoskeletal ("Locomotion")', E'Laufen: Bewegungsapparat');
select i18n.upd_tx(E'de', E'nephew', E'Neffe');
select i18n.upd_tx(E'de', E'Neurological', E'Neurologisch');
select i18n.upd_tx(E'de', E'niece', E'Nichte');
select i18n.upd_tx(E'de', E'noted at age', E'aufgefallen im Alter von');
select i18n.upd_tx(E'de', E'Occupational Therapy Practice', E'Ergotherapiepraxis');
select i18n.upd_tx(E'de', E'of', E'von');
select i18n.upd_tx(E'de', E'often late', E'oft zu spät');
select i18n.upd_tx(E'de', E'ongoing', E'andauernd');
select i18n.upd_tx(E'de', E'open', E'andauernd');
select i18n.upd_tx(E'de', E'Other (referral etc)', E'Anderes');
select i18n.upd_tx(E'de', E'other form', E'sonstiges Formular');
select i18n.upd_tx(E'de', E'phone w/ caregiver', E'Telefonat mit Pflegeperson');
select i18n.upd_tx(E'de', E'phone w/ patient', E'Telefonat mit Patient');
select i18n.upd_tx(E'de', E'phone w/ provider', E'Telefonat mit Arzt/Behandler');
select i18n.upd_tx(E'de', E'Physical Therapy Practice', E'Physiotherapiepraxis');
select i18n.upd_tx(E'de', E'Practice', E'Praxis');
select i18n.upd_tx(E'de', E'Pregnancy, Childbearing, Family planning ("Women")', E'Weiblich: Schwangerschaft, Geburt, Familienplanung');
select i18n.upd_tx(E'de', E'prescription', E'Rezept');
select i18n.upd_tx(E'de', E'Privacy notice', E'Datenschutzhinweis');
select i18n.upd_tx(E'de', E'Procedure', E'Maßnahme');
select i18n.upd_tx(E'de', E'Psychological', E'Psychologisch');
select i18n.upd_tx(E'de', E'Respiratory', E'Respiratorisch: Atmungsorgane');
select i18n.upd_tx(E'de', E'RFE', E'BU');
select i18n.upd_tx(E'de', E'salmonella typhi (typhoid)', E'Salmonella typhi (Typhus)');
select i18n.upd_tx(E'de', E'Serbia', E'Serbien');
select i18n.upd_tx(E'de', E'sister', E'Schwester');
select i18n.upd_tx(E'de', E'Skin', E'Skin: Haut');
select i18n.upd_tx(E'de', E'smokes', E'raucht');
select i18n.upd_tx(E'de', E'Social problems', E'SoZiale Probleme');
select i18n.upd_tx(E'de', E'son', E'Sohn');
select i18n.upd_tx(E'de', E'step daughter', E'Stieftochter');
select i18n.upd_tx(E'de', E'step father', E'Stiefvater');
select i18n.upd_tx(E'de', E'step mother', E'Stiefmutter');
select i18n.upd_tx(E'de', E'step son', E'Stiefsohn');
select i18n.upd_tx(E'de', E'stepbrother', E'Stiefbruder');
select i18n.upd_tx(E'de', E'stepnephew', E'Stiefneffe');
select i18n.upd_tx(E'de', E'stepniece', E'Stiefnichte');
select i18n.upd_tx(E'de', E'stepsister', E'Stiefschwester');
select i18n.upd_tx(E'de', E'Summary', E'Zusammenfassung');
select i18n.upd_tx(E'de', E'Surgery', E'Praxis');
select i18n.upd_tx(E'de', E'Symptoms, complaints', E'Symptome, Beschwerden');
select i18n.upd_tx(E'de', E'Synopsis', E'Synopse');
select i18n.upd_tx(E'de', E'Test results', E'Testresultate');
select i18n.upd_tx(E'de', E'Treatment, procedures, medication', E'Behandlung, Prozeduren, Medikation');
select i18n.upd_tx(E'de', E'tuberculosis', E'Tuberkulose');
select i18n.upd_tx(E'de', E'uncle', E'Onkel');
select i18n.upd_tx(E'de', E'uncle (maternal)', E'Onkel (mütterlicherseits)');
select i18n.upd_tx(E'de', E'uncle (paternal)', E'Onkel (väterlicherseits)');
select i18n.upd_tx(E'de', E'until', E'bis');
select i18n.upd_tx(E'de', E'Urological', E'Urologisch');
select i18n.upd_tx(E'de', E'Ward', E'Station');
select i18n.upd_tx(E'de', E'wife', E'Ehefrau');
select i18n.upd_tx(E'de_DE', E'\'closed\'', E'\'geschlossen\'');
select i18n.upd_tx(E'de_DE', E' (closed)', E' (beendet)');
select i18n.upd_tx(E'de_DE', E'administrative', E'Verwaltung');
select i18n.upd_tx(E'de_DE', E'administrative encounter', E'Verwaltungsakt');
select i18n.upd_tx(E'de_DE', E'Albania', E'Albanien');
select i18n.upd_tx(E'de_DE', E'Algeria', E'Algerien');
select i18n.upd_tx(E'de_DE', E'allergene', E'Allergen');
select i18n.upd_tx(E'de_DE', E'allergy', E'Allergie');
select i18n.upd_tx(E'de_DE', E'Allergy state', E'Allergiestatus');
select i18n.upd_tx(E'de_DE', E'American Samoa', E'Amerikanisch-Samoa');
select i18n.upd_tx(E'de_DE', E'Antarctica', E'Antarktis');
select i18n.upd_tx(E'de_DE', E'Antigua and Barbuda', E'Antigua und Barbados');
select i18n.upd_tx(E'de_DE', E'Argentina', E'Argentinien');
select i18n.upd_tx(E'de_DE', E'Armenia', E'Armenien');
select i18n.upd_tx(E'de_DE', E'ATC code', E'ATC-Code');
select i18n.upd_tx(E'de_DE', E'Australia', E'Australien');
select i18n.upd_tx(E'de_DE', E'Austria', E'Österreich');
select i18n.upd_tx(E'de_DE', E'batch no', E'Charge');
select i18n.upd_tx(E'de_DE', E'Belgium', E'Belgien');
select i18n.upd_tx(E'de_DE', E'blood oxygen saturation', E'Sauerstoffsättigung (Blut)');
select i18n.upd_tx(E'de_DE', E'blood pressure', E'Blutdruck');
select i18n.upd_tx(E'de_DE', E'Bolivia', E'Bolivien');
select i18n.upd_tx(E'de_DE', E'Bosnia and Herzegovina', E'Bosnien und Herzegovina');
select i18n.upd_tx(E'de_DE', E'Brazil', E'Brasilien');
select i18n.upd_tx(E'de_DE', E'Bulgaria', E'Bulgarien');
select i18n.upd_tx(E'de_DE', E'Cambodia', E'Kambodscha');
select i18n.upd_tx(E'de_DE', E'Cameroon', E'Kamerun');
select i18n.upd_tx(E'de_DE', E'Canada', E'Kanada');
select i18n.upd_tx(E'de_DE', E'Central African Republic', E'Zentralafrikanische Republik');
select i18n.upd_tx(E'de_DE', E'Chad', E'Tschad');
select i18n.upd_tx(E'de_DE', E'chart review', E'Akteneinsicht');
select i18n.upd_tx(E'de_DE', E'child', E'Kind');
select i18n.upd_tx(E'de_DE', E'cholera', E'Cholera');
select i18n.upd_tx(E'de_DE', E'Christmas Island', E'Weihnachtsinseln');
select i18n.upd_tx(E'de_DE', E'clinical', E'medizinisch');
select i18n.upd_tx(E'de_DE', E'code', E'Code');
select i18n.upd_tx(E'de_DE', E'Colombia', E'Kolumbien');
select i18n.upd_tx(E'de_DE', E'Comment', E'Kommentar');
select i18n.upd_tx(E'de_DE', E'Comoros', E'Komoren');
select i18n.upd_tx(E'de_DE', E'Congo', E'Kongo');
select i18n.upd_tx(E'de_DE', E'Congo, The Democratic Republic', E'Demokratische Republik Kongo');
select i18n.upd_tx(E'de_DE', E'Cote D\'Ivoire', E'Elfenbeinküste');
select i18n.upd_tx(E'de_DE', E'Croatia', E'Kroatien');
select i18n.upd_tx(E'de_DE', E'Cuba', E'Kuba');
select i18n.upd_tx(E'de_DE', E'current medication list', E'Medikamentenliste');
select i18n.upd_tx(E'de_DE', E'Cyprus', E'Zypern');
select i18n.upd_tx(E'de_DE', E'Czech Republic', E'Tschechien');
select i18n.upd_tx(E'de_DE', E'Deletion of document', E'Dokument gelöscht');
select i18n.upd_tx(E'de_DE', E'Denmark', E'Dänemark');
select i18n.upd_tx(E'de_DE', E'diet', E'Ernährung');
select i18n.upd_tx(E'de_DE', E'diphtheria', E'Diphtherie');
select i18n.upd_tx(E'de_DE', E'discharge summary ENT', E'Entlassung HNO');
select i18n.upd_tx(E'de_DE', E'discharge summary internal', E'Entlassung Interne');
select i18n.upd_tx(E'de_DE', E'discharge summary neurological', E'Entlassung Neuro');
select i18n.upd_tx(E'de_DE', E'discharge summary neurosurgery', E'Entlassung Neurochirurgie');
select i18n.upd_tx(E'de_DE', E'discharge summary ophthalmology', E'Entlassung Augen');
select i18n.upd_tx(E'de_DE', E'discharge summary orthopaedic', E'Entlassung Ortho');
select i18n.upd_tx(E'de_DE', E'discharge summary other', E'Entlassung sonstige');
select i18n.upd_tx(E'de_DE', E'discharge summary psychiatric', E'Entlassung Psychiatrie');
select i18n.upd_tx(E'de_DE', E'discharge summary rehabilitation', E'Entlassung Reha');
select i18n.upd_tx(E'de_DE', E'discharge summary surgical', E'Entlassung Chirurgie');
select i18n.upd_tx(E'de_DE', E'discharge summary urology', E'Entlassung Uro');
select i18n.upd_tx(E'de_DE', E'divorced', E'geschieden');
select i18n.upd_tx(E'de_DE', E'doctor', E'Arzt');
select i18n.upd_tx(E'de_DE', E'document entry', E'Dokumenteneingang');
select i18n.upd_tx(E'de_DE', E'does have allergies', E'Allergien vorhanden');
select i18n.upd_tx(E'de_DE', E'Dominican Republic', E'Dominikanische Republik');
select i18n.upd_tx(E'de_DE', E'East Timor', E'Osttimor');
select i18n.upd_tx(E'de_DE', E'Ecuador', E'Ekuador');
select i18n.upd_tx(E'de_DE', E'Egypt', E'Ägypten');
select i18n.upd_tx(E'de_DE', E'email', E'e-mail');
select i18n.upd_tx(E'de_DE', E'emergency encounter', E'Notfall');
select i18n.upd_tx(E'de_DE', E'EMR printout', E'Karteiausdruck');
select i18n.upd_tx(E'de_DE', E'encounter', E'APK');
select i18n.upd_tx(E'de_DE', E'episode', E'Episode');
select i18n.upd_tx(E'de_DE', E'Ethiopia', E'Äthiopien');
select i18n.upd_tx(E'de_DE', E'external org', E'externe Organisation');
select i18n.upd_tx(E'de_DE', E'f', E'w');
select i18n.upd_tx(E'de_DE', E'family history', E'Familienanamnese');
select i18n.upd_tx(E'de_DE', E'Family Hx', E'Familienanamnese');
select i18n.upd_tx(E'de_DE', E'fax', E'Fax');
select i18n.upd_tx(E'de_DE', E'fax consultation', E'per Fax');
select i18n.upd_tx(E'de_DE', E'female', E'weiblich');
select i18n.upd_tx(E'de_DE', E'female only', E'nur Frauen');
select i18n.upd_tx(E'de_DE', E'final', E'endgültig');
select i18n.upd_tx(E'de_DE', E'Finland', E'Finnland');
select i18n.upd_tx(E'de_DE', E'France', E'Frankreich');
select i18n.upd_tx(E'de_DE', E'FYI', E'zur Kenntnisnahme');
select i18n.upd_tx(E'de_DE', E'generic', E'Generikum');
select i18n.upd_tx(E'de_DE', E'Georgia', E'Georgien');
select i18n.upd_tx(E'de_DE', E'Germany', E'Deutschland');
select i18n.upd_tx(E'de_DE', E'gnuplot script', E'Gnuplot-Script');
select i18n.upd_tx(E'de_DE', E'Greece', E'Griechenland');
select i18n.upd_tx(E'de_DE', E'Greenland', E'Grönland');
select i18n.upd_tx(E'de_DE', E'haemophilus influenzae b', E'Haemophilus Influenzae B');
select i18n.upd_tx(E'de_DE', E'halfsibling', E'Stiefgeschwister');
select i18n.upd_tx(E'de_DE', E'health issue', E'Grunderkrankung');
select i18n.upd_tx(E'de_DE', E'height', E'Größe');
select i18n.upd_tx(E'de_DE', E'hepatitis A', E'Hepatitis A');
select i18n.upd_tx(E'de_DE', E'hepatitis B', E'Hepatitis B');
select i18n.upd_tx(E'de_DE', E'hermaphrodite', E'Hermaphrodit');
select i18n.upd_tx(E'de_DE', E'hght', E'Gr.');
select i18n.upd_tx(E'de_DE', E'history of presenting complaint', E'Jetztanamnese');
select i18n.upd_tx(E'de_DE', E'holidays', E'Urlaub');
select i18n.upd_tx(E'de_DE', E'Holy See (Vatican City State)', E'Vatikanstadt');
select i18n.upd_tx(E'de_DE', E'home', E'daheim');
select i18n.upd_tx(E'de_DE', E'home visit', E'Hausbesuch');
select i18n.upd_tx(E'de_DE', E'homephone', E'Telefon zu Hause');
select i18n.upd_tx(E'de_DE', E'hospital stay', E'Krankenhausaufenthalt');
select i18n.upd_tx(E'de_DE', E'hospital visit', E'Krankenhausbesuch');
select i18n.upd_tx(E'de_DE', E'housing', E'Unterkunft');
select i18n.upd_tx(E'de_DE', E'Hungary', E'Ungarn');
select i18n.upd_tx(E'de_DE', E'Iceland', E'Island');
select i18n.upd_tx(E'de_DE', E'in surgery', E'in Praxis');
select i18n.upd_tx(E'de_DE', E'India', E'Indien');
select i18n.upd_tx(E'de_DE', E'indication', E'Indikation');
select i18n.upd_tx(E'de_DE', E'Indications', E'Indikationen');
select i18n.upd_tx(E'de_DE', E'Indonesia', E'Indonesion');
select i18n.upd_tx(E'de_DE', E'influenza', E'Influenza');
select i18n.upd_tx(E'de_DE', E'intramuscular', E'intramuskulär');
select i18n.upd_tx(E'de_DE', E'Iran, Islamic Republic Of', E'Islamische Republik Iran');
select i18n.upd_tx(E'de_DE', E'Iraq', E'Irak');
select i18n.upd_tx(E'de_DE', E'Ireland', E'Irland');
select i18n.upd_tx(E'de_DE', E'Italy', E'Italien');
select i18n.upd_tx(E'de_DE', E'jabber', E'Jabber');
select i18n.upd_tx(E'de_DE', E'Jamaica', E'Jamaika');
select i18n.upd_tx(E'de_DE', E'japanese B encephalitis', E'Japanische Enzephalitis B');
select i18n.upd_tx(E'de_DE', E'Jordan', E'Jordanien');
select i18n.upd_tx(E'de_DE', E'Kazakstan', E'Kasachstan');
select i18n.upd_tx(E'de_DE', E'Kenya', E'Kenia');
select i18n.upd_tx(E'de_DE', E'Korea, Democratic People\'s Republic', E'Nordkorea');
select i18n.upd_tx(E'de_DE', E'Korea, Republic Of', E'Südkorea');
select i18n.upd_tx(E'de_DE', E'Kyrgyzstan', E'Kirgisien');
select i18n.upd_tx(E'de_DE', E'lab', E'Labor');
select i18n.upd_tx(E'de_DE', E'lab technician', E'MTLA');
select i18n.upd_tx(E'de_DE', E'Lao People\'s Democratic Republic', E'Laos');
select i18n.upd_tx(E'de_DE', E'last confirmed', E'zuletzt überprüft');
select i18n.upd_tx(E'de_DE', E'Lebanon', E'Libanon');
select i18n.upd_tx(E'de_DE', E'legal guardian', E'Vormund');
select i18n.upd_tx(E'de_DE', E'Lithuania', E'Litauen');
select i18n.upd_tx(E'de_DE', E'lying in infants, else standing, see result notes', E'Säuglinge liegend, sonst stehend, siehe Kommentar');
select i18n.upd_tx(E'de_DE', E'male', E'männlich');
select i18n.upd_tx(E'de_DE', E'manager', E'Manager');
select i18n.upd_tx(E'de_DE', E'married', E'verheiratet');
select i18n.upd_tx(E'de_DE', E'Mauritania', E'Mauretanien');
select i18n.upd_tx(E'de_DE', E'measles', E'Masern');
select i18n.upd_tx(E'de_DE', E'Medical statement', E'Bescheinigung');
select i18n.upd_tx(E'de_DE', E'medical student', E'Medizinstudent');
select i18n.upd_tx(E'de_DE', E'memo', E'Memo');
select i18n.upd_tx(E'de_DE', E'meningococcus C', E'Meningokokken Typ C');
select i18n.upd_tx(E'de_DE', E'Mexico', E'Mexiko');
select i18n.upd_tx(E'de_DE', E'mobile', E'Funktelefon');
select i18n.upd_tx(E'de_DE', E'Mongolia', E'Mongolei');
select i18n.upd_tx(E'de_DE', E'Morocco', E'Marokko');
select i18n.upd_tx(E'de_DE', E'mumps', E'Mumps');
select i18n.upd_tx(E'de_DE', E'name', E'Name');
select i18n.upd_tx(E'de_DE', E'Netherlands', E'Niederlanden');
select i18n.upd_tx(E'de_DE', E'Netherlands Antilles', E'Niederländische Antillen');
select i18n.upd_tx(E'de_DE', E'New Zealand', E'Neuseeland');
select i18n.upd_tx(E'de_DE', E'no known allergies', E'keine bekannten Allergie');
select i18n.upd_tx(E'de_DE', E'Norway', E'Norwegen');
select i18n.upd_tx(E'de_DE', E'noted at age', E'aufgefallen im Alter von');
select i18n.upd_tx(E'de_DE', E'notes', E'Bemerkung');
select i18n.upd_tx(E'de_DE', E'nurse', E'Arzthelferin');
select i18n.upd_tx(E'de_DE', E'nursing home visit', E'Heimbesuch');
select i18n.upd_tx(E'de_DE', E'orally', E'oral');
select i18n.upd_tx(E'de_DE', E'other encounter', E'anderer Kontakt');
select i18n.upd_tx(E'de_DE', E'other letter', E'sonstiger Brief');
select i18n.upd_tx(E'de_DE', E'parent', E'Elternteil');
select i18n.upd_tx(E'de_DE', E'parents', E'Eltern');
select i18n.upd_tx(E'de_DE', E'partial', E'unvollständig');
select i18n.upd_tx(E'de_DE', E'patient', E'Patient');
select i18n.upd_tx(E'de_DE', E'patient photograph', E'Patientenphoto');
select i18n.upd_tx(E'de_DE', E'pdf form', E'PDF-Formular');
select i18n.upd_tx(E'de_DE', E'pending', E'ausstehend');
select i18n.upd_tx(E'de_DE', E'peripheral arterial blood oxygenization level, transduced', E'peripher-arterielle Blutsauerstoffsättigung, transduziert');
select i18n.upd_tx(E'de_DE', E'peripheral arterial pulse', E'peripher-arterieller Puls');
select i18n.upd_tx(E'de_DE', E'personal', E'persönlich');
select i18n.upd_tx(E'de_DE', E'pertussis', E'Pertussis');
select i18n.upd_tx(E'de_DE', E'Philippines', E'Philippinen');
select i18n.upd_tx(E'de_DE', E'phone consultation', E'Anruf');
select i18n.upd_tx(E'de_DE', E'physical therapy report', E'Therapiebericht (PT)');
select i18n.upd_tx(E'de_DE', E'pneumococcus', E'Pneumokokken');
select i18n.upd_tx(E'de_DE', E'Poland', E'Polen');
select i18n.upd_tx(E'de_DE', E'poliomyelitis', E'Poliomyelitis');
select i18n.upd_tx(E'de_DE', E'preliminary', E'vorläufig');
select i18n.upd_tx(E'de_DE', E'proxy encounter', E'indirekt');
select i18n.upd_tx(E'de_DE', E'psycho-social history', E'Sozialanamnese');
select i18n.upd_tx(E'de_DE', E'pulse', E'Puls');
select i18n.upd_tx(E'de_DE', E'pulse, periph.art.', E'Puls, periph.art.');
select i18n.upd_tx(E'de_DE', E'rabies', E'Tollwut');
select i18n.upd_tx(E'de_DE', E'reaction', E'Reaktion');
select i18n.upd_tx(E'de_DE', E'Reaction', E'Reaktion');
select i18n.upd_tx(E'de_DE', E'referral letter', E'Überweisungsbrief');
select i18n.upd_tx(E'de_DE', E'referral report cardiology', E'Arztbrief Kardio');
select i18n.upd_tx(E'de_DE', E'referral report ENT', E'Arztbrief HNO');
select i18n.upd_tx(E'de_DE', E'referral report eye', E'Arztbrief Augen');
select i18n.upd_tx(E'de_DE', E'referral report internal', E'Arztbrief Innere');
select i18n.upd_tx(E'de_DE', E'referral report neuro', E'Arztbrief Neuro');
select i18n.upd_tx(E'de_DE', E'referral report neurosurgery', E'Arztbrief Neurochirurgie');
select i18n.upd_tx(E'de_DE', E'referral report oncology', E'Arztbrief Onkologie');
select i18n.upd_tx(E'de_DE', E'referral report orthopaedic', E'Arztbrief Ortho');
select i18n.upd_tx(E'de_DE', E'referral report other', E'sonstiger Arztbrief');
select i18n.upd_tx(E'de_DE', E'referral report pathology', E'Arztbrief Patho');
select i18n.upd_tx(E'de_DE', E'referral report psychotherapy', E'Arztbrief Psychotherapie');
select i18n.upd_tx(E'de_DE', E'referral report radiology', E'Arztbrief Röntgen');
select i18n.upd_tx(E'de_DE', E'referral report surgical', E'Arztbrief Chirurgie');
select i18n.upd_tx(E'de_DE', E'referral report urology', E'Arztbrief Uro');
select i18n.upd_tx(E'de_DE', E'repeat script', E'Wiederholungsrezept');
select i18n.upd_tx(E'de_DE', E'results review change', E'Ergebnisbewertung geändert');
select i18n.upd_tx(E'de_DE', E'results review changed for patient', E'Bewertung von Testergebnissen änderte sich beim Patienten');
select i18n.upd_tx(E'de_DE', E'review docs', E'Dokumente durchsehen');
select i18n.upd_tx(E'de_DE', E'review lab', E'Labor durchsehen');
select i18n.upd_tx(E'de_DE', E'review results', E'Tests durchsehen');
select i18n.upd_tx(E'de_DE', E'review vaccs', E'Impfungen überprüfen');
select i18n.upd_tx(E'de_DE', E'RFE', E'BA');
select i18n.upd_tx(E'de_DE', E'Romania', E'Rumänien');
select i18n.upd_tx(E'de_DE', E'rubella', E'Röteln');
select i18n.upd_tx(E'de_DE', E'Russian Federation', E'Russische Föderation');
select i18n.upd_tx(E'de_DE', E'sample ID', E'Probennummer');
select i18n.upd_tx(E'de_DE', E'sample taken', E'Probe genommen');
select i18n.upd_tx(E'de_DE', E'Saudi Arabia', E'Saudi Arabien');
select i18n.upd_tx(E'de_DE', E'seasonal', E'saisonal');
select i18n.upd_tx(E'de_DE', E'secretary', E'Sekretärin');
select i18n.upd_tx(E'de_DE', E'sensitivity', E'Unverträglichkeit');
select i18n.upd_tx(E'de_DE', E'separated', E'getrennt');
select i18n.upd_tx(E'de_DE', E'sexual history', E'Sexualanamnese');
select i18n.upd_tx(E'de_DE', E'Seychelles', E'Seychellen');
select i18n.upd_tx(E'de_DE', E'sibling', E'Geschwister');
select i18n.upd_tx(E'de_DE', E'Singapore', E'Singapur');
select i18n.upd_tx(E'de_DE', E'site', E'Ort');
select i18n.upd_tx(E'de_DE', E'Slovakia', E'Slowakei');
select i18n.upd_tx(E'de_DE', E'Slovenia', E'Slowenien');
select i18n.upd_tx(E'de_DE', E'South Africa', E'Südafrika');
select i18n.upd_tx(E'de_DE', E'Spain', E'Spanien');
select i18n.upd_tx(E'de_DE', E'specifics attached to result record', E'Einzelheiten im Karteieintrag');
select i18n.upd_tx(E'de_DE', E'state/territory/province/region not available', E'Bundesland/Provinz/Region nicht verfügbar');
select i18n.upd_tx(E'de_DE', E'status', E'Status');
select i18n.upd_tx(E'de_DE', E'stepchild', E'Stiefkind');
select i18n.upd_tx(E'de_DE', E'stepparent', E'Stiefelter');
select i18n.upd_tx(E'de_DE', E'student nurse', E'Schwesternschüler/-in');
select i18n.upd_tx(E'de_DE', E'subcutaneous', E'subkutan');
select i18n.upd_tx(E'de_DE', E'substance', E'Substanz');
select i18n.upd_tx(E'de_DE', E'Summary', E'Zusammenfassung');
select i18n.upd_tx(E'de_DE', E'Sweden', E'Schweden');
select i18n.upd_tx(E'de_DE', E'Switzerland', E'Schweiz');
select i18n.upd_tx(E'de_DE', E'Syrian Arab Republic', E'Syrien');
select i18n.upd_tx(E'de_DE', E'Taiwan, Province Of China', E'Taiwan');
select i18n.upd_tx(E'de_DE', E'temporary', E'zeitweilig');
select i18n.upd_tx(E'de_DE', E'tetanus', E'Tetanus');
select i18n.upd_tx(E'de_DE', E'the patient\'s weight (body mass to be accurate)', E'Patientengewicht (Körpermasse, genaugenommen)');
select i18n.upd_tx(E'de_DE', E'tick-borne meningoencephalitis', E'FSME');
select i18n.upd_tx(E'de_DE', E'trainee - lab', E'MTLA (Azubi)');
select i18n.upd_tx(E'de_DE', E'trainee - X-ray', E'MTRA (Azubi)');
select i18n.upd_tx(E'de_DE', E'transsexual phenotype female', E'transsexuell, weiblicher Phänotyp');
select i18n.upd_tx(E'de_DE', E'transsexual phenotype male', E'transsexuell, männlicher Phänotyp');
select i18n.upd_tx(E'de_DE', E'Tunisia', E'Tunesien');
select i18n.upd_tx(E'de_DE', E'Turkey', E'Türkei');
select i18n.upd_tx(E'de_DE', E'Two vaccinations with overlapping target conditions recorded within one week of each other !', E'Zwei Impfungen innerhalb einer Woche haben überlappende Indikationen !');
select i18n.upd_tx(E'de_DE', E'type', E'Typ');
select i18n.upd_tx(E'de_DE', E'United Arab Emirates', E'Vereinigte Arabische Emirate');
select i18n.upd_tx(E'de_DE', E'United Kingdom', E'Großbritannien');
select i18n.upd_tx(E'de_DE', E'United States', E'Vereinigte Staaten von Amerika');
select i18n.upd_tx(E'de_DE', E'unknown', E'unbekannt');
select i18n.upd_tx(E'de_DE', E'unknown, unasked', E'unbekannt, nicht erfragt');
select i18n.upd_tx(E'de_DE', E'unreviewed (abnormal) results for patient', E'neue (pathologische) Testergebnisse beim Patienten');
select i18n.upd_tx(E'de_DE', E'unreviewed (normal) results for patient', E'neue (normale) Testergebnisse beim Patienten');
select i18n.upd_tx(E'de_DE', E'unreviewed documents for patient', E'neue Dokumente für Patient');
select i18n.upd_tx(E'de_DE', E'unreviewed results for patient', E'neue Testergebnisse beim Patienten');
select i18n.upd_tx(E'de_DE', E'Vaccination', E'Impfung');
select i18n.upd_tx(E'de_DE', E'vaccination record', E'Impfnachweis');
select i18n.upd_tx(E'de_DE', E'vaccine', E'Impfstoff');
select i18n.upd_tx(E'de_DE', E'value', E'Wert');
select i18n.upd_tx(E'de_DE', E'varicella', E'Varizellen');
select i18n.upd_tx(E'de_DE', E'video conference', E'per Video');
select i18n.upd_tx(E'de_DE', E'visual progress note', E'Bildnotiz');
select i18n.upd_tx(E'de_DE', E'ward', E'Betreuer');
select i18n.upd_tx(E'de_DE', E'web', E'WWW');
select i18n.upd_tx(E'de_DE', E'weight (body mass)', E'Gewicht (Masse)');
select i18n.upd_tx(E'de_DE', E'wght', E'KG');
select i18n.upd_tx(E'de_DE', E'widowed', E'verwitwet');
select i18n.upd_tx(E'de_DE', E'work', E'Arbeit');
select i18n.upd_tx(E'de_DE', E'workphone', E'Telefon auf Arbeit');
select i18n.upd_tx(E'de_DE', E'X-ray assistant', E'MTRA');
select i18n.upd_tx(E'de_DE', E'yellow fever', E'Gelbfieber');
select i18n.upd_tx(E'de_DE', E'your own practice', E'eigene Praxis');
select i18n.upd_tx(E'es_ES', E'Spain', E'España');

-- --------------------------------------------------------------
select gm.log_script_insertion('v21-gm-db-translations-de_DE.sql', '21.0');
