INSERT into dem.state(code, country, name) VALUES ('ACT', 'AU', 'Australian Capital Territory');
INSERT into dem.state(code, country, name) VALUES ('NSW', 'AU', 'New South Wales');
INSERT into dem.state(code, country, name) VALUES ('NT', 'AU', 'Northern Territory');
INSERT into dem.state(code, country, name) VALUES ('SA', 'AU', 'South Australia');
INSERT into dem.state(code, country, name) VALUES ('TAS', 'AU', 'Tasmania');
INSERT into dem.state(code, country, name) VALUES ('QLD', 'AU', 'Queensland');
INSERT into dem.state(code, country, name) VALUES ('VIC', 'AU', 'Victoria');
INSERT into dem.state(code, country, name) VALUES ('WA', 'AU', 'West Australia');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 0200, 'AUSTRALIAN NATIONAL UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0800, 'DARWIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0801, 'DARWIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0804, 'PARAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'ALAWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'BRINKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'CASUARINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'COCONUT GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'JINGILI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'LEE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'MILLNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'MOIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'NAKARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'NIGHTCLIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'RAPID CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'TIWI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'WAGAMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0810, 'WANGURI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0811, 'CASUARINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0812, 'ANULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0812, 'KARAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0812, 'LEANYER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0812, 'MALAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0812, 'MARRARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0812, 'SANDERSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0812, 'WOODLEIGH GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0812, 'WULAGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0813, 'SANDERSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0814, 'NIGHTCLIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0815, 'NORTHERN TERRITORY UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'BAGOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'EAST POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'FANNIE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'HMAS COONAWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'LARRAKEYAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'LUDMILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'PARAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'STUART PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'THE GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'THE NARROWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'WINNELLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0820, 'WOOLNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0821, 'WINNELLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'ANGURUGU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'CROKER ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'DALY RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'DARWIN MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'DELISSAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'GALIWINKU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'GOULBOURN ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'MANINGRIDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'MILINGIMBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'MINJILANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'NGUIU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'OENPELLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'PULARUMPI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'RAMINGINING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'UMBAKUMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'WADEYE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0822, 'WINNELLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0828, 'BERRIMAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0830, 'ARCHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0830, 'DRIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0830, 'GRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0830, 'MARLOW LAGOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0830, 'MOULDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0830, 'PALMERSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0830, 'WOODROFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0830, 'YARRAWONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0831, 'PALMERSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0832, 'BAKEWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0832, 'BELLAMACK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0832, 'GUNN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0832, 'MITCHELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0832, 'ROSEBERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0835, 'HOWARD SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0836, 'HUMPTY DOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0837, 'BERRY SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0837, 'NOONAMAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0840, 'DUNDEE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0845, 'BATCHELOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0846, 'ADELAIDE RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0847, 'PINE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0850, 'KATHERINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0851, 'KATHERINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'DALY WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'KATHERINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'LAJAMANU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'LARRIMAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'MARANBOY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'MATARANKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'NGUKURR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'NUMBULWAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0852, 'VICTORIA RIVER DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0853, 'TINDAL RAAF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0854, 'BORROLOOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0860, 'TENNANT CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0861, 'TENNANT CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0862, 'ELLIOTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0862, 'NEWCASTLE WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0862, 'TENNANT CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0862, 'WARREGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0870, 'ALICE SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0871, 'ALICE SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'ALI CURUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'ALICE SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'AREYONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'BARROW CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 0872, 'ERNABELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'FINKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 0872, 'FREGON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'HAASTS BLUFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'HERMANNSBURG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'KALTUKATJARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'KINTORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'PAPUNYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'SANTA TERESA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'TI TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'YUENDUMU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0872, 'YULARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0880, 'NHULUNBUY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0880, 'YIRRKALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0881, 'NHULUNBUY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0885, 'ALYANGULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NT'), 0886, 'JABIRU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1215, 'AUSTRALIA SQUARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1220, 'GROSVENOR PLACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1225, 'ROYAL EXCHANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1230, 'QUEEN VICTORIA BUILDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1235, 'SYDNEY SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1240, 'HAYMARKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1300, 'DARLINGHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1335, 'POTTS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1340, 'KINGS CROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1350, 'WOOLLAHRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1355, 'BONDI JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1360, 'DOUBLE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1363, 'MOORE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1420, 'STRAWBERRY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1424, 'STRAWBERRY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1427, 'STRAWBERRY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1435, 'ALEXANDRIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1445, 'ROSEBERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1450, 'CAMPERDOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1455, 'BOTANY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1460, 'MASCOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1465, 'KENSINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1470, 'DRUMMOYNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1475, 'MARRICKVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1480, 'KINGSGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1481, 'HURSTVILLE BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1485, 'KOGARAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1490, 'MIRANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1495, 'CARINGBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1499, 'SUTHERLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1515, 'WEST CHATSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1560, 'NORTHBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1565, 'MILSONS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1570, 'ARTARMON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1585, 'CROWS NEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1590, 'ST LEONARDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1595, 'LANE COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1630, 'HORNSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1635, 'HORNSBY NORTHGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1639, 'FRENCHS FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1640, 'FRENCHS FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1655, 'MANLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1660, 'MONA VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1670, 'NORTH RYDE BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1675, 'GLADESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1680, 'RYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1685, 'WEST RYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1700, 'ERMINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1701, 'RYDALMERE BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1710, 'EPPING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1715, 'PENNANT HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1730, 'SEVEN HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1750, 'NORTH PARRAMATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1755, 'BAULKHAM HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1765, 'CASTLE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1790, 'ST MARYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1800, 'ASHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1805, 'BURWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1811, 'SILVERWATER DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1825, 'LIDCOMBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1835, 'AUBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1851, 'WETHERILL PARK DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1860, 'FAIRFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1871, 'LIVERPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1875, 'MOOREBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1885, 'BANKSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1890, 'INGLEBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 1891, 'MILPERRA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2000, 'DAWES POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2000, 'HAYMARKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2000, 'MILLERS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2000, 'ST JAMES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2000, 'SYDNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2000, 'SYDNEY SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2000, 'THE ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2001, 'SYDNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2004, 'EASTERN SUBURBS MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2006, 'THE UNIVERSITY OF SYDNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2007, 'BROADWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2007, 'ULTIMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2008, 'CHIPPENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2008, 'DARLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2009, 'PYRMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2010, 'DARLINGHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2010, 'SURRY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2011, 'ELIZABETH BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2011, 'GARDEN ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2011, 'KINGS CROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2011, 'POTTS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2011, 'RUSHCUTTERS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2011, 'WOOLLOOMOOLOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2012, 'STRAWBERRY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2014, 'BEACONSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2015, 'ALEXANDRIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2015, 'BEACONSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2015, 'EVELEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2016, 'REDFERN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2017, 'WATERLOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2017, 'WATERLOO DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2017, 'ZETLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2018, 'EASTLAKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2018, 'ROSEBERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2019, 'BANKSMEADOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2019, 'BOTANY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2020, 'MASCOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2020, 'SYDNEY AIRPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2020, 'SYDNEY INTERNATIONAL AIRPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2021, 'CENTENNIAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2021, 'PADDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2022, 'BONDI JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2022, 'BONDI JUNCTION DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2022, 'QUEENS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2023, 'BELLEVUE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2024, 'BRONTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2024, 'WAVERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2025, 'WOOLLAHRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2026, 'BEN BUCKLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2026, 'BONDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2026, 'BONDI BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2026, 'TAMARAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2027, 'DARLING POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2027, 'EDGECLIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2027, 'POINT PIPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2028, 'DOUBLE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2029, 'ROSE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2030, 'DOVER HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2030, 'ROSE BAY NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2030, 'VAUCLUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2030, 'WATSONS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2031, 'CLOVELLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2031, 'CLOVELLY WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2031, 'RANDWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2031, 'ST PAULS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2032, 'DACEYVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2032, 'KINGSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2033, 'KENSINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2034, 'COOGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2035, 'MAROUBRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2035, 'PAGEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'CHIFLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'EASTGARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'HILLSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'LA PEROUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'LITTLE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'MALABAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'MATRAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'PHILLIP BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2036, 'PORT BOTANY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2037, 'GLEBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2038, 'ANNANDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2039, 'ROZELLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2040, 'LEICHHARDT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2040, 'LILYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2041, 'BALMAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2041, 'BIRCHGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2042, 'ENMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2042, 'NEWTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2043, 'ERSKINEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2044, 'ST PETERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2044, 'ST PETERS DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2044, 'SYDENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2044, 'TEMPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2045, 'DOBROYD POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2045, 'HABERFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2046, 'ABBOTSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2046, 'CANADA BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2046, 'CHISWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2046, 'FIVE DOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2046, 'RODD POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2046, 'RUSSELL LEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2046, 'WAREEMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2047, 'DRUMMOYNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2048, 'STANMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2048, 'WESTGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2049, 'LEWISHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2049, 'PETERSHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2050, 'CAMPERDOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2050, 'MISSENDEN ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2052, 'UNSW SYDNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2055, 'NORTH SYDNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2057, 'CHATSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2059, 'NORTH SYDNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2060, 'LAVENDER BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2060, 'MCMAHONS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2060, 'NORTH SYDNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2060, 'NORTH SYDNEY SHOPPINGWORLD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2060, 'WAVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2061, 'KIRRIBILLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2061, 'MILSONS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2062, 'CAMMERAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2063, 'NORTHBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2064, 'ARTARMON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2065, 'CROWS NEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2065, 'GORE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2065, 'GREENWICH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2065, 'NAREMBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2065, 'ROYAL NORTH SHORE HOSPITAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2065, 'ST LEONARDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2065, 'WOLLSTONECRAFT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2066, 'LANE COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2066, 'LINLEY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2066, 'LONGUEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2066, 'NORTHWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2066, 'RIVERVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2067, 'CHATSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2067, 'CHATSWOOD DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2067, 'CHATSWOOD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2068, 'CASTLECRAG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2068, 'MIDDLE COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2068, 'WILLOUGHBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2069, 'CASTLE COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2069, 'ROSEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2070, 'EAST LINDFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2070, 'LINDFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2070, 'LINDFIELD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2071, 'KILLARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2072, 'GORDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2073, 'PYMBLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2073, 'WEST PYMBLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2074, 'NORTH TURRAMURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2074, 'SOUTH TURRAMURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2074, 'TURRAMURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2074, 'WARRAWEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2075, 'ST IVES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2076, 'NORMANHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2076, 'WAHROONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2077, 'ASQUITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2077, 'HORNSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2077, 'WAITARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2079, 'MOUNT COLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2080, 'MOUNT KURING-GAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2081, 'BEROWRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2081, 'COWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2082, 'BEROWRA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2082, 'BEROWRA WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2083, 'BROOKLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2083, 'DANGAR ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2083, 'MILSONS PASSAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2083, 'MOONEY MOONEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2084, 'DUFFYS FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2084, 'TERREY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2085, 'BELROSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2085, 'BELROSE WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2085, 'DAVIDSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2086, 'FRENCHS FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2086, 'FRENCHS FOREST DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2087, 'FORESTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2087, 'KILLARNEY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2088, 'BALMORAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2088, 'BEAUTY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2088, 'CLIFTON GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2088, 'GEORGES HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2088, 'MOSMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2088, 'SPIT JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2088, 'THE SPIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2089, 'NEUTRAL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2089, 'NEUTRAL BAY JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2090, 'CREMORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2090, 'CREMORNE JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2092, 'SEAFORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2093, 'BALGOWLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2093, 'BALGOWLAH DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2093, 'CLONTARF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2093, 'MANLY VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2094, 'FAIRLIGHT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2095, 'MANLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2096, 'CURL CURL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2096, 'HARBORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2096, 'HARBORD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2096, 'QUEENSCLIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2097, 'COLLAROY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2097, 'COLLAROY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2097, 'COLLAROY PLATEAU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2097, 'WHEELER HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2099, 'CROMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2099, 'DEE WHY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2099, 'NARRAWEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2099, 'NORTH CURL CURL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2099, 'WINGALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2100, 'ALLAMBIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2100, 'ALLAMBIE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2100, 'BEACON HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2100, 'BROOKVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2100, 'BROOKVALE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2100, 'NORTH MANLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2100, 'OXFORD FALLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2100, 'WARRINGAH MALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2101, 'ELANORA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2101, 'INGLESIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2101, 'NARRABEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2102, 'WARRIEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2102, 'WARRIEWOOD DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2102, 'WARRIEWOOD SHOPPING SQUARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2103, 'MONA VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2104, 'BAYVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2105, 'CHURCH POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2105, 'ELVINA BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2105, 'LOVETT BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2105, 'SCOTLAND ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2106, 'NEWPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2106, 'NEWPORT BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2107, 'AVALON BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2107, 'BILGOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2107, 'CAREEL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2107, 'WHALE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2108, 'PALM BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2108, 'THE BASIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2109, 'MACQUARIE UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2110, 'HUNTERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2110, 'WOOLWICH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2111, 'GLADESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2111, 'HENLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2111, 'HUNTLEYS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2111, 'MONASH PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2111, 'TARBAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2111, 'TENNYSON POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2112, 'DENISTONE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2112, 'PUTNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2112, 'RYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2113, 'BLENHEIM ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2113, 'EAST RYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2113, 'MACQUARIE CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2113, 'MACQUARIE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2113, 'NORTH RYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2114, 'DENISTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2114, 'DENISTONE WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2114, 'MEADOWBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2114, 'MELROSE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2114, 'WEST RYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2115, 'ERMINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2116, 'RYDALMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2117, 'DUNDAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2117, 'OATLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2117, 'TELOPEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2118, 'CARLINGFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2118, 'CARLINGFORD COURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2118, 'KINGSDENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2119, 'BEECROFT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2119, 'CHELTENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2120, 'PENNANT HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2120, 'THORNLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2120, 'WESTLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2121, 'EPPING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2122, 'EASTWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2122, 'MARSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2123, 'PARRAMATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2124, 'PARRAMATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2125, 'WEST PENNANT HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2126, 'CHERRYBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2127, 'HOMEBUSH BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2127, 'NEWINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2128, 'SILVERWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2129, 'SYDNEY MARKETS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2130, 'SUMMER HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2131, 'ASHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2132, 'CROYDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2133, 'CROYDON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2133, 'ENFIELD SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2134, 'BURWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2135, 'STRATHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2136, 'BURWOOD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2136, 'ENFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2136, 'STRATHFIELD SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2137, 'CABARITA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2137, 'CONCORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2137, 'MORTLAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2137, 'NORTH STRATHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2138, 'CONCORD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2138, 'RHODES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2139, 'CONCORD REPATRIATION HOSPITAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2140, 'HOMEBUSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2140, 'STRATHFIELD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2141, 'BERALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2141, 'LIDCOMBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2142, 'BLAXCELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2142, 'CAMELLIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2142, 'CLYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2142, 'GRANVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2142, 'HOLROYD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2142, 'ROSEHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2143, 'BIRRONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2143, 'POTTS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2143, 'REGENTS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2144, 'AUBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2145, 'GIRRAWEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2145, 'GREYSTANES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2145, 'MAYS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2145, 'PENDLE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2145, 'WENTWORTHVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2145, 'WESTMEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2146, 'OLD TOONGABBIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2146, 'TOONGABBIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2146, 'TOONGABBIE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2147, 'KINGS LANGLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2147, 'LALOR PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2147, 'SEVEN HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2147, 'SEVEN HILLS WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2148, 'BLACKTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2148, 'BLACKTOWN DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2148, 'BLACKTOWN WESTPOINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2148, 'KINGS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2148, 'MARAYONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2148, 'PROSPECT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2150, 'HARRIS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2150, 'PARRAMATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2150, 'PARRAMATTA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2151, 'NORTH PARRAMATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2151, 'NORTH ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2152, 'NORTHMEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2153, 'BAULKHAM HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2153, 'BAULKHAM HILLS DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2153, 'BELLA VISTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2153, 'CHISHOLM CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2153, 'MODEL FARMS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2153, 'WINSTON HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2154, 'CASTLE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2155, 'KELLYVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2155, 'ROUSE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2156, 'ANNANGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2156, 'GLENHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2156, 'KENTHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2157, 'GLENORIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2158, 'DURAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2158, 'ROUND CORNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2159, 'ARCADIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2159, 'BERRILEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2159, 'FIDDLETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2159, 'GALSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2160, 'MERRYLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2160, 'MERRYLANDS WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2161, 'GUILDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2161, 'GUILDFORD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2161, 'OLD GUILDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2161, 'YENNORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2162, 'CHESTER HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2162, 'SEFTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2163, 'CARRAMAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2163, 'VILLAWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2164, 'HORSLEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2164, 'SMITHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2164, 'SMITHFIELD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2164, 'WETHERILL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2165, 'FAIRFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2165, 'FAIRFIELD EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2165, 'FAIRFIELD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2165, 'FAIRFIELD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2166, 'CABRAMATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2166, 'CANLEY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2166, 'CANLEY VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2166, 'LANSVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2167, 'GLENFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2168, 'ASHCROFT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2168, 'BUSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2168, 'CARTWRIGHT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2168, 'GREEN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2168, 'HECKENBERG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2168, 'HINCHINBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2168, 'MILLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2168, 'SADLEIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'CASULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'CASULA MALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'CHIPPING NORTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'HAMMONDVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'LIVERPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'LIVERPOOL BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'LIVERPOOL SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'LURNEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'MOOREBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'MOUNT PRITCHARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'PRESTONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'PRESTONS DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2170, 'WARWICK FARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'AUSTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'BADGERYS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'BRINGELLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'CATHERINE FIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'CECIL HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'CECIL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'EDMONDSON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'HORNINGSEA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'HOXTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'KEMPS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'LEPPINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'PLEASURE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'ROSSMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'SANDY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'VOYAGER POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2171, 'WEST HOXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2173, 'HOLSWORTHY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2173, 'WATTLE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2176, 'ABBOTSBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2176, 'BOSSLEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2176, 'EDENSOR PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2176, 'GREENFIELD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2176, 'PRAIRIEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2176, 'ST JOHNS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2176, 'WAKELEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2177, 'BONNYRIGG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2177, 'BONNYRIGG HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2190, 'CHULLORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2190, 'GREENACRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2190, 'MOUNT LEWIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2191, 'BELFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2192, 'BELMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2193, 'ASHBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2193, 'CANTERBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2193, 'HURLSTONE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2194, 'CAMPSIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2195, 'LAKEMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2195, 'LAKEMBA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2195, 'WILEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2196, 'PUNCHBOWL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2196, 'ROSELANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2197, 'BASS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2198, 'GEORGES HALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2199, 'YAGOONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2199, 'YAGOONA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2200, 'BANKSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2200, 'BANKSTOWN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2200, 'BANKSTOWN SQUARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2200, 'CONDELL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2200, 'MANAHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2200, 'MOUNT LEWIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2203, 'DULWICH HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2204, 'MARRICKVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2204, 'MARRICKVILLE METRO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2204, 'MARRICKVILLE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2205, 'ARNCLIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2205, 'TURRELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2206, 'CLEMTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2206, 'EARLWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2206, 'UNDERCLIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2207, 'BARDWELL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2207, 'BARDWELL VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2207, 'BEXLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2207, 'BEXLEY NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2207, 'BEXLEY SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2208, 'KINGSGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2208, 'KINGSWAY WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2209, 'BEVERLY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2209, 'NARWEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2210, 'LUGARNO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2210, 'PEAKHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2210, 'PEAKHURST DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2210, 'PEAKHURST HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2210, 'RIVERWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2211, 'PADSTOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2212, 'REVESBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2212, 'REVESBY NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2213, 'EAST HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2213, 'PANANIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2213, 'PICNIC POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2214, 'MILPERRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2215, 'SOUTHERN SUBURBS MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2216, 'BANKSIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2216, 'BRIGHTON-LE-SANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2216, 'KYEEMAGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2216, 'ROCKDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2216, 'ROCKDALE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2217, 'BEVERLEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2217, 'KOGARAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2217, 'KOGARAH BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2217, 'MONTEREY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2217, 'RAMSGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2217, 'RAMSGATE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2218, 'ALLAWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2218, 'CARLTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2219, 'SANDRINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2219, 'SANS SOUCI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2220, 'HURSTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2220, 'HURSTVILLE WESTFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2221, 'BLAKEHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2221, 'CARSS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2221, 'CONNELLS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2221, 'KYLE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2221, 'SOUTH HURSTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2222, 'PENSHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2223, 'MORTDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2223, 'OATLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2224, 'KANGAROO POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2224, 'SYLVANIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2224, 'SYLVANIA SOUTHGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2224, 'SYLVANIA WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2225, 'OYSTER BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2226, 'BONNET BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2226, 'COMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2226, 'JANNALI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2227, 'GYMEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2228, 'MIRANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2228, 'YOWIE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2229, 'CARINGBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2229, 'DOLANS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2229, 'LILLI PILLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2229, 'PORT HACKING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2229, 'TAREN POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2229, 'TAREN POINT DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2230, 'BUNDEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2230, 'CRONULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2230, 'MAIANBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2230, 'WOOLOOWARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2231, 'KURNELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2232, 'AUDLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2232, 'GRAYS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2232, 'KAREELA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2232, 'KIRRAWEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2232, 'KIRRAWEE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2232, 'LOFTUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2232, 'SUTHERLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2232, 'WORONORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2233, 'ENGADINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2233, 'HEATHCOTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2233, 'WATERFALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2233, 'WORONORA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2233, 'YARRAWARRAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2234, 'ALFORDS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2234, 'BANGOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2234, 'BARDEN RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2234, 'ILLAWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2234, 'LUCAS HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2234, 'MENAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2234, 'MENAI CENTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'CALGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'EAST GOSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'ERINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'ERINA FAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'GOSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'GOSFORD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'KARIONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'KULNURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'LISAROW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'LOWER MANGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'MANGROVE MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'MATCHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'MOUNT WHITE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'NARARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'NIAGARA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'PEATS RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'POINT CLARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'SOMERSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'SPRINGFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'TASCOTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'WENDOREE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2250, 'WYOMING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'AVOCA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'BENSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'COPACABANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'DAVISTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'GREEN POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'KINCUMBER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'MACMASTERS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'SARATOGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2251, 'YATTALUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2256, 'BLACKWALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2256, 'KOOLEWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2256, 'PATONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2256, 'PATONGA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2256, 'PEARL BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2256, 'PHEGANS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2256, 'WOY WOY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'BOOKER BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'DALEYS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'EMPIRE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'ETTALONG BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'HARDYS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'KILLCARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'PRETTY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'ST HUBERTS ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2257, 'UMINA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2258, 'KANGY ANGY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2258, 'OURIMBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'CHAIN VALLEY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'DOORALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'DURREN DURREN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'GWANDALAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'JILLIBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'KANWAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'LAKE MUNMORAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'LEMON TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'MANNERING PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'RAVENSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'SUMMERLAND POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'TACOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'TUGGERAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'TUGGERAWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'WARNERVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'WATANOBBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'WYEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'WYONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'WYONGAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2259, 'YARRAMALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2260, 'ERINA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2260, 'FORRESTERS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2260, 'NORTH AVOCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2260, 'TERRIGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2260, 'WAMBERAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'BATEAU BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'BAY VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'BERKELEY VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'BLUE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'CHITTAWAY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'CHITTAWAY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'GLENNING VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'KILLARNEY VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'LONG JETTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'LONG JETTY DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'SHELLY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'THE ENTRANCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'TOOWOON BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2261, 'TUMBI UMBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2262, 'BLUE HAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2262, 'BUDGEWOI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2262, 'BUFF POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2262, 'DOYALSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2262, 'HALEKULANI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2262, 'SAN REMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2263, 'CHARMHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2263, 'GOROKAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2263, 'LAKE HAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2263, 'NORAH HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2263, 'NORAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2263, 'TOUKLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'BONNELLS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'BRIGHTWATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'DORA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'ERARING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'MANDALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'MIRRABOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'MORISSET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'SILVERWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2264, 'SUNSHINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2265, 'COORANBONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2265, 'MARTINSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2267, 'WANGI WANGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2278, 'BARNSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2278, 'KILLINGWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2278, 'WAKEFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2280, 'BELMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2280, 'CROUDACE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2280, 'FLORAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2280, 'JEWELLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2280, 'MARKS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2280, 'VALENTINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2281, 'BLACKSMITHS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2281, 'CAMS WHARF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2281, 'CATHERINE HILL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2281, 'CAVES BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2281, 'MIDDLE CAMP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2281, 'NORDS WHARF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2281, 'SWANSEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2282, 'ELEEBANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2282, 'LAKELANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2282, 'WARNERS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'ARCADIA VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'AWABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'BALMORAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'BLACKALLS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'BOLTON POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'BUTTABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'CAREY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'COAL POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'FASSIFERN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'FENNELL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'FISHING POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'KILABEN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'RATHMINES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2283, 'TORONTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2284, 'ARGENTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2284, 'BOOLAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2284, 'BOORAGUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2284, 'MARMONG POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2284, 'SPEERS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2284, 'TERALBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2284, 'WOODRISING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2285, 'CARDIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2285, 'EDGEWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2285, 'EDGEWORTH DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2285, 'GLENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2286, 'HOLMESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2286, 'WEST WALLSEND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'BIRMINGHAM GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'ELERMORE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'FLETCHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'MARYLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'MINMI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'RANKIN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'SUMMER HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'WALLSEND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'WALLSEND DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2287, 'WALLSEND SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2289, 'ADAMSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2289, 'ADAMSTOWN HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2289, 'GARDEN SUBURB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2289, 'HIGHFIELDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2289, 'KOTARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2289, 'KOTARA FAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'BENNETTS GREEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'CHARLESTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'DUDLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'GATESHEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'HILLSBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'KAHIBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'MOUNT HUTTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'REDHEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'TINGIRA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2290, 'WHITEBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2291, 'MEREWETHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2291, 'MEREWETHER HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2291, 'THE JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2292, 'BROADMEADOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2293, 'MARYVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2293, 'WICKHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2294, 'CARRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2295, 'FERN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2295, 'STOCKTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2295, 'STOCKTON DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2296, 'ISLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2297, 'TIGHES HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2298, 'GEORGETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2298, 'WARATAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2298, 'WARATAH WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2299, 'JESMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2299, 'LAMBTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2299, 'NORTH LAMBTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2300, 'BAR BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2300, 'COOKS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2300, 'NEWCASTLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2300, 'NEWCASTLE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2300, 'THE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2302, 'NEWCASTLE WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2303, 'HAMILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2303, 'HAMILTON EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2303, 'HAMILTON SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2304, 'KOORAGANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2304, 'MAYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2304, 'MAYFIELD EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2304, 'MAYFIELD NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2304, 'MAYFIELD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2304, 'SANDGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2304, 'WARABROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2305, 'KOTARA EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2305, 'NEW LAMBTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2305, 'NEW LAMBTON HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2306, 'WINDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2307, 'SHORTLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2308, 'CALLAGHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2308, 'NEWCASTLE UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2309, 'DANGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2310, 'HUNTER REGION MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2311, 'ALLYNBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2311, 'EAST GRESFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2311, 'GRESFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2311, 'HALTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2311, 'LOSTOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2312, 'NABIAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2314, 'WILLIAMTOWN RAAF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2315, 'CORLETTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2315, 'FINGAL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2315, 'NELSON BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2315, 'SHOAL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2316, 'ANNA BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2316, 'BOAT HARBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2316, 'BOBS FARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2317, 'SALAMANDER BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2317, 'SOLDIERS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2318, 'CAMPVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2318, 'FULLERTON COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2318, 'MEDOWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2318, 'OYSTER COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2318, 'SALT ASH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2318, 'WILLIAMTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2319, 'LEMON TREE PASSAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2319, 'MALLABULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2319, 'TANILBA BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'BOLWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'FARLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'HILLSBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'LARGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'LORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'MAITLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'MAITLAND DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'MAITLAND NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'POKOLBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'ROTHBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'RUTHERFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2320, 'TELARAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'CLARENCE TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'GILLIESTON HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'GLEN WILLIAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'HEDDON GRETA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'HINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'LOCHINVAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'MORPETH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'RAWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2321, 'WOODVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2322, 'BERESFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2322, 'BLACK HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2322, 'HEXHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2322, 'LENAGHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2322, 'TARRO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2322, 'THORNTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2322, 'TOMAGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2322, 'WOODBERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'ASHTONFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'BRUNKERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'EAST MAITLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'FREEMANS WATERHOLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'GREENHILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'METFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'METFORD DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'MOUNT VINCENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'MULBRING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2323, 'TENAMBIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'CARRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'HAWKS NEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'HEATHERBRAE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'KARUAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'LIMEBURNERS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'MILLERS FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'NORTH ARM COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'OSTERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'RAYMOND TERRACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'RAYMOND TERRACE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'SEAHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'SWAN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2324, 'TEA GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'ABERDARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'ABERNETHY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'BELLBIRD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'CESSNOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'CESSNOCK DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'CESSNOCK WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'CONGEWAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'ELLALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'ELRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'KEARSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'KITCHENER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'LAGUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'MILLFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'MOUNT VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'NULKABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'PAXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'PAYNES CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'PELTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'QUORROBOLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2325, 'WOLLOMBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2326, 'ABERMAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2326, 'BISHOPS BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2326, 'LOXFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2326, 'WESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2327, 'KURRI KURRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2327, 'PELAW MAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2327, 'STANFORD MERTHYR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2328, 'DENMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2328, 'KERRABEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2329, 'BORAMBIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2329, 'BOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2329, 'CASSILIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2329, 'MERRIWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2329, 'UARBRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'BROKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'BULGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'CAMBERWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'CARROWBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'DURAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'GLENNIES CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'GREENLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'HEBDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'HOWES VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'JERRYS PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'MIRANNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'MITCHELLS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'MOUNT OLIVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'PUTTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'RAVENSWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'REEDY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'SINGLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'SINGLETON DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'ST CLAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2330, 'WARKWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2331, 'SINGLETON MILPO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'BAERAMI CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'EDDERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'GUNGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'HOLLYDEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'LIDDELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'MCCULLYS GAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'MUSCLE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'MUSWELLBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'SANDY HOLLOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2333, 'WYBONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2334, 'GRETA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2335, 'BELFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2335, 'BRANXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2335, 'DALWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2335, 'ELDERSLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2335, 'NORTH ROTHBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2335, 'STANHOPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2336, 'ABERDEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2336, 'DANGARFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2336, 'DARTBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2336, 'DAVIS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2336, 'ROUCHEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2336, 'UPPER ROUCHEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'BUNNAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'ELLERSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'GUNDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'KARS SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'MOONAN BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'MOONAN FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'OWENS GAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'PARKVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'SATUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'SCONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'STEWARTS BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'WINGEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2337, 'WOOLOOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2338, 'ARDGLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2338, 'BLANDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2338, 'MURRURUNDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2339, 'WARRAH CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2339, 'WILLOW TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'BOWLING ALLEY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'CARROLL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'DUNGOWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'GOWRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'NEMINGHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'NUNDLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'OXLEY VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'SOMERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'TAMWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'TAMWORTH DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'TAMWORTH SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'WEST TAMWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'WESTDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2340, 'WOOLOMIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2341, 'WERRIS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2342, 'CURRABUBULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2343, 'BLACKVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2343, 'CAROONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2343, 'COLLY BLUE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2343, 'PINE RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2343, 'QUIRINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2343, 'SPRING RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2343, 'WALLABADAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2344, 'DURI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2345, 'ATTUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2345, 'GARTHOWEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2346, 'MANILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2347, 'BARRABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2347, 'COBBADAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2347, 'UPPER HORTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2348, 'NEW ENGLAND MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'ACACIA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'ARMIDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'EAST ARMIDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'ENMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'EXMOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'HILLGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'INVERGOWRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'JEOGLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'METZ');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'NORTH HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'SOUTH HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'ST PATRICKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'WEST ARMIDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2350, 'WOLLOMOMBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2351, 'UNIVERSITY OF NEW ENGLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2352, 'KOOTINGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2352, 'LIMBRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2353, 'MOONBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2354, 'KENTUCKY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2354, 'NIANGALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2354, 'NOWENDOC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2354, 'WALCHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2354, 'WOLLUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2354, 'WOOLBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2355, 'BENDEMEER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2355, 'WATSONS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2356, 'GWABEGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2357, 'BUGALDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2357, 'COONABARABRAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2357, 'PURLEWAUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2357, 'ROCKY GLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2357, 'ULAMAMBRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2358, 'ENMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2358, 'KINGSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2358, 'URALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2359, 'BUNDARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'BUKKULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'ELSMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'GILGAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'GRAMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'GUM FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'INVERELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'LITTLE PLAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'MOUNT RUSSELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'NULLAMANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2360, 'WALLANGRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2361, 'ASHFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2361, 'BONSHAW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2365, 'BEN LOMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2365, 'BLACK MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2365, 'GLENCOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2365, 'GUYRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2365, 'LLANGOTHLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2365, 'WANDSWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2369, 'STANNIFER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2369, 'TINGHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2370, 'DUNDEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2370, 'FURRACABAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2370, 'GLEN INNES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2370, 'MATHESON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2370, 'NEWTON BOYD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2370, 'RED RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2370, 'SWAN VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2371, 'DEEPWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2371, 'EMMAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2371, 'STANNUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2371, 'TORRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2372, 'BLACK SWAMP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2372, 'BOLIVIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2372, 'BOONOO BOONOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2372, 'BUNGULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2372, 'LISTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2372, 'SANDY FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2372, 'TENTERFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2372, 'WYLIE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2379, 'MULLALEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2380, 'BURBURGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2380, 'COOCOOBOONAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2380, 'GUNNEDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2380, 'KELVIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2380, 'ORANGE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2381, 'BREEZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2381, 'CURLEWIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2381, 'PREMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2381, 'PULLAMING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2381, 'TAMBAR SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2382, 'BOGGABRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2386, 'BURREN JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2387, 'ROWENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2388, 'CUTTABRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2388, 'PILLIGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2388, 'WEE WAA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2390, 'BAAN BAA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2390, 'EDGEROI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2390, 'NARRABRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2390, 'TURRAWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2395, 'BINNAWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2395, 'WEETALIBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2396, 'BARADINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2396, 'KENEBRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2397, 'BELLATA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2398, 'GURLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2399, 'PALLAMALLAWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2400, 'ASHLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2400, 'CROOBLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2400, 'MOREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2400, 'TERRY HIE HIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2401, 'GRAVESEND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2402, 'COOLATAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2402, 'WARIALDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2403, 'DELUNGRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2403, 'KOLOONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2404, 'BINGARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2404, 'DINOGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2405, 'BOOMI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2405, 'GARAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2406, 'MUNGINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2408, 'NORTH STAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2409, 'BOGGABILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2410, 'YETMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2411, 'CROPPA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2415, 'MONKERAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2415, 'STROUD ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2420, 'BANDON GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2420, 'DUNGOG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2420, 'HILLDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2420, 'MARSHDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2420, 'SALISBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2420, 'WALLAROBBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2421, 'PATERSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2421, 'TREVALLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2421, 'VACY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'BARRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'BELBORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'BRETTI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'BUNDOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'COPELAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'CRAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'GLOUCESTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'RAWDON VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'STRATFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'UPPER BOWMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2422, 'WARDS RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'BOOLAMBAYTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'BULAHDELAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'BUNGWAHL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'COOLONGOLOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'MARKWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'NERONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'SEAL ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'UPPER MYALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'WANG WAUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'WILLINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2423, 'WOOTTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2424, 'CUNDLE FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2424, 'KNORRIT FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2424, 'MOUNT GEORGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2424, 'NUMBER ONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2425, 'ALLWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2425, 'BOORAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2425, 'GIRVAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2425, 'STROUD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2425, 'WASHPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2426, 'COOPERNOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2426, 'LANGLEY VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2427, 'CROWDY HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2427, 'HARRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2428, 'FORSTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2428, 'FORSTER DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2428, 'FORSTER SHOPPING VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2428, 'GREEN POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2428, 'SMITHS LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2428, 'TARBUCK BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2428, 'TUNCURRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'BOBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'BUNYAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'BURRELL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'CAPARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'COMBOYNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'DYERS CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'ELANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'FIREFLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'KILLABAKH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'KIMBRIKI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'KRAMBACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'MARLEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'MOORAL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'WARRIWILLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'WHERROL FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2429, 'WINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'BOHNOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'CHATHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'CUNDLETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'DIAMOND BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'FAILFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'GHINNI GHINNI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'HALLIDAYS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'KOLODONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'KOORAINGHAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'OLD BAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'PURFLEET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'TAREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'TAREE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'TINONEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2430, 'UPPER LANSDOWNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2431, 'JERSEYVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2431, 'SOUTH WEST ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2439, 'KENDALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2439, 'KEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2439, 'LORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'BELLBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'BELLIMBOPINNI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'CARRAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'CLYBUCCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'COLLOMBATTI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'COMARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'CRESCENT HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'FREDERICKTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'GLADSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'GREENHILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'HAT HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'HICKEYS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'KEMPSEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'LOWER CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'MILLBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'SMITHTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'SOUTH KEMPSEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'TOOROOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'VERGES CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2440, 'WILLAWARRIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'BALLENGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'CROSSMAGLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'EUNGAI CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'EUNGAI RAIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'GRASSY HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'GUM SCRUB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'KUNDABUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'ROLLANDS PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'STUARTS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2441, 'TELEGRAPH POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2442, 'MID NORTH COAST MSC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'CAMDEN HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'DUNBOGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'HANNAM VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'HERONS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'JOHNS RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'LAURIETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'MOORLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'NORTH HAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2443, 'WEST HAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2444, 'BLACKMANS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2444, 'FLYNNS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2444, 'PORT MACQUARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2444, 'PORT MACQUARIE BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2444, 'PORT MACQUARIE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2445, 'BONNY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2445, 'LAKE CATHIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'BAGNOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'BEECHWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'BELLANGRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'BYABARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'ELLENBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'HOLLISDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'HUNTINGDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'LONG FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'PAPPINBARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'PEMBROOKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'TOMS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2446, 'WAUCHOPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2447, 'MACKSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2447, 'SCOTTS HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2447, 'TAYLORS ARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2447, 'THUMB CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2447, 'WARRELL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2448, 'NAMBUCCA HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2448, 'VALLA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2449, 'ARGENTS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2449, 'BOWRAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2449, 'MISSABOTTI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'BOAMBEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'COFFS HARBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'COFFS HARBOUR DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'CORAMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'GLENREAGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'KARANGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'KORORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'LOWANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'LOWER BUCCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'MOONEE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'NANA GLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'TIMMSVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'ULONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2450, 'UPPER ORARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2452, 'SAWTELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2452, 'TOORMINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'BOSTOBRICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'BRIGGSVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'CASCADE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'DORRIGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'DUNDURRABIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'EBOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'HERNANI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'MEGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2453, 'TYRINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2454, 'BELLINGEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2454, 'FERNMOUNT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2454, 'KALANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2454, 'MYLESTOM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2454, 'RALEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2454, 'REPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2454, 'SUNNY CORNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2454, 'THORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2455, 'URUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2456, 'ARRAWARRA HEADLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2456, 'CORINDI BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2456, 'EMERALD BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2456, 'RED ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2456, 'SAFETY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2456, 'SANDY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2456, 'WOOLGOOLGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2456, 'WOOLGOOLGA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'BARYULGIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'BRUSHGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'CANGAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'COALDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'COPMANHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'COUTTS CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'COWPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'GRAFTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'GRAFTON WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'HALFWAY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'JACKADGERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'JUNCTION HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'KANGAROO CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'LAWRENCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'NYMBOIDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'SEELANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'SOUTH ARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'SOUTH GRAFTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'WATERVIEW HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2460, 'WINEGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2462, 'PILLAR VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2462, 'TUCABIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2462, 'ULMARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2462, 'WOOLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2463, 'BROOMS HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2463, 'MACLEAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2463, 'TULLYMORGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2463, 'WOODFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2464, 'YAMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2468, 'NORTHERN RIVERS MSC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2469, 'MUMMULGUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'BACKMEDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'BARAIMAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'CASINO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'CASINO WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'COOMBELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'DOBIES BIGHT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'DOUBTFUL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'DYRAABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'DYRAABA CENTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'DYRAABA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'ELLANGOWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'FAIRY HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'IRVINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'LEEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'MONGOGARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'NAUGHTONS GAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'PIORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'SEXTONVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'SHANNON BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'SPRING GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'STRATHEDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'TOMKI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2470, 'WOODVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2471, 'CORAKI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2471, 'SWAN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2471, 'TATHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2472, 'BROADWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2472, 'RILEYS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2472, 'WOODBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2473, 'EVANS HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'CAWONGLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'ETTRICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'GENEVA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'GREVILLIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'KYOGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'LINDESAY VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'LYNCHS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'RUKENVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'THE RISK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'TOONUMBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2474, 'WIANGAREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2475, 'URBENVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2476, 'ACACIA PLATEAU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2476, 'LEGUME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2476, 'OLD KOREELAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2476, 'WOODENBONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'ALSTONVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'ALSTONVILLE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'CABBAGE TREE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'DALWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'MEERSCHAUM VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'ROUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'ROUS MILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'URALBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'WARDELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2477, 'WOLLONGBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2478, 'BALLINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2478, 'BALLINA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2478, 'EMPIRE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2478, 'KEITH HALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2478, 'LENNOX HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2478, 'PIMLICO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2478, 'TEVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2478, 'TINTENBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2479, 'BANGALOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2479, 'BINNA BURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2479, 'BROOKLET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2479, 'FERNLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2479, 'NASHUA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'BENTLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'BEXHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'CLUNES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'CORNDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'DORROUGHBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'DUNOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'ELTHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'EUREKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'FEDERAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'GEORGICA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'GOOLMANGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'GOONELLABAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'LISMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'LISMORE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'MAROM CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'MCKEES HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'NIMBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'NORTH LISMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'NUMULGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'RICHMOND HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'ROCK VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'ROSEBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'RUTHVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'THE CHANNON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'TREGEAGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'TUCKURIMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'TUNCESTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'WHIAN WHIAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2480, 'WYRALLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2481, 'BROKEN HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2481, 'BYRON BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2481, 'BYRON BAY DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2481, 'SUFFOLK PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2481, 'TYAGARAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2482, 'GOONENGERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2482, 'MULLUMBIMBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'BILLINUDGEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'BRUNSWICK HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'BURRINGBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'CRABBES CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'MOOBALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'NEW BRIGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'OCEAN SHORES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'SOUTH GOLDEN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2483, 'YELGUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'BOAT HARBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'BRAY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'CHILLINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'CONDONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'CRYSTAL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'CUDGERA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'DOON DOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'DUNBIBLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'DUNGAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'EUNGELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'KUNGHUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'MURWILLUMBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'MURWILLUMBAH DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'NUMINBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'PALMVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'STOKERS SIDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'TYALGUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2484, 'UKI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2485, 'TWEED HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2485, 'TWEED HEADS WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2486, 'BANORA POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2486, 'BILAMBIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2486, 'CAROOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2486, 'TERRANORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2486, 'TWEED HEADS SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2486, 'TWEED HEADS SOUTH DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2487, 'CHINDERAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2487, 'CUDGEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2487, 'DURANBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2487, 'FINGAL HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2487, 'KINGSCLIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2487, 'STOTTS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2488, 'BOGANGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2488, 'CABARITA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2489, 'HASTINGS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2489, 'POTTSVILLE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2490, 'TUMBULGUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2500, 'CONISTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2500, 'GWYNNEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2500, 'KEIRAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2500, 'MANGERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2500, 'MOUNT KEIRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2500, 'MOUNT SAINT THOMAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2500, 'WOLLONGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2502, 'CRINGILA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2502, 'LAKE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2502, 'PRIMBEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2502, 'WARRAWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2505, 'KEMBLAWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2505, 'PORT KEMBLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2506, 'BERKELEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2508, 'COALCLIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2508, 'DARKES FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2508, 'HELENSBURGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2508, 'OTFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2508, 'STANWELL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2508, 'STANWELL TOPS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2515, 'AUSTINMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2515, 'CLIFTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2515, 'COLEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2515, 'SCARBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2515, 'THIRROUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2515, 'WOMBARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2516, 'BULLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2517, 'RUSSELL VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2517, 'WOONONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2518, 'BELLAMBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2518, 'BELLAMBI DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2518, 'CORRIMAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2518, 'TARRAWANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2518, 'TOWRADGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2519, 'BALGOWNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2519, 'FAIRY MEADOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2519, 'MOUNT OUSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2519, 'MOUNT PLEASANT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2520, 'WOLLONGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2521, 'SOUTH COAST MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2522, 'UNIVERSITY OF WOLLONGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2525, 'FIGTREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2526, 'CORDEAUX HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2526, 'FARMBOROUGH HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2526, 'KEMBLA GRANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2526, 'MOUNT KEMBLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2526, 'UNANDERRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2527, 'ALBION PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2527, 'ALBION PARK RAIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2528, 'BARRACK HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2528, 'BARRACK POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2528, 'LAKE ILLAWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2528, 'MOUNT WARRIGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2528, 'WARILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2528, 'WINDANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'BALARANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'BLACKBUTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'DUNMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'FLINDERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'OAK FLATS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'OAK FLATS DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'SHELL COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'SHELLHARBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2529, 'SHELLHARBOUR SQUARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2530, 'BROWNSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2530, 'DAPTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2530, 'HORSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2530, 'KANAHOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2530, 'KOONAWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2530, 'WONGAWILLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2530, 'YALLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2533, 'BOMBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2533, 'JAMBEROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2533, 'KIAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2533, 'MINNAMURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2534, 'FOXGROUND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2534, 'GERRINGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2534, 'GERROA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2534, 'TOOLIJOOA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2534, 'WERRI BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2535, 'BELLAWONGARAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2535, 'BERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2535, 'BUDDEROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2535, 'COOLANGATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2535, 'JASPERS BRUSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2535, 'SHOALHAVEN HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2535, 'WATTAMOLLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2535, 'WOODHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'BATEHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'BATEMANS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'BENANDARAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'BIMBIMBIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'BUCKENBOWRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'CATALINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'CURROWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'DENHAMS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'DURRAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'DURRAS NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'EAST LYNNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'GUERILLA BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'JEREMADRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'LILLI PILLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'LONG BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'MALONEYS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'MALUA BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'MERRICUMBENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'MOGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'MURRENGENBURG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'NELLIGEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'NORTH BATEMANS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'ROSEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'RUNNYFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'SOUTH DURRAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'SUNSHINE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'SURF BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'SURFSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2536, 'WOODLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'BERGALIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'BINGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'BROULEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'COILA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'CONGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'DEUA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'DEUA RIVER VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'KIORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'MERINGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'MOGENDOURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'MORUYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'MORUYA HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'MOSSY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'TOMAKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'TURLINJAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2537, 'TUROSS HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2538, 'MILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'BAWLEY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'BENDALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'BERRINGER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'BURRILL LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'CONJOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'CUNJURONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'KIOLOA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'LAKE CONJOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'MANYANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'MOLLYMOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'TABOURIE LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'TERMEIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'ULLADULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2539, 'YATTEYATTAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'BAMARANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'BASIN VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'BERRARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'BOLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'BRUNDEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'BURRIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'CABBAGE TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'CALLALA BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'CALLALA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'CAMBEWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'CROOKHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'CUDMIRRAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'CULBURRA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'CURRARONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'EROWAL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'FALLS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'GREENWELL POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'HMAS ALBATROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'HMAS CRESWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'HUSKISSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'HYAMS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2540, 'JERVIS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'MEROO MEADOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'MYOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'NOWRA NAVAL PO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'NUMBAA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'OLD EROWAL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'ORIENT POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'PYREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'SANCTUARY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'ST GEORGES BASIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'SUSSEX INLET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'SWANHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'TAPITALLEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'TERARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'TOMERONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'VINCENTIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'WANDANDIAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'WOOLLAMIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'WORRIGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'WRIGHTS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2540, 'YALWAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2541, 'BOMADERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2541, 'NOWRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2541, 'NOWRA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2545, 'BODALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2545, 'NERRIGUNDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'BARRAGGA BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'BEAUTY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'BERMAGUI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'CENTRAL TILBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'CUTTAGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'DALMENY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'DIGNAMS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'GREENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'NAROOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'NORTH NAROOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'TILBA TILBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'TINPOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'WADBILLIGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'WALLAGA LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2546, 'WALLAGA LAKE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2548, 'BERRAMBOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2548, 'MERIMBULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2548, 'TURA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2549, 'BROADWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2549, 'GREIGS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2549, 'NETHERCOTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2549, 'PAMBULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2549, 'SOUTH PAMBULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'BEGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'BEMBOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'BOURNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'BROGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'BURRAGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'CANDELO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'COBARGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'DOCTOR GEORGE MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'KINGSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'MOGAREEKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'MORANS CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'MUMBULLA MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'NELSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'QUAAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'ROCKY HALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'TATHRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'TOWAMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'WANDELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'WAPENGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'WOLUMLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'WYNDHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2550, 'YOWRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2551, 'EDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2551, 'KIAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2551, 'WONBOYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2551, 'WONBOYN LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2558, 'EAGLE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2558, 'ESCHOL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2558, 'KEARNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2559, 'BLAIRMOUNT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2559, 'CLAYMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'AIRDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'AMBARVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'APPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'BLAIR ATHOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'BRADBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'CAMPBELLTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'CAMPBELLTOWN DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'ENGLORIE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'GILEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'GLEN ALPINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'KENTLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'LEUMEAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'ROSEMEADOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'RUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'ST HELENS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'WEDDERBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2560, 'WOODBINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2563, 'MENANGLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2564, 'LONG POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2564, 'MACQUARIE FIELDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2565, 'DENHAM COURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2565, 'INGLEBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2565, 'MACQUARIE LINKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2566, 'BOW BOWING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2566, 'MINTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2566, 'RABY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2566, 'ST ANDREWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2566, 'VARROVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2567, 'CURRANS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2567, 'HARRINGTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2567, 'MOUNT ANNAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2567, 'NARELLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2567, 'NARELLAN DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2567, 'NARELLAN VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2568, 'CAMDEN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2568, 'MENANGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2569, 'DOUGLAS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'CAMDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'CAWDOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'COBBITTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'ELDERSLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'ELLIS LANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'GRASMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'MOUNT HUNTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'NATTAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'OAKDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'ORANGEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'THE OAKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2570, 'WEROMBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2571, 'BALMORAL VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2571, 'BUXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2571, 'COURIDJAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2571, 'PICTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2571, 'RAZORBACK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2571, 'WILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2572, 'LAKESLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2572, 'THIRLMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2573, 'TAHMOOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2574, 'BARGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2574, 'PHEASANTS NEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2574, 'YANDERRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2575, 'AYLMERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2575, 'COLO VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2575, 'HILL TOP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2575, 'MITTAGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2575, 'WELBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2575, 'YERRINBOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2576, 'BOWRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2576, 'BURRADOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2576, 'KANGALOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'AVOCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'BARRENGARRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'BEAUMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'BERRIMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'BURRAWANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'FITZROY FALLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'KANGAROO VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'MOSS VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'NEW BERRIMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'ROBERTSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'SUTTON FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2577, 'WILDES MEADOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2578, 'BUNDANOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2579, 'EXETER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2579, 'MARULAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2579, 'PENROSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2579, 'TALLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2579, 'WINGELLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'BANNISTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'BRADFORDVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'BUNGONIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'GOLSPIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'GOULBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'KENMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'KINGSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'LAKE BATHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'ROSLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'TARAGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'TARALGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'TOWRANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'WOMBEYAN CAVES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'WOODHOUSELEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'YALBRAITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2580, 'YARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2581, 'BREADALBANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2581, 'COLLECTOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2581, 'DALTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2581, 'GUNNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2582, 'BOOKHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2582, 'BOWNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2582, 'BURRINJUCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2582, 'MURRUMBATEMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2582, 'WEE JASPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2582, 'YASS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'BIGGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'BINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'BLANKET FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'CROOKED CORNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'CROOKWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'FULLERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'GRABBEN GULLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'KIALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'LAGGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'LIMERICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'PEELWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'RUGBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2583, 'TUENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2584, 'BINALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2585, 'GALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2586, 'BOOROWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2586, 'MURRINGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2586, 'REIDS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2586, 'RYE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2587, 'HARDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2587, 'KINGSVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2587, 'MURRUMBURRAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2587, 'WOMBAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2588, 'WALLENDBEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2589, 'SOUTHERN TABLELANDS MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2590, 'BETHUNGRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2590, 'COOTAMUNDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2590, 'ILLABO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2594, 'BRIBBAREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2594, 'MILVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2594, 'MONTEAGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2594, 'YOUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'BARTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'CANBERRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'DEAKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'DUNTROON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'HARMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'PARKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'PARLIAMENT HOUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'RUSSELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2600, 'YARRALUMLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2601, 'ACTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2601, 'BLACK MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2601, 'CANBERRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2602, 'AINSLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2602, 'DICKSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2602, 'DOWNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2602, 'HACKETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2602, 'LYNEHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2602, 'O''CONNOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2602, 'WATSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2603, 'FORREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2603, 'GRIFFITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2603, 'MANUKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2603, 'RED HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2604, 'CAUSEWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2604, 'KINGSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2604, 'NARRABUNDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2605, 'CURTIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2605, 'GARRAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2605, 'HUGHES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2606, 'CHIFLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2606, 'LYONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2606, 'O''MALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2606, 'PHILLIP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2606, 'SWINGER HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2606, 'WODEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2607, 'FARRER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2607, 'ISAACS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2607, 'MAWSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2607, 'PEARCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2607, 'TORRENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2608, 'CIVIC SQUARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2609, 'FYSHWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2609, 'PIALLIGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2609, 'SYMONSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2610, 'CANBERRA BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2611, 'BRINDABELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'CHAPMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'DUFFY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'FISHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'HOLDER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'MOUNT STROMLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'RIVETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'STIRLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'URIARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'WARAMANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'WESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2611, 'WESTON CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2612, 'BRADDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2612, 'CAMPBELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2612, 'REID');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2612, 'TURNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2614, 'ARANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2614, 'COOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2614, 'HAWKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2614, 'JAMISON CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2614, 'MACQUARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2614, 'PAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2614, 'SCULLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2614, 'WEETANGERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'CHARNWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'DUNLOP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'FLOREY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'FLYNN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'FRASER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'HIGGINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'HOLT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'KIPPAX');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'KIPPAX CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'LATHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'MACGREGOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'MELBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2615, 'SPENCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2616, 'BELCONNEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2617, 'BELCONNEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2617, 'BRUCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2617, 'EVATT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2617, 'GIRALANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2617, 'KALEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2617, 'LAWSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2617, 'MCKELLAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2617, 'UNIVERSITY OF CANBERRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2618, 'HALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2619, 'JERRABOMBERRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'BURRA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'GUNDAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2620, 'HUME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'KARABAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'MICHELAGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'QUEANBEYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'QUEANBEYAN EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'ROYALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'SUTTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2620, 'THARWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'WAMBOIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2620, 'WILLIAMSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2621, 'BUNGENDORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'ARALUEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'BALLALABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'BORO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'BRAIDWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'GUNDILLION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'JEMBAICUMBENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'MAJORS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'MAYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'MONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'MONGARLOWE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'NERRIGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'ORANMEIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2622, 'REIDSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2623, 'CAPTAINS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2624, 'CHARLOTTES PASS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2624, 'PERISHER VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2624, 'SMIGGIN HOLES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2625, 'THREDBO VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2626, 'BREDBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2627, 'JINDABYNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2628, 'BERRIDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2628, 'DALGETY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2628, 'EUCUMBENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2628, 'NUMBLA VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'ADAMINABY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'BUNGARBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'BUNYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'CABRAMURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'CHAKOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'COOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'JERANGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'KIANDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'NUMERALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'PEAK VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'ROCK FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'ROSE VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2630, 'YAOUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2631, 'ANDO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2631, 'NIMMITABEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2632, 'BIBBENLUKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2632, 'BOMBALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2632, 'CATHCART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2632, 'CRAIGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2632, 'MILA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2633, 'DELEGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2640, 'ALBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2640, 'EAST ALBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2640, 'LAVINGTON DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2640, 'NORTH ALBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2640, 'SOUTH ALBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2640, 'TABLE TOP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2640, 'TALMALMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2640, 'THURGOONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2641, 'LAVINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'BROCKLESBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'BURRUMBUTTOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'GEROGERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'JINDERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'JINGELLIC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'KHANCOBAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'RAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'TOOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'WALBUNDRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2642, 'YERONG CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2643, 'HOWLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2644, 'BOWNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2644, 'HOLBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2644, 'MULLENGANDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2644, 'WOOMARGAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2645, 'URANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2646, 'BALLDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2646, 'COROWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2646, 'DAYSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2646, 'LOWESDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2646, 'OAKLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2646, 'RENNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2646, 'SAVERNAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2647, 'MULWALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2648, 'CAL LAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2648, 'CURLWAA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2648, 'MOURQUONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2648, 'PALINYEWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2648, 'POMONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2648, 'POONCARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2648, 'RUFUS RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2648, 'WENTWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2649, 'LAUREL HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'ASHMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'CARABOST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'COLLINGULLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'COOKARDINIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'DOWNSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'GLENFIELD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'HAREFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'KOORINGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'LAKE ALBERT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'MOUNT AUSTIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'TOLLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'TURVEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'WAGGA WAGGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2650, 'WAGGA WAGGA SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2651, 'FOREST HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2651, 'WAGGA WAGGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'BOREE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'GALORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'GOOLGOWI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'GRONG GRONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'GUMLY GUMLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'HUMULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'LADYSMITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'MANGOPLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'MARRAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'MATONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'MERRIWAGGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'OLD JUNEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'ROSEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'TABBITA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'TARCUTTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2652, 'URANQUINTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2653, 'MANNUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2653, 'TUMBARUMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2655, 'FRENCH PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2655, 'THE ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2656, 'LOCKHART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2656, 'MILBRULONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2656, 'URANGELINE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2658, 'HENTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2658, 'PLEASANT HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2658, 'RYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2659, 'WALLA WALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2660, 'CULCAIRN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2660, 'MORVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2661, 'KAPOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2663, 'JUNEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2665, 'ARDLETHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2665, 'ARIAH PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2665, 'BARELLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2665, 'BECKOM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2665, 'BINYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2665, 'KAMARAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2665, 'MIRROOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2665, 'MOOMBOOLDOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2666, 'GROGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2666, 'REEFTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2666, 'SEBASTOPOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2666, 'SPRINGDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2666, 'TEMORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2666, 'TRUNGLEY HALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2668, 'BARMEDMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'BYGALORIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'ERIGOLIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'GIRRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'GUBBATA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'NARADHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'RANKINS SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'TALLIMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'TULLIBIGEAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'UNGARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2669, 'WEETHALLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2671, 'BURCHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2671, 'WEST WYALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2671, 'WYALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2672, 'BURGOONEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2672, 'LAKE CARGELLIGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2675, 'HILLSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2675, 'ROTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2678, 'CHARLES STURT UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'BEELBANGERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'BENEREMBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'BILBUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'GRIFFITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'HANWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'LAKE WYANGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'THARBOGANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'WIDGELLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'WILLBRIGGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2680, 'YOOGALI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2681, 'YENDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2700, 'COROBIMILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2700, 'GILLENBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2700, 'MORUNDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2700, 'NARRANDERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2701, 'COOLAMON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2702, 'GANMAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2703, 'YANCO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2705, 'CORBIE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2705, 'LEETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2705, 'MURRAMI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2705, 'WAMOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2705, 'WHITTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2706, 'DARLINGTON POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2707, 'ARGOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2707, 'COLEAMBALLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2708, 'MURRAY REGION MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'CALDWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'CONARGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'DENILIQUIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'GULPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'MATHOURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'MAYRUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'MOIRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'WAKOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2710, 'WANGANELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2711, 'BOOLIGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2711, 'CARRATHOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2711, 'GUNBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2711, 'HAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2711, 'MAUDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2711, 'OXLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2712, 'BERRIGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2713, 'BLIGHTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2713, 'FINLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2714, 'TOCUMWAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2715, 'BALRANALD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2715, 'HATFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2716, 'JERILDERIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2716, 'MABINS WELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2717, 'DARETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2720, 'GILMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2720, 'TALBINGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2720, 'TUMUT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2721, 'QUANDIALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2722, 'BRUNGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2722, 'GUNDAGAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2722, 'MUTTAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2722, 'NANGUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2725, 'STOCKINBINGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2726, 'JUGIONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2727, 'ADJUNGBILLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2727, 'COOLAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2729, 'ADELONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2729, 'BACK CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2729, 'COOLEYS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2729, 'GRAHAMSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2729, 'MOUNT HOREB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2729, 'TUMBLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2729, 'WONDALGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2730, 'BATLOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2730, 'GREEN HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2731, 'BUNNALOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2731, 'MOAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2731, 'WOMBOOTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2732, 'BARHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2733, 'MOULAMEIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2734, 'KYALITE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2735, 'KORALEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2736, 'GOODNIGHT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2736, 'TOOLEYBUC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2737, 'EUSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2738, 'GOL GOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2738, 'MONAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2739, 'BURONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2745, 'GLENMORE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2745, 'GREENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2745, 'LUDDENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2745, 'MULGOA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2745, 'REGENTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2745, 'WALLACIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2747, 'CAMBRIDGE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2747, 'KINGSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2747, 'LLANDILO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2747, 'SHANES PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2747, 'WERRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2747, 'WERRINGTON COUNTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2747, 'WERRINGTON DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2748, 'ORCHARD HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2749, 'CASTLEREAGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2749, 'CRANEBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2749, 'MOUNT PLEASANT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2750, 'EMU PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2750, 'LEONAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2750, 'PENRITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2750, 'PENRITH BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2750, 'PENRITH SOUTH DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2751, 'PENRITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2752, 'SILVERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2752, 'WARRAGAMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2753, 'BOWEN MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2753, 'GROSE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2753, 'GROSE WOLD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2753, 'HOBARTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2753, 'LONDONDERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2753, 'RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2753, 'YARRAMUNDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2754, 'NORTH RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2754, 'TENNYSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2755, 'RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'BLIGH PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'CATTAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'CLARENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'COLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'CORNWALLIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'EBENEZER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'FREEMANS REACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'GLOSSODIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'LOWER PORTLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'MAROOTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'MCGRATHS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'MULGRAVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'PITT TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'SCHEYVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'WILBERFORCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2756, 'WINDSOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2757, 'KURMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2758, 'BILPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2758, 'BLAXLANDS RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2758, 'KURRAJONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2759, 'ERSKINE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2759, 'MOUNT VERNON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2759, 'ST CLAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2760, 'COLYTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2760, 'OXLEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2760, 'ST MARYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2761, 'DEAN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2761, 'GLENDENNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2761, 'HASSALL GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2761, 'OAKHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2761, 'PLUMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2762, 'SCHOFIELDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2763, 'ACACIA GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2763, 'QUAKERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2764, 'QUAKERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2765, 'BERKSHIRE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2765, 'BOX HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2765, 'MARAYLYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2765, 'MARSDEN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2765, 'NELSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2765, 'OAKVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2765, 'RIVERSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2765, 'VINEYARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2766, 'EASTERN CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2766, 'ROOTY HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2767, 'DOONSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2767, 'WOODCROFT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2768, 'GLENWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2768, 'PARKLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2768, 'STANHOPE GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'BIDWILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'BLACKETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'DHARRUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'EMERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'HEBERSHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'LETHBRIDGE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'MINCHINBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'MOUNT DRUITT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'SHALVEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'TREGEAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'WHALAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2770, 'WILLMOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2773, 'GLENBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2773, 'LAPSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2774, 'BLAXLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2774, 'MOUNT RIVERVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2774, 'WARRIMOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2775, 'CENTRAL MACDONALD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2775, 'LAUGHTONDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2775, 'LOWER HAWKESBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2775, 'SPENCER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2775, 'ST ALBANS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2775, 'WISEMANS FERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2776, 'FAULCONBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2777, 'HAWKESBURY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2777, 'SPRINGWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2777, 'VALLEY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2777, 'WINMALEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2777, 'YELLOW ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2778, 'LINDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2778, 'WOODFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2779, 'HAZELBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2780, 'KATOOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2780, 'LEURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2780, 'MEDLOW BATH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2782, 'WENTWORTH FALLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2783, 'LAWSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2784, 'BULLABURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2785, 'BLACKHEATH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2785, 'MEGALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2786, 'BELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2786, 'DARGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2786, 'MOUNT IRVINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2786, 'MOUNT VICTORIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2786, 'MOUNT WILSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'BLACK SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'DUCKMALOI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'EDITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'GINGKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'HAZELGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'OBERON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'PORTERS RETREAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'SHOOTERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2787, 'TARANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'BOWENFELS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'CLARENCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'COBAR PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'CULLEN BULLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'HAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'HARTLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'JENOLAN CAVES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'LIDSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'LITHGOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'LITTLE HARTLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'LOWTHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'MARRANGAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'RYDAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2790, 'SODWALLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2791, 'CARCOAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2792, 'MANDURAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2793, 'DARBYS FALLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2793, 'WOODSTOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2794, 'BUMBALDRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2794, 'COWRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2794, 'NOONBINNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2794, 'WATTAMONDARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2794, 'WESTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'BALD RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'BALLYROE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'BATHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'BREWONGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'BURRAGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'DARK CORNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'DUNKELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'DURAMANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'EGLINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'FREEMANTLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'GEMALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'GEORGES PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'HOBBYS YARDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'ISABELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'JUDDS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'KELSO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'LOCKSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'MEADOW FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'MOUNT DAVID');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'NEWBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'PEEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'PERTHVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'RAGLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'ROCKLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'SOFALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'SUNNY CORNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'THE ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'TRUNKEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'TURONDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'WAMBOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'WATTLE FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'WEST BATHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'WIMBLEDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'WISEMANS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2795, 'YETHOLME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2797, 'GARLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2797, 'LYNDHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2798, 'FOREST REEFS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2798, 'MILLTHORPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2798, 'TALLWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2799, 'BARRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2799, 'BLAYNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2799, 'BROWNS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2799, 'NEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2799, 'VITTORIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'BORENORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'BOWEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'CARGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'LUCKNOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'MARCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'MULLION CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'NARRAMBLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'NASHDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'ORANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2800, 'SPRING HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2803, 'BENDICK MURRELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2803, 'CROWTHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2803, 'WIRRIMAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2804, 'CANOWINDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2805, 'GOOLOOGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2806, 'EUGOWRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2807, 'KOORAWATHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2808, 'WYANGALA DAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2809, 'GREENETHORPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2810, 'BIMBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2810, 'CARAGABAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2810, 'GRENFELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2810, 'PULLABOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'ARTHURVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'BAKERS SWAMP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'BODANGORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'DRIPSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'FARNHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'MARYVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'MUMBIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'NEUREA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'SPICERS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'STUART TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'WALMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2820, 'WELLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2821, 'NARROMINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2823, 'TRANGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2824, 'WARREN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2825, 'BOGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2825, 'CANONBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2825, 'MIANDETTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2825, 'MULLENGUDGERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2825, 'NYNGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2826, 'WESTERN PLAINS MSC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2827, 'COLLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2827, 'CURBAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2827, 'GILGANDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2828, 'GULARGAMBONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2828, 'WARRUMBUNGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2829, 'COMBARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2829, 'COONAMBLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2830, 'BALLIMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2830, 'BROCKLEHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2830, 'DUBBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2830, 'MOGRIGUY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2830, 'MURONBUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'ARMATREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'BALLADORAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'BYROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'CARINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'COOLABAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'ELONG ELONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'EUMUNGERIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'GEURIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'GIRILAMBONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'GOODOOGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'HERMIDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'MERRYGOEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'NEILREX');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'NEVERTIRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'NYMAGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'QUAMBONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'TOORAWEENAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2831, 'WONGARBON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2832, 'COME BY CHANCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2832, 'CRYON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2832, 'CUMBORAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2832, 'WALGETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2833, 'COLLARENEBRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2833, 'POKATAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2834, 'LIGHTNING RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2835, 'COBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2836, 'WHITE CLIFFS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2836, 'WILCANNIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2839, 'BREWARRINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2839, 'WEILMORINGLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'BARRINGUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'BOURKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'ENNGONIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'FORDS BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'LOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'TILPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'URISINO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'WANAARING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2840, 'YANTABULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2842, 'MENDOORAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2842, 'NEW MOLLYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2843, 'COOLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2844, 'BIRRIWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2844, 'COBBORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2844, 'CRABOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2844, 'DUNEDOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2844, 'LEADVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2844, 'TUCKLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2845, 'WALLERAWANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2846, 'CAPERTEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2846, 'GLEN DAVIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2847, 'PIPERS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2847, 'PORTLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2848, 'CHARBON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2848, 'CLANDULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2848, 'KANDOS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2849, 'BYLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2849, 'RYLSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'HARGRAVES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'HAVILAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'HILL END');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'ILFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'LUE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'MUDGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'RUNNING STREAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'TURILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'TWELVE MILE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'ULAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'WINDEYER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'WOLLAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2850, 'YARRAWONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2852, 'GOOLMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2852, 'GULGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2852, 'LAHEYS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2852, 'TWO MILE FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2864, 'CUDAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2864, 'MURGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2864, 'TOOGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2865, 'MANILDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2866, 'EUCHAREENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2866, 'GARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2866, 'LARRAS LEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2866, 'MOLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2867, 'BALDRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2867, 'CUMNOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2868, 'YEOVAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2869, 'PEAK HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2869, 'TOMINGLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2869, 'TREWILGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2870, 'ALECTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2870, 'COOKAMIDGERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2870, 'DAROOBALGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2870, 'GOONUMBLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2870, 'MANDAGERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2870, 'NELUNGALOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2870, 'PARKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2870, 'TICHBORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2871, 'BEDGEREBONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2871, 'FORBES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2871, 'GAREMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2871, 'WIRRINYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2873, 'ALBERT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2873, 'TOTTENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2874, 'TULLAMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2875, 'FIFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2875, 'OOTHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2875, 'TRUNDLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2875, 'YARRABANDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2876, 'BOGAN GATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2876, 'GUNNINGBLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2877, 'CONDOBOLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2877, 'DERRIWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2877, 'EUABALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2877, 'MOUNT HOPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2878, 'CONOBLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2878, 'DARNICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2878, 'IVANHOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2878, 'MOSSGIEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2878, 'TRIDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2879, 'MENINDEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2880, 'BROKEN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2880, 'MILPARINKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2880, 'SILVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2880, 'TIBOOBURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2890, 'AUSTRALIAN DEFENCE FORCES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2898, 'LORD HOWE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 2899, 'NORFOLK ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2900, 'GREENWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2900, 'TUGGERANONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2901, 'TUGGERANONG DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2902, 'KAMBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2903, 'ERINDALE CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2903, 'OXLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2903, 'WANNIASSA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2904, 'FADDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2904, 'GOWRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2904, 'MACARTHUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2904, 'MONASH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2905, 'BONYTHON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2905, 'CALWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2905, 'CHISHOLM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2905, 'GILMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2905, 'ISABELLA PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2905, 'RICHARDSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2905, 'THEODORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2906, 'BANKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2906, 'CONDER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2906, 'GORDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2911, 'CRACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2911, 'KENNY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2911, 'MITCHELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2911, 'MITCHELL DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2912, 'GUNGAHLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2913, 'CASEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2913, 'FRANKLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2913, 'GINNINDERRA VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2913, 'KINLYSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2913, 'NGUNNAWAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2913, 'NICHOLLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2913, 'PALMERSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2913, 'TAYLOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2914, 'AMAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2914, 'FORDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2914, 'HARRISON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2914, 'MONCRIEFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2914, 'MULANGGARRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='ACT'), 2914, 'THROSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3000, 'MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3001, 'MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3002, 'EAST MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3002, 'PARLIAMENT HOUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3003, 'WEST MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3004, 'QUEENS ROAD MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3004, 'ST KILDA ROAD MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3005, 'WORLD TRADE CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3006, 'SOUTHBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3008, 'DOCKLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3010, 'UNIVERSITY OF MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3011, 'FOOTSCRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3011, 'SEDDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3011, 'SEDDON WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3012, 'BROOKLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3012, 'KINGSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3012, 'MAIDSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3012, 'TOTTENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3012, 'WEST FOOTSCRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3013, 'YARRAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3013, 'YARRAVILLE WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3015, 'NEWPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3015, 'SOUTH KINGSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3015, 'SPOTSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3016, 'WILLIAMSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3018, 'ALTONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3018, 'SEAHOLME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3019, 'BRAYBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3019, 'ROBINSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3020, 'ALBION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3020, 'SUNSHINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3021, 'ALBANVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3021, 'KEALBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3021, 'KINGS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3021, 'ST ALBANS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3022, 'ARDEER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3022, 'DEER PARK EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3023, 'BURNSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3023, 'CAROLINE SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3023, 'DEER PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3024, 'MOUNT COTTRELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3024, 'WYNDHAM VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3025, 'ALTONA NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3026, 'LAVERTON NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3028, 'ALTONA MEADOWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3028, 'LAVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3029, 'HOPPERS CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3029, 'TARNEIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3029, 'TRUGANINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3030, 'DERRIMUT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3030, 'POINT COOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3030, 'WERRIBEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3031, 'FLEMINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3031, 'KENSINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3032, 'ASCOT VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3032, 'HIGHPOINT CITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3032, 'MARIBYRNONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3032, 'TRAVANCORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3033, 'KEILOR EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3034, 'AVONDALE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3036, 'KEILOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3037, 'DELAHEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3037, 'HILLSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3037, 'SYDENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3038, 'KEILOR DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3038, 'TAYLORS LAKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3039, 'MOONEE PONDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3040, 'ABERFELDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3040, 'ESSENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3040, 'ESSENDON WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3041, 'ESSENDON NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3041, 'STRATHMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3041, 'STRATHMORE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3042, 'AIRPORT WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3042, 'KEILOR PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3042, 'NIDDRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3043, 'GLADSTONE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3043, 'GOWANBRAE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3043, 'TULLAMARINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3044, 'PASCOE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3044, 'PASCOE VALE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3044, 'WESTBREEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3045, 'MELBOURNE AIRPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3046, 'GLENROY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3046, 'HADFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3046, 'OAK PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3047, 'BROADMEADOWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3047, 'DALLAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3047, 'JACANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3048, 'COOLAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3048, 'MEADOW HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3049, 'ATTWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3049, 'WESTMEADOWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3050, 'ROYAL MELBOURNE HOSPITAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3051, 'HOTHAM HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3051, 'NORTH MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3052, 'MELBOURNE UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3052, 'PARKVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3053, 'CARLTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3053, 'CARLTON SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3054, 'CARLTON NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3055, 'BRUNSWICK WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3056, 'BRUNSWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3057, 'BRUNSWICK EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3058, 'COBURG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3058, 'COBURG NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3058, 'MERLYNSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3058, 'MORELAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3059, 'GREENVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3060, 'FAWKNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3061, 'CAMPBELLFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3062, 'SOMERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3063, 'OAKLANDS JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3063, 'YUROKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3064, 'CRAIGIEBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3064, 'DONNYBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3064, 'KALKALLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3064, 'MICKLEHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3064, 'ROXBURGH PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3065, 'FITZROY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3066, 'COLLINGWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3067, 'ABBOTSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3068, 'CLIFTON HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3068, 'FITZROY NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3070, 'NORTHCOTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3071, 'THORNBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3072, 'NORTHLAND CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3072, 'PRESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3072, 'PRESTON SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3072, 'REGENT WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3073, 'KEON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3073, 'RESERVOIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3074, 'THOMASTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3075, 'LALOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3076, 'EPPING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3076, 'EPPING DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3078, 'ALPHINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3078, 'FAIRFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3079, 'IVANHOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3079, 'IVANHOE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3081, 'HEIDELBERG HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3081, 'HEIDELBERG RGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3081, 'HEIDELBERG WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3082, 'MILL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3083, 'BUNDOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3083, 'KINGSBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3084, 'BANYULE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3084, 'EAGLEMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3084, 'HEIDELBERG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3084, 'ROSANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3084, 'VIEWBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3085, 'MACLEOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3085, 'YALLAMBIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3087, 'WATSONIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3088, 'BRIAR HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3088, 'GREENSBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3088, 'SAINT HELENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3089, 'DIAMOND CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3090, 'PLENTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3091, 'YARRAMBAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3093, 'LOWER PLENTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3094, 'MONTMORENCY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3095, 'ELTHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3095, 'ELTHAM NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3095, 'RESEARCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3096, 'WATTLE GLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3097, 'BEND OF ISLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3097, 'KANGAROO GROUND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3099, 'ARTHURS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3099, 'COTTLES BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3099, 'HURSTBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3099, 'NUTFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3099, 'STRATHEWEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3101, 'KEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3102, 'KEW EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3103, 'BALWYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3104, 'BALWYN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3105, 'BULLEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3106, 'TEMPLESTOWE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3107, 'TEMPLESTOWE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3107, 'TEMPLESTOWE LOWER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3108, 'DONCASTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3109, 'DONCASTER EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3109, 'DONCASTER HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3109, 'TUNSTALL SQUARE PO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3110, 'NUNAWADING BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3111, 'DONVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3113, 'WARRANDYTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3114, 'PARK ORCHARDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3115, 'WONGA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3116, 'CHIRNSIDE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3121, 'BURNLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3121, 'RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3122, 'HAWTHORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3123, 'HAWTHORN EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3124, 'CAMBERWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3124, 'CAMBERWELL NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3124, 'CAMBERWELL SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3124, 'CAMBERWELL WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3124, 'MIDDLE CAMBERWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3125, 'BENNETTSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3125, 'BURWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3126, 'CAMBERWELL EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3126, 'CANTERBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3127, 'MONT ALBERT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3127, 'SURREY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3128, 'BOX HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3128, 'BOX HILL SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3128, 'HOUSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3128, 'WATTLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3129, 'BOX HILL NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3129, 'KERRIMUIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3129, 'MONT ALBERT NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3130, 'BLACKBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3130, 'BLACKBURN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3130, 'BLACKBURN SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3130, 'LABURNUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3131, 'BRENTFORD SQUARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3131, 'FOREST HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3131, 'NUNAWADING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3132, 'HEATHERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3132, 'MITCHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3132, 'RANGEVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3133, 'VERMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3133, 'VERMONT SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3134, 'RINGWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3134, 'RINGWOOD NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3134, 'WARRANDYTE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3134, 'WARRANWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3135, 'BEDFORD ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3135, 'HEATHMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3135, 'RINGWOOD EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3136, 'CROYDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3136, 'CROYDON HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3136, 'CROYDON NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3136, 'CROYDON SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3137, 'KILSYTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3137, 'KILSYTH SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3138, 'MOOROOLBARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3139, 'HODDLES CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3139, 'LAUNCHING PLACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3139, 'SEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3139, 'WANDIN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3139, 'WOORI YALLOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3139, 'YELLINGBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3140, 'LILYDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3141, 'SOUTH YARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3142, 'HAWKSBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3142, 'TOORAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3143, 'ARMADALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3143, 'ARMADALE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3144, 'KOOYONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3144, 'MALVERN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3145, 'CAULFIELD EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3145, 'CENTRAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3145, 'DARLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3145, 'MALVERN EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3146, 'GLEN IRIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3147, 'ASHBURTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3147, 'ASHWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3148, 'CHADSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3148, 'HOLMESGLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3149, 'MOUNT WAVERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3149, 'SYNDAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3150, 'GLEN WAVERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3150, 'WHEELERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3151, 'BURWOOD EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3151, 'BURWOOD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3152, 'KNOX CITY CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3152, 'STUDFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3152, 'WANTIRNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3152, 'WANTIRNA SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3153, 'BAYSWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3153, 'BAYSWATER NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3154, 'THE BASIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3155, 'BORONIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3156, 'FERNTREE GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3156, 'LYSTERFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3156, 'MOUNTAIN GATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3156, 'UPPER FERNTREE GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3158, 'UPWEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3159, 'MENZIES CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3159, 'SELBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3160, 'BELGRAVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3160, 'TECOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3161, 'CAULFIELD JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3161, 'CAULFIELD NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3162, 'CAULFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3162, 'CAULFIELD SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3163, 'CARNEGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3163, 'GLEN HUNTLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3163, 'MURRUMBEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3164, 'DANDENONG SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3165, 'BENTLEIGH EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3165, 'COATESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3166, 'HUGHESDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3166, 'HUNTINGDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3166, 'OAKLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3166, 'OAKLEIGH EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3167, 'OAKLEIGH SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3168, 'CLAYTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3168, 'NOTTING HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3169, 'CLARINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3169, 'CLAYTON SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3170, 'MULGRAVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3171, 'SANDOWN VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3171, 'SPRINGVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3172, 'DINGLEY VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3172, 'SPRINGVALE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3173, 'KEYSBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3174, 'NOBLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3174, 'NOBLE PARK NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3175, 'BANGHOLME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3175, 'DANDENONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3175, 'DANDENONG SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3176, 'SCORESBY BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3177, 'DOVETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3178, 'ROWVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3179, 'SCORESBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3180, 'KNOXFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3181, 'PRAHRAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3181, 'WINDSOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3182, 'ST KILDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3182, 'ST KILDA SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3182, 'ST KILDA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3183, 'BALACLAVA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3183, 'ST KILDA EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3184, 'BRIGHTON ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3184, 'ELWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3185, 'ELSTERNWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3185, 'GARDENVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3185, 'RIPPONLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3186, 'BRIGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3186, 'DENDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3187, 'BRIGHTON EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3187, 'NORTH ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3188, 'HAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3188, 'HAMPTON EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3188, 'HAMPTON NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3189, 'MOORABBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3189, 'MOORABBIN EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3189, 'WISHART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3190, 'HIGHETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3191, 'SANDRINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3192, 'CHELTENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3192, 'CHELTENHAM EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3192, 'SOUTHLAND CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3193, 'BEAUMARIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3193, 'BLACK ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3193, 'CROMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3194, 'MENTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3194, 'MOORABBIN AIRPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3195, 'ASPENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3195, 'ASPENDALE GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3195, 'BRAESIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3195, 'MORDIALLOC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3195, 'PARKDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3196, 'BONBEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3196, 'CHELSEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3196, 'CHELSEA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3196, 'EDITHVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3197, 'CARRUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3197, 'PATTERSON LAKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3198, 'BELVEDERE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3198, 'SEAFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3199, 'FRANKSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3199, 'KARINGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3200, 'FRANKSTON NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3200, 'PINES FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3201, 'CARRUM DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3202, 'HEATHERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3204, 'BENTLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3204, 'MCKINNON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3204, 'ORMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3205, 'SOUTH MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3205, 'SOUTH MELBOURNE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3206, 'ALBERT PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3206, 'MIDDLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3207, 'GARDEN CITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3207, 'PORT MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3211, 'LITTLE RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3212, 'LARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3214, 'CORIO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3214, 'NORLANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3214, 'NORTH SHORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3215, 'BELL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3215, 'BELL POST HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3215, 'HAMLYN HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3215, 'NORTH GEELONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3216, 'BELMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3216, 'FRESHWATER CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3216, 'GROVEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3216, 'HIGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3216, 'MARSHALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3216, 'MOUNT DUNEED');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3216, 'WANDANA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3216, 'WAURN PONDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3217, 'DEAKIN UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3218, 'GEELONG WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3218, 'HERNE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3218, 'MANIFOLD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3219, 'BREAKWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3219, 'EAST GEELONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3219, 'NEWCOMB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3219, 'ST ALBANS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3219, 'WHITTINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3220, 'GEELONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3220, 'NEWTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'ANAKIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'BARRABOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'BATESFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'BELLARINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'CERES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'FYANSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'GNARWARRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'KENNETT RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'LOVELY BANKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'MOOLAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'MOORABOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'MURGHEBOLUC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'STAUGHTON VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'STONEHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'WALLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'WONGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3221, 'WYE RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3222, 'CLIFTON SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3222, 'CURLEWIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3222, 'DRYSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3222, 'MANNERIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3222, 'MARCUS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3223, 'INDENTED HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3223, 'PORTARLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3223, 'ST LEONARDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3224, 'LEOPOLD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3225, 'POINT LONSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3225, 'QUEENSCLIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3226, 'OCEAN GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3227, 'BARWON HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3227, 'BREAMLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3227, 'CONNEWARRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3228, 'BELLBRAE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3228, 'JAN JUC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3228, 'TORQUAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3230, 'ANGLESEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3231, 'AIREYS INLET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3231, 'EASTERN VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3231, 'FAIRHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3231, 'MOGGS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3232, 'LORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3233, 'APOLLO BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3233, 'SKENES CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3235, 'DEANS MARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3236, 'FORREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3237, 'BEECH FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3237, 'GELLIBRAND LOWER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3238, 'HORDERN VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3238, 'JOHANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3238, 'LAVERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3239, 'CARLISLE RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3239, 'CHAPPLE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3239, 'GELLIBRAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3239, 'KENNEDYS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3240, 'BUCKLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3240, 'MODEWARRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3240, 'MORIAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3240, 'MOUNT MORIAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3241, 'BAMBRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3241, 'WINCHELSEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3241, 'WURDIBOLUC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3242, 'BIRREGURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3243, 'BARWON DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3243, 'GERANGAMETE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3243, 'WARNCOORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'ALVIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'BARONGAROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'BARRAMUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'CORAGULAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'CORUNNUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'DREEITE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'IRREWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'KAWARREN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'LARPENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'NALANGIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'ONDIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'PIRRON YALLOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'SWAN MARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'WARRION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'WOOL WOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3249, 'YEODENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3250, 'COLAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3250, 'ELLIMINYT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3251, 'BEEAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3251, 'CUNDARE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3251, 'WEERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3254, 'COROROOKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3260, 'BUNGADOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3260, 'CAMPERDOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3260, 'GNOTUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3260, 'POMBORNEIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3260, 'STONYFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3264, 'TERANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'BOORCAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'CUDGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'ELLERSLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'FRAMLINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'GARVOC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'KOLORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'NOORAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'PANMURE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3265, 'THE SISTERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3266, 'COBDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3266, 'GLENFYNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3266, 'JANCOURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3266, 'JANCOURT EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3266, 'SIMPSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3267, 'SCOTTS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3268, 'CURDIE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3268, 'CURDIES RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3268, 'NIRRANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3268, 'NULLAWARRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3268, 'TIMBOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3269, 'PORT CAMPBELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3269, 'PRINCETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3270, 'PETERBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3271, 'DARLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3271, 'DUNDONNELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3271, 'PURA PURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3272, 'MORTLAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3272, 'WOORNDOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3273, 'HEXHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3274, 'CARAMUT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3275, 'MAILER FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3276, 'WOOLSTHORPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3277, 'ALLANSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3277, 'MEPUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3277, 'NARINGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3278, 'PURNIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3279, 'WANGOOM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3280, 'DENNINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3280, 'WARRNAMBOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3281, 'BUSHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3281, 'GRASSMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3281, 'WINSLOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3281, 'WOODFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3282, 'ILLOWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3282, 'KOROIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3282, 'MALONES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3283, 'KILLARNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3283, 'KIRKSTALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3283, 'SOUTHERN CROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3283, 'TOWER HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3284, 'PORT FAIRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3285, 'NARRAWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3285, 'ROSEBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3285, 'ST HELENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3285, 'TOOLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3285, 'TYRENDARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3285, 'YAMBUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3286, 'MACARTHUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3287, 'HAWKESDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3287, 'MINHAMITE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3289, 'PENSHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3292, 'NELSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3293, 'GLENTHOMPSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3294, 'DUNKELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3294, 'MOUTAJUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3294, 'VICTORIA VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3300, 'HAMILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3301, 'BROADWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3301, 'BYADUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3301, 'STRATHKELLAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3301, 'TARRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3302, 'BRANXHOLME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3303, 'CONDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3304, 'DARTMOOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3304, 'HEYWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3304, 'WINNAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3305, 'ALLESTREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3305, 'BOLWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3305, 'GORAE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3305, 'PORTLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3309, 'DIGBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3310, 'MERINO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3311, 'CASTERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'CARAPOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'CHETWYND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'DERGHOLM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'HENTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'LAKE MUNDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'POOLAIJELO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'SANDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'STRATHDOWNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3312, 'WANDO VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3314, 'CAVENDISH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3315, 'COLERAINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3315, 'MELVILLE FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3315, 'NAREEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3317, 'HARROW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3318, 'EDENHOPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3318, 'LANGKOOP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3319, 'APSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3319, 'BENAYEO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3321, 'INVERLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3322, 'CRESSY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3323, 'BERRYBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3323, 'DUVERNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3324, 'LISMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3325, 'DERRINALLUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3328, 'TEESDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3329, 'BARUNAH PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3329, 'SHELFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3330, 'ROKEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3331, 'BANNOCKBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3331, 'GHERINGHAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3331, 'MAUDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3331, 'RUSSELLS BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3331, 'SHE OAKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3331, 'STEIGLITZ');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3331, 'SUTHERLANDS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3332, 'LETHBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3333, 'MEREDITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3334, 'ELAINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3334, 'MORRISONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3335, 'ROCKBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3337, 'KURUNJANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3337, 'MELTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3337, 'TOOLERN VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3338, 'BROOKFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3338, 'EXFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3338, 'MELTON SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3340, 'BACCHUS MARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3340, 'BALLIANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3340, 'COIMADAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3340, 'GLENMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3340, 'PARWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3340, 'ROWSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3341, 'GREENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3341, 'MYRNIONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3342, 'BALLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3342, 'BEREMBOKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3342, 'BLAKEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3342, 'MOUNT WALLACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3345, 'GORDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'ALFREDTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'BALLARAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'BALLARAT NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'BALLARAT WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'BLACK HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'BROWN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'CANADIAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'EUREKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'LAKE WENDOUREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'MOUNT CLEAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'MOUNT HELEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'MOUNT PLEASANT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'NERRINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'REDAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3350, 'SOVEREIGN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'BERRINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'CAPE CLEAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'CARNGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'CHEPSTOWE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'HADDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'HILLCREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'ILLABAROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'LAKE BOLAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'MININERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'NERRIN NERRIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'ROKEWOOD JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'ROSS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'SCARSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'SMYTHES CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'SMYTHESDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'SNAKE VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'STREATHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3351, 'WESTMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'ADDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'BLOWHARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'BOLWARRAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'BULLAROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'BUNGAREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'BURRUMBEET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'CAMBRIAN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'CARDIGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'CLARENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'CLARKES HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'CORINDHAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'DEAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'DEREEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'DUNNSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'DURHAM LEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'ENFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'INVERMAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'LAL LAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'LEARMONTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'LEIGH CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'LEXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'MAGPIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'MILLBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'MINERS REST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'MITCHELL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'MOLLONGGHIP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'MOUNT EGERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'MOUNT ROWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'NAPOLEONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'NAVIGATORS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'POOTILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'SCOTSBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'SPRINGBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'WALLACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'WARRENHEIP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'WAUBRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'WEATHERBOARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'WERNETH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'WINDERMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3352, 'YENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3353, 'BALLARAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3354, 'BAKERY HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3354, 'BALLARAT MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3355, 'MITCHELL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3355, 'WENDOUREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3355, 'WENDOUREE VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3356, 'DELACOMBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3356, 'SEBASTOPOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3357, 'BUNINYONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3360, 'LINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3361, 'CARRANBALLAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3361, 'SKIPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3363, 'CRESWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'ALLENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'ASCOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'BARKSTEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'BLAMPIED');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'BROOMFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'CAMPBELLTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'COGHILLS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'KINGSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'NEWLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'ROCKLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'SMEATON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3364, 'ULLINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3370, 'CLUNES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3371, 'EVANSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3371, 'STONY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3371, 'TALBOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3373, 'BEAUFORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3373, 'TRAWALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3375, 'BAYINDEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3375, 'BUANGOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3377, 'ARARAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3377, 'CROWLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3377, 'GREAT WESTERN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3377, 'MAROONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3377, 'MOYSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3377, 'WARRAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3378, 'TATYOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3379, 'CHATSWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3379, 'STAVELY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3379, 'WICKLIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3379, 'WILLAURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3380, 'STAWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3381, 'BARKLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3381, 'CAMPBELLS BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3381, 'HALLS GAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3381, 'LUBECK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3381, 'POMONAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3384, 'LANDSBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3384, 'NAVARRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3385, 'DADSWELLS BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3385, 'GLENORCHY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3387, 'MARNOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3388, 'BANYENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3388, 'RUPANYUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3390, 'MURTOA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3391, 'BRIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3392, 'MINYIP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3392, 'SHEEP HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3393, 'WARRACKNABEAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3395, 'BEULAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3396, 'HOPETOUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3399, 'JUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3400, 'HORSHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'DOOEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'DOUGLAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'GYMBOWEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'KARNAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'MITRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'NORADJUHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'QUANTONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'ROCKLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'TELANGATUK EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'TOOLONDO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'WALLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3401, 'WOMBELANO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3402, 'HORSHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3407, 'BALMORAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3407, 'GATUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3407, 'VASEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3409, 'NATIMUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3412, 'GOROKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3413, 'MINIMAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3413, 'OZENKADNOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3413, 'PERONNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3414, 'ANTWERP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3414, 'DIMBOOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3415, 'LILLIMUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3415, 'MIRAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3418, 'GERANG GERUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3418, 'KIATA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3418, 'LAWLOIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3418, 'NHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3418, 'YANAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3419, 'KANIVA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3420, 'SERVICETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3422, 'TARRANYURK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3423, 'JEPARIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3424, 'RAINBOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3424, 'YAAPEET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3427, 'DIGGERS REST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3428, 'BULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3429, 'SUNBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3430, 'CLARKEFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3431, 'RIDDELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3431, 'RIDDELLS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3432, 'BOLINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3434, 'KERRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3434, 'MONEGEETTA NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3434, 'ROMSEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3435, 'LANCEFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3437, 'BULLENGAROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3437, 'COUANGALT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3437, 'GISBORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3438, 'NEW GISBORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3440, 'MACEDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3441, 'MOUNT MACEDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3442, 'ASHBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3442, 'CARLSRUHE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3442, 'HESKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3442, 'NEWHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3442, 'ROCHFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3442, 'WOODEND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3444, 'KYNETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3444, 'MIA MIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3444, 'REDESDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3444, 'TYLDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3446, 'MALMSBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3447, 'TARADALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3448, 'ELPHINSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3448, 'METCALFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3448, 'SUTTON GRANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3450, 'CASTLEMAINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3451, 'BARKERS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3451, 'CAMPBELLS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3451, 'CHEWTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3451, 'FRYERSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3451, 'GUILDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3451, 'MUCKLEFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3453, 'HARCOURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3453, 'RAVENSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3458, 'BLACKWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3458, 'FERN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3458, 'NEWBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3458, 'TRENTHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3460, 'DAYLESFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'BULLARTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'DRUMMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'FRANKLINFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'GLENLYON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'HEPBURN SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'KORWEINGUBOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'LYONVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'MUSK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3461, 'YANDOIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3462, 'MUCKLEFORD SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3462, 'NEWSTEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3463, 'BARINGHUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3463, 'LAANECOORIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3463, 'MALDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3463, 'SHELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3463, 'WOODSTOCK WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3464, 'CARISBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3465, 'MAJORCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3465, 'MARYBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3465, 'NATTE YALLOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3465, 'RATHSCAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3465, 'WAREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3467, 'AVOCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3468, 'AMPHITHEATRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3468, 'MOUNT LONARCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3469, 'ELMHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3472, 'BET BET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3472, 'BETLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3472, 'DUNOLLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3472, 'EDDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3472, 'MOLIAGUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3475, 'BEALIBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3475, 'EMU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3475, 'LOGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3478, 'MOONAMBEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3478, 'REDBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3478, 'ST ARNAUD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3478, 'STUART MILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3480, 'AREEGRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3480, 'CORACK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3480, 'DONALD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3480, 'LITCHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3482, 'WATCHEM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3483, 'BIRCHIP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3485, 'WATCHUPGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3485, 'WOOMELANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3487, 'LASCELLES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3488, 'SPEED');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3489, 'TEMPY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3490, 'OUYEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3491, 'PATCHEWOLLOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3494, 'CARWARP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3494, 'COLIGNAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3494, 'NANGILOC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3496, 'CARDROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3496, 'CULLULLERAINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3496, 'MERINGUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3496, 'RED CLIFFS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3496, 'SUNNYCLIFFS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3496, 'WERRIMULL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3498, 'IRYMPLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3500, 'MILDURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 3500, 'PARINGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3501, 'KOORLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3501, 'MILDURA CENTRE PLAZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3501, 'NICHOLS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3502, 'MILDURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3505, 'CABARITA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3505, 'MERBEIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3506, 'COWANGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3507, 'WALPEUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3509, 'UNDERBOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3512, 'MURRAYVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3515, 'MARONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3516, 'BRIDGEWATER ON LODDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3516, 'DERBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3516, 'LEICHARDT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3517, 'INGLEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3517, 'JARKLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3517, 'SALISBURY WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3517, 'SERPENTINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3518, 'BERRIMAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3518, 'BORUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3518, 'FERNIHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3518, 'MYSIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3518, 'WEDDERBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3520, 'KORONG VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3521, 'PYALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3522, 'TOOBORAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3523, 'COSTERFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3523, 'HEATHCOTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3523, 'KNOWSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3525, 'CHARLTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3525, 'WYCHITELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3527, 'WYCHEPROOF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3529, 'NULLAWIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3530, 'CULGOA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3531, 'BERRIWILLOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3533, 'NANDALY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3533, 'SEA LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3537, 'BOORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3537, 'GREDGWIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3540, 'CANNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3540, 'QUAMBATOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3542, 'LALBERT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3544, 'ULTIMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3544, 'WAITCHIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3546, 'BOLTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3546, 'CHINKAPOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3546, 'MANANGATANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3549, 'ROBINVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'BENDIGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'KENNINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'LONG GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'NORTH BENDIGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'QUARRY HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'SANDHURST EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'SPRING GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'STRATHDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'TYSONS REEF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3550, 'WHITE HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'ARNOLD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'AXEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'EPPALOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'EPSOM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'HUNTLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'JUNORTOUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'LLANELLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'LONGLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'MAIDEN GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'MANDURANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'NEWBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'STRATHFIELDSAYE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'TARNAGULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3551, 'TOOLLEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3552, 'BENDIGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3554, 'BENDIGO DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3555, 'GOLDEN SQUARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3555, 'KANGAROO FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3556, 'CALIFORNIA GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3556, 'CAMPBELLS FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3556, 'COMET HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3556, 'EAGLEHAWK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3556, 'MYERS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3556, 'SEBASTIAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3557, 'BARNADOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3557, 'FOSTERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3557, 'GOORNONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3558, 'ELMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3558, 'HUNTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3559, 'COLBINABBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3559, 'COROP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3561, 'BAMAWM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3561, 'NANNEELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3561, 'ROCHESTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3562, 'TORRUMBARRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3563, 'LOCKINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3564, 'ECHUCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3564, 'KANYAPELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3564, 'PATHO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3564, 'SIMMIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3565, 'KOTTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3566, 'GUNBOWER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3567, 'LEITCHVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3567, 'MINCHA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3568, 'COHUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3570, 'RAYWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3571, 'DINGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3571, 'TANDARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3572, 'MILLOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3572, 'PIAVELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3572, 'PRAIRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3572, 'TENNYSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3573, 'CALIVIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3573, 'MITIAMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3575, 'MINCHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3575, 'PYRAMID HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3575, 'YARRAWALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3576, 'DURHAM OX');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3579, 'KERANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3579, 'MACORNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3579, 'MURRABIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3580, 'KOONDROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3581, 'LAKE CHARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3583, 'TRESCO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3584, 'LAKE BOGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3585, 'SWAN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3588, 'WOORINEN SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3589, 'WOORINEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3590, 'BEVERFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3591, 'VINIFERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3594, 'NYAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3595, 'NYAH WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3596, 'WOOD WOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3597, 'PIANGIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3599, 'BOUNDARY BEND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3607, 'TABILK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3608, 'BAILIESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3608, 'DARGALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3608, 'GOULBURN WEIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3608, 'GRAYTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3608, 'NAGAMBIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3608, 'WAHRING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3610, 'DHURRINGILE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3610, 'MURCHISON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3612, 'MATHIESONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3612, 'RUSHWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3612, 'WANALTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3614, 'TOOLAMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3616, 'COOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3616, 'GILLIESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3616, 'HARSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3616, 'TATURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3616, 'TOOLAMBA EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3617, 'BYRNESIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3618, 'MERRIGUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3619, 'KYABRAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3620, 'KYABRAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3620, 'LANCASTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3620, 'PEDERICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3620, 'WYUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3621, 'KOYUGA SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3621, 'TONGALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3621, 'YAMBUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3622, 'KOYUGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3622, 'STRATHALLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3623, 'STANHOPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3624, 'GIRGARRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3629, 'ARDMONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3629, 'COOMBOONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3629, 'MOOROOPNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3629, 'UNDERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3630, 'BENARCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3630, 'BRANDITT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3630, 'CANIAMBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3630, 'COLLIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3630, 'DUNKIRK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3630, 'SHEPPARTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'ARCADIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'COSGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'KIALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'KIALLA EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'KIALLA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'LEMNOS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'PINE LODGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'SHEPPARTON EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3631, 'TAMLEUGH WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3632, 'SHEPPARTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3633, 'CONGUPNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3634, 'BUNBARTHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3634, 'INVERGORDON SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3634, 'KATANDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3634, 'MARUNGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3634, 'TALLYGAROOPNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3635, 'WUNGHNU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3636, 'DUNBULBALANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3636, 'INVERGORDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3636, 'NUMURKAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3637, 'WAAIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3638, 'KOTUPNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3638, 'NATHALIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3639, 'BARMAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3639, 'PICOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3640, 'KATUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3641, 'STRATHMERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3643, 'COBRAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='NSW'), 3644, 'BAROOGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3644, 'COBRAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3644, 'YARROWEYAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3646, 'DOOKIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3646, 'KATANDRA NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3646, 'YABBA NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3646, 'YOUANMITE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3647, 'DOOKIE COLLEGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3649, 'KATAMATITE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3658, 'BROADFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3658, 'CLONBINANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3658, 'HAZELDENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3658, 'KING PARROT CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3658, 'PETERSONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3658, 'REEDY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3658, 'STRATH CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3659, 'TALLAROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3660, 'KERRISDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3660, 'SEYMOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3660, 'TRAWOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3661, 'SEYMOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3662, 'PUCKAPUNYAL MILPO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3663, 'MANGALORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3664, 'AVENEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3665, 'LOCKSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3665, 'LONGWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3666, 'BALMATTUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3666, 'CREIGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3666, 'EUROA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3666, 'GOORAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3666, 'KITHBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3666, 'RUFFY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3666, 'SEVEN CREEKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3666, 'STRATHBOGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3669, 'BOHO SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3669, 'CREEK JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3669, 'GOWANGARDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3669, 'KOONDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3669, 'STRATHBOGIE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3669, 'TAMLEUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3669, 'VIOLET TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3670, 'BADDAGINNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3670, 'WARRENBAYNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3671, 'BENALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3672, 'BENALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3673, 'BENALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3673, 'LIMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3673, 'MOLYULLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3673, 'SWANPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3673, 'TATONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3673, 'WINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3675, 'GLENROWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3675, 'GRETA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3675, 'HANSONVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3676, 'WANGARATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3677, 'APPIN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3677, 'MURDOCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3677, 'WANGARATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3677, 'YARRUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3678, 'BOORHAMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3678, 'CHESHUNT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3678, 'EVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3678, 'MILAWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3678, 'OXLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3682, 'NORONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3682, 'SPRINGHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3683, 'CHILTERN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3685, 'BOORHAMAN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3685, 'BROWNS PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3685, 'GOORAMADDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3685, 'PRENTICE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3685, 'RUTHERGLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3687, 'WAHGUNYAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3688, 'BARNAWARTHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3688, 'WOORAGEE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3689, 'WODONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3690, 'WODONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3690, 'WODONGA PLAZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'ALLANS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'BARANDUDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'BELLBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'BERRINGAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'BETHANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'BONEGILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'DEDERANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'EBDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'GLEN CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'GUNDOWRING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'HUME WEIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'KERGUNYAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'KIEWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'LENEVA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'LONE PINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'MOUNT ALFRED');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'STAGHORN FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'TALGARNO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3691, 'TANGAMBALANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3694, 'BANDIANA MILPO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3695, 'CHARLEROI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3695, 'HUON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3695, 'RED BLUFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3695, 'SANDY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3697, 'TAWONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3698, 'TAWONGA SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3699, 'BOGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3699, 'FALLS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3699, 'MOUNT BEAUTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3700, 'MULLINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3700, 'TALLANDOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3700, 'TALLANGATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3701, 'DARTMOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3701, 'ESKDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3701, 'GRANYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3701, 'MITTA MITTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3701, 'SHELLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3704, 'KOETONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3705, 'CUDGEWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3705, 'NARIEL VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3707, 'BIGGARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3707, 'COLAC COLAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3707, 'CORRYONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3707, 'THOWGLA VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3707, 'TOWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3708, 'TINTALDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3708, 'WALWA EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3709, 'BURROWYE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3709, 'GUYS FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3709, 'WALWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3711, 'BUXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3712, 'RUBICON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3712, 'THORNTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3713, 'EILDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3714, 'ACHERON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3714, 'ALEXANDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3714, 'CATHKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3714, 'KORIELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3714, 'TAGGERTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3715, 'ANCONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3715, 'MERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3715, 'WOODFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3717, 'FLOWERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3717, 'GLENBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3717, 'HOMEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3717, 'MURRINDINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3717, 'YEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3718, 'MOLESWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3719, 'GOBUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3719, 'KANUMBRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3719, 'YARCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3720, 'BONNIE DOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3722, 'MANSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3722, 'MIRIMBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3723, 'A1 MINE SETTLEMENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3723, 'GOUGHS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3723, 'JAMIESON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3723, 'MATLOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3723, 'MERRIJIG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3723, 'MOUNT BULLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3723, 'WOODS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3724, 'MANSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3725, 'BOXWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3725, 'GOORAMBAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3726, 'BUNGEET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3726, 'DEVENISH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3726, 'THOONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3727, 'LAKE ROWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3727, 'ST JAMES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3727, 'YUNDOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3728, 'TUNGAMAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3728, 'WILBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3730, 'BUNDALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3730, 'TELFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3730, 'YARRAWONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3732, 'MOYHU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3733, 'WHITFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3733, 'WHITLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3735, 'BOWMANS FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3735, 'WHOROULY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3736, 'MYRTLEFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3737, 'BUFFALO RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3737, 'DANDONGADALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3737, 'GAPSTED');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3737, 'MUDGEGONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3737, 'MYRTLEFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3738, 'OVENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3739, 'EUROBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3740, 'MOUNT BUFFALO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3740, 'POREPUNKAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3741, 'BRIGHT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3741, 'FREEBURGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3741, 'HARRIETVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3741, 'HOTHAM HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3741, 'MOUNT HOTHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3744, 'WANDILIGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3746, 'ELDORADO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3747, 'BAARMUTHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3747, 'BEECHWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3747, 'MURMUNGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3747, 'STANLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3747, 'WOORAGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3749, 'BRUARONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3749, 'YACKANDANDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3750, 'WOLLERT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3751, 'WOODSTOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3752, 'SOUTH MORANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3753, 'BEVERIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3754, 'DOREEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3754, 'MERNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3754, 'YAN YEAN SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3755, 'YAN YEAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3756, 'DARRAWEIT GUIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3756, 'UPPER PLENTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3756, 'WALLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3757, 'EDEN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3757, 'GLENVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3757, 'HUMEVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3757, 'KINGLAKE WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3757, 'PHEASANT CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3757, 'WHITTLESEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3758, 'HEATHCOTE JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3758, 'WANDONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3759, 'PANTON HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3760, 'SMITHS GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3761, 'ST ANDREWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3762, 'BYLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3763, 'KINGLAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3764, 'KILMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3765, 'MONTROSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3766, 'KALORAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3767, 'MOUNT DANDENONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3770, 'COLDSTREAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3770, 'GRUYERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3775, 'CHRISTMAS HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3775, 'DIXONS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3775, 'STEELS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3775, 'YARRA GLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3777, 'HEALESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3777, 'TOOLANGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3778, 'NARBETHONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3779, 'MARYSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3781, 'COCKATOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3782, 'AVONSLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3782, 'CLEMATIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3782, 'EMERALD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3782, 'MACCLESFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3783, 'GEMBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3786, 'FERNY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3787, 'SASSAFRAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3787, 'SASSAFRAS GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3788, 'OLINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3789, 'SHERBROOKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3791, 'KALLISTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3792, 'THE PATCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3793, 'MONBULK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3795, 'SILVAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3796, 'MOUNT EVELYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3797, 'GILDEROY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3797, 'GLADYSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3797, 'POWELLTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3797, 'THREE BRIDGES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3797, 'YARRA JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3799, 'MCMAHONS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3799, 'MILLGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3799, 'WARBURTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3799, 'WESBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3802, 'ENDEAVOUR HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3803, 'HALLAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3804, 'NARRE WARREN EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3804, 'NARRE WARREN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3805, 'FOUNTAIN GATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3805, 'NARRE WARREN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3806, 'BERWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3806, 'HARKAWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3807, 'BEACONSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3807, 'GUYS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3808, 'BEACONSFIELD UPPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3809, 'OFFICER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3810, 'PAKENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3810, 'PAKENHAM UPPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3812, 'MARYKNOLL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3812, 'NAR NAR GOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3813, 'TYNONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3814, 'CORA LYNN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3814, 'GARFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3814, 'VERVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3815, 'BUNYIP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3815, 'IONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3815, 'TONIMBUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3816, 'LABERTOUCHE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3816, 'LONGWARRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3816, 'MODELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3818, 'ATHLONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3818, 'DROUIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3818, 'RIPPLEBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3820, 'WARRAGUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3821, 'BULN BULN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3821, 'NEERIM JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3821, 'NEERIM NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3821, 'NILMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3821, 'ROKEBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3822, 'DARNUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3823, 'YARRAGON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3824, 'CHILDERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3824, 'THORPDALE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3824, 'TRAFALGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3824, 'YULUNGAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'ABERFELDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'COALVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'ERICA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'HERNES OAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'HILL END');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'MOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'MOONDARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'NEWBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'PARKERS CORNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'RAWSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'TANJIL SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'WALHALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'WILLOW GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3825, 'YALLOURN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3831, 'NEERIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3831, 'NEERIM SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3833, 'NOOJEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3835, 'THORPDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3840, 'JEERALANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3840, 'MID VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3840, 'MORWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3841, 'MORWELL MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3842, 'CHURCHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3844, 'CALLIGNEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3844, 'CARRAJUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3844, 'FLYNN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3844, 'KOORNALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3844, 'TRARALGON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3844, 'TYERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3844, 'WILLUNG SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3847, 'NAMBROK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3847, 'ROSEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3847, 'WILLUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3850, 'GUTHRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3850, 'SALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3850, 'WURRUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3851, 'BUNDALAGUAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3851, 'DARRIMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3851, 'KILMANY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3851, 'LOCH SPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3851, 'LONGFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3851, 'MYRTLEBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3851, 'PARADISE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3851, 'SEASPRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3852, 'EAST SALE RAAF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3853, 'SALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3854, 'GLENGARRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3856, 'TOONGABBIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3857, 'COWWARR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3858, 'GLENMAGGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3858, 'HEYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3858, 'LICOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3858, 'SEATON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3859, 'NEWRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3859, 'TINAMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3860, 'BOISDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3860, 'BRIAGOLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3860, 'MAFFRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3860, 'VALENCIA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3862, 'DARGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3862, 'MEERLIEU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3862, 'STRATFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3864, 'FERNBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3865, 'LINDENOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3869, 'JUMBUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3869, 'YINNAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3870, 'BOOLARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3870, 'MORWELL RIVER PRISON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3871, 'DARLIMURLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3871, 'MIRBOO NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3873, 'GORMANDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3874, 'CARRAJUNG SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3874, 'WOODSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'BAIRNSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'BENGWORDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'CALULU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'HILLSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'LINDENOW SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'LUCKNOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'MOUNT TAYLOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'NEWLANDS ARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'SARSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'WALPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3875, 'WY YUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3878, 'EAGLE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3880, 'PAYNESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3880, 'RAYMOND ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3882, 'NICHOLSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'BRUTHEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'BUCHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'BUTCHERS RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'GELANTIPY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'MOSSIFACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'TAMBO UPPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'W TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'WISELEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3885, 'WULGULMERANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3886, 'NEWMERELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3887, 'LAKE TYERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3887, 'NOWA NOWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3887, 'WAIREWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3888, 'BENDOC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3888, 'BONANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3888, 'MARLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3888, 'ORBOST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3888, 'TUBBUT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3889, 'BEMM RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3889, 'CABBAGE TREE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3889, 'CLUB TERRACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3889, 'COMBIENBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3889, 'SYDENHAM INLET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3890, 'CANN RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3890, 'NOORINBEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3891, 'GENOA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3891, 'GIPSY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3892, 'MALLACOOTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3893, 'TAMBO CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3895, 'ENSAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3896, 'SWIFTS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3898, 'DINNER PLAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3898, 'OMEO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3900, 'BENAMBRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3902, 'JOHNSONVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3903, 'SWAN REACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3904, 'METUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3909, 'KALIMNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3909, 'LAKE TYERS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3909, 'LAKES ENTRANCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3910, 'LANGWARRIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3911, 'BAXTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3912, 'PEARCEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3912, 'SOMERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3913, 'TYABB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3915, 'HASTINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3915, 'TUERONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3916, 'MERRICKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3916, 'SHOREHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3918, 'BITTERN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3919, 'CRIB POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3920, 'HMAS CERBERUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3921, 'TANKERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3922, 'COWES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3923, 'RHYLL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3925, 'CAPE WOOLAMAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3925, 'NEWHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3925, 'SAN REMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3926, 'BALNARRING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3926, 'MERRICKS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3926, 'MERRICKS NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3927, 'SOMERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3928, 'MAIN RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3929, 'FLINDERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3930, 'KUNYUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3930, 'MOUNT ELIZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3931, 'MORNINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3933, 'MOOROODUC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3934, 'MOUNT MARTHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3936, 'ARTHURS SEAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3936, 'DROMANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3936, 'SAFETY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3937, 'RED HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3937, 'RED HILL SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3938, 'MCCRAE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3939, 'ROSEBUD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3940, 'ROSEBUD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3941, 'RYE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3941, 'ST ANDREWS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3941, 'TOOTGAROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3942, 'BLAIRGOWRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3943, 'SORRENTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3944, 'PORTSEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3945, 'JEETHO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3945, 'KROWERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3945, 'LOCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3945, 'WOODLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3946, 'BENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3950, 'KORUMBURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3951, 'JUMBUNNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3951, 'KARDELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3951, 'KONGWAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3951, 'OUTTRIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3953, 'BERRYS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3953, 'HALLSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3953, 'LEONGATHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3953, 'NERRENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3954, 'KOONWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3956, 'DUMBALK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3956, 'MEENIYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3956, 'TARWIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3956, 'TARWIN LOWER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3956, 'VENUS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3956, 'WALKERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3956, 'WALKERVILLE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3957, 'STONY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3958, 'BUFFALO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3959, 'FISH CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3959, 'SANDY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3959, 'WARATAH BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3960, 'BENNISON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3960, 'FOSTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3960, 'MOUNT BEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3960, 'TIDAL RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3960, 'YANAKIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3962, 'AGNES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3962, 'BARRY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3962, 'TOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3964, 'PORT FRANKLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3965, 'PORT WELSHPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3966, 'BINGINWARRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3966, 'WELSHPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3967, 'HEDLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'ALBERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'BALOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'DEVON NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'GELLIONDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'MACKS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'PORT ALBERT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'TARRAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'WON WRON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3971, 'YARRAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3975, 'LYNBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3975, 'LYNDHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3976, 'HAMPTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3977, 'CANNONS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3977, 'CRANBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3977, 'CRANBOURNE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3977, 'CRANBOURNE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3977, 'DEVON MEADOWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3977, 'FIVE WAYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3977, 'SKYE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3977, 'TOORADIN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3978, 'CARDINIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3978, 'CLYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3979, 'ALMURTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3979, 'GLEN ALVIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3979, 'KERNOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3980, 'BLIND BIGHT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3980, 'TOORADIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3980, 'WARNEET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3981, 'BAYLES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3981, 'CATANI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3981, 'DALMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3981, 'KOO WEE RUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3981, 'YANNATHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'CALDERMEADE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'CORINELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'CORONET BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'GRANTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'JAM JERRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'LANG LANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'MONOMEITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'TENBY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3984, 'THE GURDIES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3987, 'NYORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3988, 'POOWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3990, 'GLEN FORBES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3991, 'BASS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3992, 'DALYSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3995, 'ARCHIES CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3995, 'CAPE PATERSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3995, 'KILCUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3995, 'SOUTH DUDLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3995, 'WONTHAGGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3995, 'WOOLAMAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 3996, 'INVERLOCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4000, 'BRISBANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4000, 'BRISBANE ADELAIDE STREET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4000, 'BRISBANE-CITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4000, 'PARLIAMENT HOUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4000, 'PETRIE TERRACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4000, 'SPRING HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4001, 'BRISBANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4001, 'CENTRAL PLAZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4001, 'RIVERSIDE CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4001, 'WATERFRONT PLACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4002, 'BRISBANE ALBERT STREET BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4002, 'WINTERGARDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4003, 'GEORGE STREET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4004, 'SPRING HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4005, 'NEW FARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4005, 'TENERIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4006, 'BOWEN HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4006, 'BRISBANE EXHIBITION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4006, 'FORTITUDE VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4006, 'HERSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4006, 'NEWSTEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4007, 'ASCOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4007, 'BRISBANE AIRPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4007, 'DOOMBEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4007, 'HAMILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4007, 'WHINSTANES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4008, 'MEEANDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4008, 'PINKENBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4009, 'EAGLE FARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4010, 'ALBION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4010, 'BREAKFAST CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4011, 'CLAYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4011, 'EAGLE JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4011, 'HENDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4012, 'NUNDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4012, 'TOOMBUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4012, 'WAVELL HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4012, 'WAVELL HEIGHTS NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4013, 'NORTHGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4014, 'BANYO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4014, 'NUDGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4014, 'NUDGEE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4014, 'VIRGINIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4017, 'BRACKEN RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4017, 'BRIGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4017, 'DEAGON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4017, 'NASHVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4017, 'SANDGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4017, 'SHORNCLIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4018, 'FITZGIBBON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4018, 'TAIGUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4019, 'CLONTARF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4019, 'MARGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4019, 'MARGATE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4019, 'WOODY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4020, 'REDCLIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4020, 'SCARBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4021, 'KIPPA-RING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4022, 'ROTHWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4025, 'CAPE MORETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4025, 'COWAN COWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4025, 'KOORINGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4025, 'TANGALOOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4029, 'ROYAL BRISBANE HOSPITAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4030, 'KALINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4030, 'LUTWYCHE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4030, 'WINDSOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4030, 'WOOLOOWIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4031, 'GORDON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4031, 'KEDRON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4032, 'CHERMSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4032, 'CHERMSIDE WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4032, 'CRAIGSLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4034, 'ASPLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4034, 'BOONDALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4034, 'CARSELDINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4034, 'GEEBUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4034, 'ZILLMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4035, 'ALBANY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4035, 'BRIDGEMAN DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4036, 'BALD HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4037, 'EATONS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4051, 'ALDERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4051, 'ENOGGERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4051, 'GAYTHORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4051, 'GRANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4051, 'NEWMARKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4051, 'WILSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4053, 'BROOKSIDE CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4053, 'EVERTON HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4053, 'EVERTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4053, 'MCDOWALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4053, 'MITCHELTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4053, 'OXFORD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4053, 'STAFFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4053, 'STAFFORD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4054, 'ARANA HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4054, 'GROVELY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4054, 'KEPERRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4055, 'BUNYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4055, 'FERNY GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4055, 'FERNY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4055, 'UPPER KEDRON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4059, 'ITHACA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4059, 'KELVIN GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4059, 'KELVIN GROVE BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4059, 'KELVIN GROVE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4059, 'NORMANBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4059, 'RED HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4060, 'ASHGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4060, 'DORRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4060, 'ST JOHNS WOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4061, 'THE GAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4064, 'MILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4064, 'PADDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4064, 'ROSALIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4065, 'BARDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4065, 'RAINWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4066, 'AUCHENFLOWER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4066, 'MOUNT COOT-THA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4066, 'TOOWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4066, 'TORWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4067, 'IRONSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4067, 'ST LUCIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4068, 'CHELMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4068, 'INDOOROOPILLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4068, 'LONG POCKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4068, 'TARINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4069, 'BROOKFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4069, 'CHAPEL HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4069, 'FIG TREE POCKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4069, 'KENMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4069, 'KENMORE HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4069, 'PINJARRA HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4069, 'PULLENVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4069, 'UPPER BROOKFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4070, 'ANSTEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4070, 'BELLBOWRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4070, 'MOGGILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4072, 'UNIVERSITY OF QUEENSLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4073, 'SEVENTEEN MILE ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4073, 'SINNAMON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4074, 'JAMBOREE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4074, 'JINDALEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4074, 'MIDDLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4074, 'MOUNT OMMANEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4074, 'RIVERHILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4074, 'SUMNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4074, 'SUMNER PARK BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4074, 'WESTLAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4075, 'CORINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4075, 'GRACEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4075, 'GRACEVILLE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4075, 'OXLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4075, 'SHERWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4076, 'DARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4076, 'WACOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4077, 'DOOLANDELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4077, 'DURACK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4077, 'INALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4077, 'RICHLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4078, 'ELLEN GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4078, 'FOREST LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4101, 'HIGHGATE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4101, 'HILL END');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4101, 'MATER HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4101, 'MATER HOSPITAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4101, 'SOUTH BANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4101, 'SOUTH BRISBANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4101, 'WEST END');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4102, 'BURANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4102, 'DUTTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4102, 'PRINCESS ALEXANDRA HOSPITAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4102, 'WOOLLOONGABBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4103, 'ANNERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4103, 'FAIRFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4104, 'YERONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4105, 'MOOROOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4105, 'TENNYSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4105, 'YEERONGPILLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4106, 'BRISBANE MARKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4106, 'ROCKLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4107, 'SALISBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4108, 'ARCHERFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4108, 'COOPERS PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4109, 'MACGREGOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4109, 'ROBERTSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4109, 'SUNNYBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4109, 'SUNNYBANK HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4110, 'ACACIA RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4110, 'ACACIA RIDGE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4110, 'HEATHWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4110, 'LARAPINTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4110, 'PALLARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4110, 'WILLAWONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4111, 'GRIFFITH UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4111, 'NATHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4112, 'KURABY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4113, 'EIGHT MILE PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4113, 'FRUITGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4113, 'RUNCORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4114, 'KINGSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4114, 'LOGAN CENTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4114, 'LOGAN CITY DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4114, 'WOODRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4115, 'ALGESTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4115, 'PARKINSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4116, 'CALAMVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4116, 'DREWVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4116, 'STRETTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4117, 'BERRINBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4117, 'KARAWATHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4118, 'BROWNS PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4118, 'FORESTDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4118, 'HERITAGE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4118, 'HILLCREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4118, 'REGENTS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4119, 'UNDERWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4120, 'GREENSLOPES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4120, 'STONES CORNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4121, 'EKIBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4121, 'HOLLAND PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4121, 'HOLLAND PARK WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4121, 'TARRAGINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4121, 'WELLERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4122, 'MANSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4122, 'MOUNT GRAVATT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4122, 'MOUNT GRAVATT EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4122, 'UPPER MOUNT GRAVATT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4122, 'WISHART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4123, 'ROCHEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4123, 'ROCHEDALE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4124, 'BORONIA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4124, 'GREENBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4125, 'MUNRUBEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4125, 'PARK RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4127, 'CHATSWOOD HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4127, 'DAISY HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4127, 'PRIESTDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4127, 'SLACKS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4127, 'SPRINGWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4128, 'KIMBERLEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4128, 'SHAILER PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4128, 'TANAH MERAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4129, 'LOGANDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4129, 'LOGANHOLME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4130, 'CARBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4130, 'CORNUBIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4131, 'LOGANLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4131, 'MEADOWBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4132, 'CRESTMEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4132, 'MARSDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4133, 'CHAMBERS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4133, 'LOGAN RESERVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4133, 'WATERFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4133, 'WATERFORD WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4151, 'COORPAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4152, 'CAMP HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4152, 'CARINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4152, 'CARINA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4152, 'CARINDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4153, 'BELMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4154, 'GUMDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4154, 'RANSOME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4154, 'WAKERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4155, 'CHANDLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4156, 'BURBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4156, 'MACKENZIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4157, 'CAPALABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4157, 'CAPALABA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4157, 'SHELDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4158, 'THORNESIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4159, 'AQUATIC PARADISE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4159, 'BIRKDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4160, 'ORMISTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4160, 'WELLINGTON POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4161, 'ALEXANDRA HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4161, 'BURWOOD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4163, 'CLEVELAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4163, 'RABY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4164, 'PINKLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4164, 'THORNLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4165, 'MOUNT COTTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4165, 'POINT HALLORAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4165, 'POINT TALBURPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4165, 'REDLAND BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4165, 'VICTORIA POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4169, 'EAST BRISBANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4169, 'KANGAROO POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4170, 'CANNON HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4170, 'COLMSLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4170, 'MORNINGSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4170, 'NORMAN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4170, 'SEVEN HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4171, 'BALMORAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4171, 'BULIMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4171, 'GALLOWAYS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4171, 'HAWTHORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4172, 'MURARRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4173, 'TINGALPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4173, 'TINGALPA BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4173, 'TINGALPA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4174, 'HEMMANT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4178, 'LINDUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4178, 'LYTTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4178, 'WYNNUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4178, 'WYNNUM WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4179, 'LOTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4179, 'MANLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4179, 'MANLY WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4183, 'AMITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4183, 'AMITY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4183, 'DUNWICH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4183, 'POINT LOOKOUT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4184, 'COOCHIEMUDLO ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4184, 'KARRAGARRA ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4184, 'LAMB ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4184, 'MACLEAY ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4184, 'PEEL ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4184, 'RUSSELL ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4205, 'BETHANIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'ALBERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'BAHRS SCRUB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'BANNOCKBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'BEENLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'BELIVAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'BUCCAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'CEDAR CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'EAGLEBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'EDENS LANDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'HOLMVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'LOGAN VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'LUSCOMBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'MOUNT WARREN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'STAPYLTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'STEIGLITZ');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'WINDAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'WOLFFDENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'WOONGOOLBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4207, 'YATALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4208, 'GILBERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4208, 'JACOBS WELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4208, 'KINGSHOLME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4208, 'NORWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4208, 'ORMEAU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4209, 'CANOWINDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4209, 'COOMERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4209, 'PIMPAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4209, 'UPPER COOMERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4209, 'WILLOW VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4210, 'GUANABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4210, 'MAUDSLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4210, 'OXENFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4210, 'STUDIO VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4210, 'WONGAWALLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'ADVANCETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'BEECHMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'CARRARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'CLAGIRABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'GAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'GILSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'LATIMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'MOUNT NATHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'NATURAL BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'NERANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'NUMINBAH VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4211, 'PACIFIC PINES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4212, 'BOYKAMBIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4212, 'HELENSVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4212, 'HOPE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4212, 'SANCTUARY COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4212, 'SANTA BARBARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4213, 'AUSTINVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4213, 'BONOGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4213, 'MUDGEERABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4213, 'NERANWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4213, 'SPRINGBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4213, 'TALLAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4213, 'WORONGARY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4214, 'ARUNDEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4214, 'ARUNDEL BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4214, 'ARUNDEL DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4214, 'ASHMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4214, 'ERNEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4214, 'MOLENDINAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4214, 'PARKWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4215, 'CHIRN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4215, 'LABRADOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4215, 'SOUTHPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4216, 'ANGLERS PARADISE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4216, 'BIGGERA WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4216, 'COOMBABAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4216, 'HOLLYWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4216, 'PARADISE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4216, 'PARADISE POINT KEYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4216, 'RUNAWAY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4216, 'SOVEREIGN ISLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'BENOWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'BUNDALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'CHEVRON ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'ISLE OF CAPRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'MAIN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'PARADISE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'PARADISE WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'SORRENTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'SURFERS PARADISE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4217, 'THE SPIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'BROADBEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'BROADBEACH WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'CYPRESS GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'FLORIDA GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'MERMAID BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'MERMAID WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'MIAMI KEYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'NOBBY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'PACIFIC FAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'Q SUPERCENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4218, 'RIO VISTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4219, 'WEST BURLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4220, 'ANDREWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4220, 'BURLEIGH HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4220, 'BURLEIGH TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4220, 'BURLEIGH WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4220, 'MIAMI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4221, 'ELANORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4221, 'PALM BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4223, 'CURRUMBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4223, 'CURRUMBIN DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4223, 'CURRUMBIN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4223, 'CURRUMBIN WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4224, 'TUGUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4225, 'BILINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4225, 'COOLANGATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4225, 'GREENMOUNT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4225, 'KIRRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4225, 'RAINBOW BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4226, 'CLEAR ISLAND WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4226, 'KERRYDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4226, 'MERRIMAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4226, 'ROBINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4227, 'STEPHENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4228, 'REEDY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4228, 'TALLEBUDGERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4228, 'TALLEBUDGERA VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4229, 'BOND UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4230, 'ROBINA TOWN CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4270, 'TAMBORINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4270, 'TAMBORINE VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4271, 'EAGLE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4272, 'MOUNT TAMBORINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4272, 'NORTH TAMBORINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4275, 'CANUNGRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4275, 'LAMINGTON NATIONAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4275, 'WITHEREN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4275, 'WONGLEPONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4280, 'JIMBOOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4280, 'MACLEAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4285, 'BEAUDESERT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4285, 'CEDAR VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4285, 'KOORALBYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4287, 'PALEN CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4287, 'RATHDOWNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4300, 'BELLBIRD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4300, 'CAMIRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4300, 'CAROLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4300, 'GAILES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4300, 'GOODNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4300, 'OPOSSUM CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4300, 'SPRINGFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4300, 'SPRINGFIELD LAKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4301, 'COLLINGWOOD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4301, 'REDBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4301, 'REDBANK PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4303, 'DINMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4303, 'NEW CHUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4303, 'RIVERVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4304, 'BLACKSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4304, 'BOOVAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4304, 'BUNDAMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4304, 'EBBW VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4304, 'NORTH BOOVAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4304, 'SILKSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'BASIN POCKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'BRASSALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'BREMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'CHURCHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'COALFALLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'EAST IPSWICH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'EASTERN HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'FLINDERS VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'IPSWICH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'LEICHHARDT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'LIMESTONE RIDGES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'MOORES POCKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'NEWTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'NORTH IPSWICH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'NORTH TIVOLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'ONE MILE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'RACEVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'RAYMONDS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'SADLIERS CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'TIVOLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'WEST IPSWICH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'WOODEND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'WULKURAKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4305, 'YAMANTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'AMBERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'AVOCA VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BANKS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BARELLAN POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BENARKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BENARKIN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BLACKBUTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BLACKBUTT NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BLACKBUTT SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BLACKSOIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BLACKWALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'BORALLON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'CHERRY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'CHUWAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'COLINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'DEEBING HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'FAIRNEY VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'FERNVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'GOOGA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'GOOLMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'HAIGSLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'HARLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'HOLTS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'IRONBARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'KARALEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'KARANA DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'LAKE MANCHESTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'LINVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'MONSILDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'MOORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'MOUNT BINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'MOUNT CROSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'MOUNT STANLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'MUIRLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'NUKKU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'PEAK CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'PINE MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'RIPLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'SOUTH RIPLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'TEELAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'THAGOONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'WALLOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4306, 'WILLOWBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4307, 'HARRISVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4309, 'ARATULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4309, 'FRAZERVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4309, 'KALBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4309, 'WASHPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4310, 'BOONAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4310, 'ROADVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4311, 'BUARABA SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4311, 'CHURCHABLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4311, 'COOMINYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4311, 'LOCKYER WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4311, 'LOWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4311, 'MINDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4311, 'PATRICK ESTATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4311, 'WIVENHOE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'BRYDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'CABOONBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'CROSSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'ESK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'GLEN ESK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'MOOMBRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'MOUNT BYRON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'REDBANK CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4312, 'SOMERSET DAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4313, 'BRAEMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4313, 'COOEEIMBARDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4313, 'FULHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4313, 'LOWER CRESSBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4313, 'OTTABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4313, 'SCRUB CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4313, 'TOOGOOLAWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4313, 'YIMBUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4340, 'GRANDCHESTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4340, 'LANEFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4340, 'LOWER MOUNT WALKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4340, 'MERRYVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4340, 'MOUNT WALKER WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4340, 'ROSEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4340, 'THE BLUFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4341, 'KENSINGTON GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4341, 'LAIDLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4341, 'LAIDLEY CREEK WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4341, 'LAIDLEY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4341, 'LAIDLEY NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4341, 'PLAINLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4341, 'TOWNSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4342, 'FOREST HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4342, 'GLEN CAIRN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4342, 'GLENORE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4342, 'LYNFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'ADARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'BLACK DUCK CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'CAFFEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'COLLEGE VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'EAST HALDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'FORDSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'GATTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'INGOLDSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'JUNCTION VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'LAKE CLARENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'LAWES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'LEFTHAND BRANCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'LOWER TENTHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'MORTON VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'MOUNT SYLVIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'PLACID HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'RINGWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'ROCKSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'ROPELEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'SPRING CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'UPPER TENTHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'VINEGAR HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'WOODBINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4343, 'WOODLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'CARPENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'EGYPT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'FLAGSTONE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'HELIDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'HELIDON SPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'LILYDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'LOCKYER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'ROCKMOUNT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'SEVENTEEN MILE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'SILVER PINCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'SILVER RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'STOCKYARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4344, 'UPPER FLAGSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4345, 'GATTON COLLEGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4346, 'MARBURG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4347, 'GRANTHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4347, 'MA MA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4347, 'MOUNT WHITESTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4347, 'VERADILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4347, 'WINWILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'ATHOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'CENTENARY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'CRANLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'DARLING HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'DRAYTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'EAST TOOWOOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'EASTLAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'FINNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'GLENVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'HARLAXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'HARRISTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'KEARNEYS SPRING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'MIDDLE RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'MOUNT KYNOCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'MOUNT LOFTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'MOUNT RASCAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'NEWTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'NORTH TOOWOOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'NORTHLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'PICNIC POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'PRINCE HENRY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'RANGEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'REDWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'ROCKVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'SOUTH TOOWOOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'SOUTHTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'TOOWOOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'TOOWOOMBA CITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'TOOWOOMBA EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'TOOWOOMBA SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'TOOWOOMBA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'TOP CAMP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'WELLCAMP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'WESTBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4350, 'WILSONTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'ACLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'AMIENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'BALLARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'BAPAUME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'BIRNAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'BLANCHVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'BRANCHVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'CABARLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'CEMENT MILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'DERRYMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'DJUAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'FIFTEEN MILE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'GEHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'GORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'GRAPE TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'GROOMSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'HIGHFIELDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'IREDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'KARARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'KLEINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'KULPI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'KURROWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'LYRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'MACLAGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'MERINGANDAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'MERRITTS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'MOUNT LUKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'MURPHYS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'OMAN AMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'PALM TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'PAMPAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'PECHEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'PERANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'PERSEVERANCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'POSTMANS RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'POZIERES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'PRESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'RAMSAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'RAVENSBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'SEVERNLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'SPRING BLUFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'ST AUBYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'THORNVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'TOOWOOMBA MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'TUMMAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'UMBIRAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'UPPER LOCKYER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'WHICHELLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'WHITE MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'WITHCOTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'WOOLMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'WYREEMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4352, 'YANDILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4353, 'HADEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4354, 'DOUGLAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4354, 'GOOMBUNGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4355, 'CROWS NEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4355, 'GLENHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4355, 'PIERCE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4355, 'THE BLUFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'BONGEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'BROXBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'EVANSLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'IRONGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'KINCORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'LINTHORPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'MOTLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'MOUNT TYSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'NORTH BRANCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'NORWIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'PITTSWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'PURRAWUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'ROSSVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'SCRUBBY MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'SPRINGSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'ST HELENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'STONELEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4356, 'YARRANLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4357, 'BRINGALILY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4357, 'KOOROONGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4357, 'MILLMERRAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4358, 'CAMBOOYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4359, 'GREENMOUNT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4359, 'WEST HALDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4360, 'NOBBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4361, 'CLIFTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4361, 'SPRING CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4362, 'ALLORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4362, 'GOOMBURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4363, 'SOUTHBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4364, 'BROOKSTEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4365, 'LEYBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4370, 'GLENNIE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4370, 'MARYVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4370, 'WARWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4371, 'EMU VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4371, 'YANGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4372, 'TANNYMOREL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4373, 'KILLARNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4374, 'DALVEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4375, 'COTTONVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4376, 'THULIMBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4377, 'THE SUMMIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4378, 'APPLETHORPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4380, 'STANTHORPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4381, 'GLEN APLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4382, 'BALLANDEAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4383, 'WALLANGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4384, 'LIMEVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4385, 'GLENARBON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4385, 'TEXAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4387, 'INGLEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4388, 'YELARBON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4390, 'GOONDIWINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4400, 'KINGSTHORPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4401, 'OAKEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4402, 'COOYAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4403, 'JONDARYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4403, 'QUINALOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4404, 'BOWENVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4404, 'IRVINGDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4405, 'DALBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4406, 'HANNAFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4406, 'JIMBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4406, 'KAIMKILLENBUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4406, 'KOGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4406, 'MACALISTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4406, 'MOONIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4406, 'THE GUMS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4407, 'CECIL PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4408, 'BELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4408, 'COORANGA NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4410, 'JANDOWAE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4411, 'WARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4412, 'BRIGALOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4413, 'CHINCHILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4413, 'HOPELAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4415, 'MILES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4416, 'CONDAMINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4417, 'SURAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4418, 'GULUGUBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4419, 'WANDOAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4420, 'SPRING CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4420, 'TAROOM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4421, 'TARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4422, 'MEANDARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4423, 'GLENMORGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4424, 'DRILLHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4425, 'DULACCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4426, 'JACKSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4427, 'YULEBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4428, 'WALLUMBILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4454, 'INJUNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4455, 'ANGELLALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4455, 'ROMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4461, 'MUCKADILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4462, 'AMBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4465, 'MITCHELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4467, 'MUNGALLALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4468, 'MORVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4470, 'CHARLEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4471, 'CLAVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4472, 'BLACKALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4474, 'ADAVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4475, 'CHEEPIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4477, 'AUGATHELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4478, 'TAMBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4479, 'COOLADDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4480, 'EROMANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4480, 'QUILPIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4481, 'WINDORAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4482, 'BIRDSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4486, 'DIRRANBANDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4486, 'HEBEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4487, 'ST GEORGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4488, 'BOLLON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4489, 'WYANDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4490, 'CUNNAMULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4490, 'YOWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4491, 'EULO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4492, 'THARGOMINDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4493, 'HUNGERFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4494, 'BUNGUNYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4496, 'TALWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4497, 'DAYMAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4497, 'THALLON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4498, 'TOOBEAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4500, 'BRAY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4500, 'BRENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4500, 'CASHMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4500, 'CLEAR MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4500, 'JOYNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4500, 'STRATHPINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4500, 'WARNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4501, 'LAWNTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4502, 'PETRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4503, 'DAKABIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4503, 'GRIFFIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4503, 'KALLANGUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4503, 'KURWONGBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4503, 'MURRUMBA DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4503, 'WHITESIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4504, 'NARANGBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4505, 'BURPENGARY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4506, 'MOORINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4506, 'MORAYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4507, 'BANKSIA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4507, 'BELLARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4507, 'BONGAREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4507, 'BRIBIE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4507, 'BRIBIE ISLAND DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4507, 'WELSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4507, 'WHITE PATCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4507, 'WOORIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4508, 'DECEPTION BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4509, 'MANGO HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4510, 'BEACHMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4510, 'CABOOLTURE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4510, 'DONNYBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4510, 'TOORBUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4511, 'GODWIN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4511, 'NINGI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4511, 'SANDSTONE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4511, 'TOORBUL POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4512, 'WAMURAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4514, 'D''AGUILAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4514, 'WOODFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4515, 'JIMNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4515, 'KILCOY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4516, 'ELIMBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4517, 'BEERBURRUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4518, 'GLASS HOUSE MOUNTAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4519, 'BEERWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'CAMP MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'CEDAR CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'CLOSEBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'DRAPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'ENOGGERA RESERVOIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'HIGHVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'MOUNT GLORIOUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'MOUNT NEBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'MOUNT SAMSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'SAMFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'SAMSONVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'WIGHTS MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4520, 'YUGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4521, 'DAYBORO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4521, 'KING SCRUB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4521, 'MOUNT MEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4521, 'MOUNT PLEASANT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4521, 'OCEAN VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4550, 'LANDSBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'AROONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'BATTERY HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'CALOUNDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'CALOUNDRA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'CURRIMUNDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'DICKY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'GOLDEN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'KINGS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'LITTLE MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'MOFFAT BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'PELICAN WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4551, 'SHELLY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4552, 'CONONDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4552, 'MALENY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4553, 'MOOLOOLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4553, 'PALMVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4554, 'EUDLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4554, 'ILKLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4555, 'PALMWOODS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4556, 'BUDERIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4556, 'KUNDA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4556, 'TANAWHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4557, 'MOOLOOLABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4557, 'MOUNTAIN CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4558, 'COTTON TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4558, 'MAROOCHYDORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4558, 'MAROOCHYDORE BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4558, 'SUNSHINE PLAZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4559, 'DIDDILLIBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4559, 'KIELS MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4559, 'WOOMBYE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4560, 'BLI BLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4560, 'DULONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4560, 'MAPLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4560, 'MONTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4560, 'NAMBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4560, 'PERWILLOWEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4561, 'MAROOCHY RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4561, 'YANDINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4562, 'EUMUNDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4563, 'COOROY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4563, 'COOROY MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4563, 'LAKE MACDONALD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4563, 'TINBEERWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4564, 'MARCOOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4564, 'MUDJIMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4564, 'PACIFIC PARADISE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4565, 'BOREEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4565, 'BOREEN POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4565, 'COOROIBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4565, 'NORTH SHORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4565, 'RINGTAIL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4565, 'TEWANTIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4566, 'NOOSAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4567, 'CASTAWAYS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4567, 'NOOSA HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4567, 'SUNRISE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4567, 'SUNSHINE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4568, 'FEDERAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4568, 'PINBARREN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4568, 'POMONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4569, 'COORAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'AMAMOOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'ANDERLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'ARALUEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'CORELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'GLANMIRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'GLEN ECHO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'GLENWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'GUNALDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'GYMPIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'IMBIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'JONES HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'KANDANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'KANIGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'KIA ORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'MIVA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'MONKLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'MUNNA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'PATERSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'SCOTCHY POCKET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'ST MARY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'TOOLARA FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4570, 'WOOLOOGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4571, 'KIN KIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4572, 'ALEXANDRA HEADLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4573, 'COOLUM BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4573, 'MARCUS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4573, 'MOUNT COOLUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4573, 'PEREGIAN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4573, 'YAROOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4574, 'KENILWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'BIRTINYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'BOKARINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'BUDDINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'KAWANA WATERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'MINYAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'PARREARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'WARANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'WARANA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4575, 'WURTULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4580, 'TIN CAN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4581, 'EURONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4581, 'RAINBOW BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4600, 'KILKIVAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4601, 'GOOMERI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4601, 'TANSEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4605, 'CHERBOURG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4605, 'CLOYNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4605, 'MURGON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4606, 'WONDAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4608, 'TINGOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4608, 'WOOROOLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'ALICE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'BENAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'BOOIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'BOYNESIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'CHAHPINGAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'COOLABUNIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'CORNDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'DANGORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'DURONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'DURONG SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'GOODGER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'GORDONBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'HALY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'INVERLAW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'IRONPOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'KINGAROY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'KUMBIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'MANNUEM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'TAABINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4610, 'WATTLE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4611, 'MONDURE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4612, 'HIVESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4613, 'ABBEYWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4613, 'PROSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4614, 'YARRAMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4615, 'MAIDENWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4615, 'NANANGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4615, 'TARONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4620, 'BROOWEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4620, 'GLENBAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4621, 'BIGGENDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4625, 'GAYNDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4626, 'MUNDUBBERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4627, 'ABERCORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4627, 'EIDSVOLD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4630, 'KALPOWAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4630, 'MONTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4630, 'MULGILDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'ANTIGUA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'BADDOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'BAUPLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'BAUPLE FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'BOONOOROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'DUNMORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'GOOTCHIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'GRANVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'GUNDIAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'MARYBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'MOUNT URAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'MUNGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'NETHERBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'OWANYILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'PILERWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'PIONEERS REST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'TALEGALLA WEIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'TEDDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'THINOOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'TIARO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'TINANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4650, 'TUAN FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'BOORAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'DUNDOWRAN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'HAPPY VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'HERVEY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'HERVEY BAY DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'KAWUNGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'KINGFISHER BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'NIKENBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'PIALBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'POINT VERNON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'SCARNESS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'TORQUAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'URANGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'URRAWEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'WALLIGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4655, 'WONDUNNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4659, 'BURRUM HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4659, 'HOWARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4660, 'ABINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4660, 'CHILDERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4660, 'CORDALBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4660, 'GOODWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4660, 'ISIS CENTRAL MILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4660, 'WOODGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4662, 'TORBANLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'ABBOTSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'ASHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'AVENELL HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'AVOCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'AVONDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BARGARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BRANYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BUNDABERG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BUNDABERG CENTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BUNDABERG DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BUNDABERG EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BUNDABERG NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BUNDABERG SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BUNDABERG WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'BURNETT HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'ELLIOTT HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'KALKIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'KENSINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'KEPNOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'MILLBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'MOORE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'NORVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'SHARON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'SOUTH KOLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'SVENSSON HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'THABEBAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'WALKERVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4670, 'WATALGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4671, 'BOOYAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4671, 'GIN GIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4671, 'MOUNT PERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4671, 'WALLAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4673, 'YANDARAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'BAFFLE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'BERAJONDO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'DEEPWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'EULEILAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'MOUNT MARIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'OYSTER CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'ROSEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'RULES BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4674, 'TAUNTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4676, 'GINDORAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4676, 'LOWMEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4677, 'AGNES WATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4677, 'CAPTAIN CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4677, 'COLOSSEUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4677, 'EURIMBULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4677, 'MIRIAM VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4677, 'MOUNT TOM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4677, 'SEVENTEEN SEVENTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4678, 'BOROREN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4678, 'FORESHORES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4678, 'RODDS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'BARNEY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'BENARABY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'BOYNE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'BUILYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'BYELLEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'CALLEMONDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'CALLIOPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'CLINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'GLADSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'GLEN EDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'HERON ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'HETHERINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'KIN KORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'KIRKWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'NEW AUCKLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'O''CONNELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'SOUTH GLADSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'SOUTH TREES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'SUN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'TANNUM SANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'TELINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'TOOLOOA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'UBOBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4680, 'WEST GLADSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4694, 'YARWUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4695, 'MOUNT LARCOM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4697, 'RAGLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4699, 'BAJOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4700, 'ALLENSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4700, 'GREAT KEPPEL ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4700, 'ROCKHAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4700, 'WANDAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4701, 'CENTRAL QUEENSLAND UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4701, 'FRENCHVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4701, 'KOONGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4701, 'NORTH ROCKHAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4701, 'PARK AVENUE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'AMBROSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'ANAKIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'BANANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'BARALABA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'BLUFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'BOULDERCOMBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'CENTRAL QUEENSLAND MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'COMET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'DINGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'DULULU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'GOGANGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'GOOVIGEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'GRACEMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'JAMBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'KALAPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'KEPPEL SANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'PARKHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'ROLLESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'RUBYVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'SAPPHIRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'STANAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'STANWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'WESTWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'WILLOWS GEMFIELDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'WOWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'WYCARBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'YALLEROI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4702, 'YARAKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4703, 'BAYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4703, 'BYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4703, 'COOEE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4703, 'LAMMERMOOR BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4703, 'STOCKYARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4703, 'TARANGANBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4703, 'YEPPOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4704, 'YAAMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4705, 'MARLBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4706, 'OGMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4707, 'ST LAWRENCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4709, 'TIERI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4710, 'EMU PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4710, 'ZILZIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4712, 'DUARINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4713, 'WOORABINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4714, 'MOUNT MORGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4715, 'BILOELA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4716, 'THANGOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4717, 'BLACKWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4718, 'MOURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4719, 'CRACOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4719, 'THEODORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4720, 'EMERALD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4721, 'CLERMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4722, 'SPRINGSURE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4723, 'CAPELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4724, 'ALPHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4725, 'BARCALDINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4726, 'ARAMAC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4727, 'ILFRACOMBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4728, 'JERICHO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4730, 'LONGREACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4730, 'MORELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4730, 'STONEHENGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4731, 'ISISFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4732, 'MUTTABURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4733, 'CORFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4735, 'WINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4736, 'JUNDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4737, 'ARMSTRONG BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4737, 'CAMPWIN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4737, 'FRESHWATER POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4737, 'SARINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4737, 'SARINA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4737, 'SARINA RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4738, 'KOUMALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4739, 'CARMILA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'ALEXANDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'ALLIGATOR CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'ANDERGROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'BAKERS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'BALNAGOWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'BEACONSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'BLACKS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'CAPE HILLSBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'CONINGSBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'DOLPHIN HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'DUNDULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'EAST MACKAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'EIMEO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'ERAKALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'GLENELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'GRASSTREE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'HABANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'HALF TIDE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'HAY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'HOMEBUSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'MACKAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'MOUNT PLEASANT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'NINDAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'NORTH MACKAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'OORALEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'PAGET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'PLANLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'RACECOURSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'ROSELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'RURAL VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'SALONIKA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'SLADE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'SOUTH MACKAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'TE KOWAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'THE LEAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'TIMBERLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4740, 'WEST MACKAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'BRAMPTON ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'DAYDREAM ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'ETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'FARLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'GARGETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'KUTTABUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'LINDEMAN ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'LONG ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'MACKAY MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'MOUNT OSSA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'PINNACLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'PLEYSTOWE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'SEAFORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4741, 'SOUTH MOLLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4742, 'NEBO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4743, 'GLENDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4744, 'MORANBAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4745, 'DYSART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4746, 'MAY DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4746, 'MIDDLEMOUNT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4750, 'BUCASIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4750, 'SHOAL POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4751, 'WALKERSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4753, 'MARIAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4754, 'MIRANI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4756, 'FINCH HATTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4756, 'NETHERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4757, 'DALRYMPLE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4798, 'CALEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4798, 'PINDI PINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4798, 'WAGOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4799, 'BLOOMSBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4800, 'CONWAY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4800, 'PRESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4800, 'PROSERPINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4800, 'WILSON BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4801, 'HAYMAN ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4802, 'AIRLIE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4802, 'CANNONVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4802, 'SHUTE HARBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4802, 'WHITSUNDAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4803, 'HAMILTON ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4804, 'COLLINSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4804, 'MOUNT COOLON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4804, 'MOUNT WYATT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4804, 'NEWLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4804, 'SPRINGLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4805, 'BOGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4805, 'BOWEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4805, 'GUTHALUNGRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4805, 'MERINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4805, 'QUEENS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4806, 'HOME HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4807, 'AYR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4807, 'CLAREDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4807, 'PARKSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4808, 'BRANDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4809, 'GIRU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'BELGIAN GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'CASTLE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'NORTH WARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'PALLARENDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'RAILWAY ESTATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'ROWES BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'SOUTH TOWNSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'TOWNSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4810, 'WEST END');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4811, 'CLUDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4811, 'IDALIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4811, 'JAMES COOK UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4811, 'OAK VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4811, 'OONOONBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4811, 'ROSENEATH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4811, 'STUART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4811, 'WULGURU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4812, 'CURRAJONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4812, 'GULLIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4812, 'HERMIT PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4812, 'HYDE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4812, 'MUNDINGBURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4812, 'MYSTERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4812, 'PIMLICO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4812, 'ROSSLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4813, 'LAVARACK BARRACKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4813, 'TOWNSVILLE MILPO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'AITKENVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'ANNANDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'CRANBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'DOUGLAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'GARBUTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'HEATLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'MOUNT LOUISA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'MURRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4814, 'VINCENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4815, 'CONDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4815, 'KELSO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4815, 'RASMUSSEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'ALLIGATOR CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'CUNGULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'DUNK ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'GREENVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'HIDDEN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'HOMESTEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'JULAGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'KENNEDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'MACROSSAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'MAXWELTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'MINGELA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'MUTARNEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'NELIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'NOME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'PALM ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'PALUMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'PENTLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'PRAIRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'RAVENSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'ROLLINGSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'SELLHEIM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'TORRENS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4816, 'WOODSTOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4817, 'ALICE RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4817, 'BOHLE PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4817, 'KIRWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4817, 'RUPERTSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4817, 'THURINGOWA CENTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'BLACK RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'BLUEWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'BLUEWATER PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'BOHLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'BUSHLAND BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'DEERAGUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'SAUNDERS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'TOOLAKEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4818, 'YABULU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4819, 'ARCADIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4819, 'HORSESHOE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4819, 'MAGNETIC ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4819, 'NELLY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4819, 'PICNIC BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4820, 'CHARTERS TOWERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4820, 'QUEENTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4820, 'RICHMOND HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4821, 'HUGHENDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4821, 'STAMFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4822, 'RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4823, 'JULIA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4823, 'KYNUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4823, 'MCKINLAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4824, 'CLONCURRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4824, 'OORINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'BREAKAWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'DAJARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'FISHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'HAPPY VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'HEALY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'MENZIES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'MICA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'MILES END');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'MOUNT ISA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'PARKSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'PIONEER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'RYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'SOLDIERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'SUNSET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'THE GAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'THE MONUMENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'TOWNVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4825, 'WINSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4828, 'CAMOOWEAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4829, 'BEDOURIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4829, 'BOULIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4830, 'BURKETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4830, 'DOOMADGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4849, 'CARDWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'ABERGOWRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'ALLINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'HALIFAX');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'INGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'LUCINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'MACKNADE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'TAYLORS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'UPPER STONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4850, 'VICTORIA ESTATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4852, 'BINGIL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4852, 'CLUMP POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4852, 'MISSION BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4852, 'SOUTH MISSION BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4852, 'WONGALING BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4854, 'CARDSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4854, 'EURAMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4854, 'MURRAY UPPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4854, 'TULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4855, 'EL ARISH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4856, 'SILKWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4857, 'SILKWOOD EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4858, 'MOURILYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4859, 'SOUTH JOHNSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4860, 'CULLINANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4860, 'FLYING FISH POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4860, 'GARRADUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4860, 'GOONDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4860, 'INNISFAIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4860, 'SUNDOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4861, 'BABINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4861, 'BARTLE FRERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4865, 'GORDONVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4868, 'BAYVIEW HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4868, 'TARRAWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4868, 'WHITE ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4868, 'WOREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4869, 'CENTENARY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4869, 'EDMONTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'AEROGLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'BRINSMEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'BUNGALOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'CAIRNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'CAIRNS NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'CAIRNS ORCHID PLAZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'EARLVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'EDGE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'FRESHWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'KAMERUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'KANIMBLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'MANOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'MANUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'MARTYNVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'MOOROOBOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'PARRAMATTA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'REDLYNCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'STRATFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'WESTCOURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4870, 'WHITFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'ALMADEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'ALOOMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'AURUKUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'BELLENDEN KER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'BOOGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'CHILLAGOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'COEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'COOKTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'COWLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'CROYDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'DEERAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'EDWARD RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'EINASLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'FISHERY FALLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'FORSAYTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'FOUR MILE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'GEORGETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'GLEN BOUGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'GREEN ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'GUNUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'HOPE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'JULATTEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'KIDSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'KOWANYAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'KURRIMINE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'LAURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'LOCKHART RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'MENA CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'MIRIWINNI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'MOUNT CARBINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'MOUNT MOLLOY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'MOUNT SURPRISE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'PORMPURAAW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'PORT DOUGLAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'WANGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'WANGETTI BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4871, 'YARRABAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'DIMBULAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'EVELYN CENTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'HERBERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'INNOT HOT SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'IRVINEBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'KAIRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'KURANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'MOUNT GARNET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'MUTCHILBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'RAVENSHOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'TUMOULIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'WALKAMIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4872, 'YUNGABURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4873, 'DAINTREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4873, 'MOSSMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4873, 'NEWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4873, 'WONGA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4874, 'WEIPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4875, 'BADU ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4875, 'THURSDAY ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4876, 'BAMAGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4878, 'CARAVONICA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4878, 'HOLLOWAYS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4878, 'LAKE PLACID');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4878, 'MACHANS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4878, 'SMITHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4878, 'SMITHFIELD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4878, 'YORKEYS KNOB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4879, 'CLIFTON BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4879, 'ELLIS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4879, 'KEWARRA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4879, 'PALM COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4879, 'TRINITY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4879, 'TRINITY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4880, 'MAREEBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4882, 'TOLGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4883, 'ATHERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4885, 'MALANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4886, 'MILLAA MILLAA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4890, 'NORMANTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 4891, 'KARUMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5000, 'ADELAIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5000, 'ADELAIDE BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5000, 'HALIFAX STREET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5000, 'HUTT STREET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5000, 'RUNDLE MALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5000, 'STATION ARCADE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5001, 'ADELAIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5005, 'ADELAIDE UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5005, 'THE UNIVERSITY OF ADELAIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5006, 'NORTH ADELAIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5007, 'BOWDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5007, 'BROMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5007, 'HINDMARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5007, 'WELLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5008, 'CROYDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5008, 'DEVON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5008, 'DUDLEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5008, 'RENOWN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5008, 'RIDLEYTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5009, 'ALLENBY GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5009, 'BEVERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5009, 'KILKENNY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5010, 'ANGLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5010, 'FERRYDEN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5010, 'REGENCY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5010, 'REGENCY PARK BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5011, 'WOODVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5012, 'ATHOL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5012, 'MANSFIELD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5012, 'WOODVILLE GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5012, 'WOODVILLE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5013, 'GILLMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5013, 'OTTOWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5013, 'PENNINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5013, 'ROSEWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5013, 'ROSEWATER EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5013, 'WINGFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5014, 'ALBERT PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5014, 'ALBERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5014, 'CHELTENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5014, 'HENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5014, 'QUEENSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5014, 'ROYAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5015, 'BIRKENHEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5015, 'ETHELTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5015, 'GLANVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5015, 'PORT ADELAIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5016, 'LARGS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5016, 'LARGS NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5016, 'PETERHEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5017, 'OSBORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5017, 'TAPEROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5018, 'NORTH HAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5018, 'OUTER HARBOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5019, 'EXETER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5019, 'SEMAPHORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5020, 'WEST LAKES SHORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5021, 'WEST LAKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5022, 'GRANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5022, 'HENLEY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5022, 'HENLEY BEACH SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5022, 'TENNYSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5023, 'FINDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5023, 'SEATON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5024, 'FULHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5024, 'FULHAM GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5024, 'WEST BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5025, 'FLINDERS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5025, 'KIDMAN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5031, 'MILE END');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5031, 'THEBARTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5031, 'TORRENSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5031, 'TORRENSVILLE PLAZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5032, 'BROOKLYN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5032, 'LOCKLEYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5032, 'UNDERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5033, 'COWANDILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5033, 'HILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5033, 'MARLESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5033, 'RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5033, 'WEST RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5034, 'CLARENCE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5034, 'GOODWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5034, 'KINGS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5034, 'MILLSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5034, 'WAYVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5035, 'ASHFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5035, 'BLACK FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5035, 'EVERARD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5035, 'FORESTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5035, 'KESWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5037, 'GLANDORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5037, 'KURRALTA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5037, 'NETLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5037, 'NORTH PLYMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5038, 'CAMDEN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5038, 'PLYMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5038, 'PLYMPTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5038, 'SOUTH PLYMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5039, 'CLARENCE GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5039, 'EDWARDSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5039, 'MELROSE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5040, 'NOVAR GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5041, 'COLONEL LIGHT GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5041, 'CUMBERLAND PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5041, 'DAW PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5041, 'PANORAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5041, 'WESTBOURNE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5042, 'BEDFORD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5042, 'CLOVELLY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5042, 'FLINDERS UNIVERSITY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5042, 'PASADENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5042, 'ST MARYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5043, 'ASCOT PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5043, 'MARION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5043, 'MITCHELL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5043, 'MORPHETTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5043, 'PARK HOLME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5044, 'GLENGOWRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5044, 'SOMERTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5045, 'GLENELG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5045, 'GLENELG SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5046, 'OAKLANDS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5046, 'WARRADALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5046, 'WARRADALE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5047, 'DARLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5047, 'SEACOMBE GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5047, 'SEACOMBE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5047, 'STURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5048, 'BRIGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5048, 'DOVER GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5048, 'HOVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5048, 'SOUTH BRIGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5049, 'KINGSTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5049, 'MARINO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5049, 'SEACLIFF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5049, 'SEACLIFF PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5049, 'SEAVIEW DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5050, 'BELLEVUE HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5050, 'EDEN HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5051, 'BLACKWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5051, 'COROMANDEL VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5051, 'CRAIGBURN FARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5051, 'HAWTHORNDENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5052, 'BELAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5052, 'GLENALTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5061, 'HYDE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5061, 'MALVERN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5061, 'UNLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'BROWN HILL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'CLAPHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'HAWTHORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'KINGSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'LOWER MITCHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'LYNTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'MITCHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'MITCHAM SHOPPING CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'NETHERBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'SPRINGFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5062, 'TORRENS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5063, 'EASTWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5063, 'FREWVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5063, 'FULLARTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5063, 'HIGHGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5063, 'PARKSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5064, 'GLEN OSMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5064, 'GLENUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5064, 'MOUNT OSMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5064, 'MYRTLE BANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5064, 'ST GEORGES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5064, 'URRBRAE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5065, 'DULWICH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5065, 'GLENSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5065, 'LINDEN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5065, 'TOORAK GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5065, 'TUSMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5066, 'BEAUMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5066, 'BURNSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5066, 'ERINDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5066, 'HAZELWOOD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5066, 'STONYFELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5066, 'WATERFALL GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5066, 'WATTLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5067, 'BEULAH PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5067, 'KENT TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5067, 'NORWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5067, 'NORWOOD SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5067, 'ROSE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5068, 'HEATHPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5068, 'KENSINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5068, 'KENSINGTON GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5068, 'KENSINGTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5068, 'LEABROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5068, 'MARRYATVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5068, 'ST MORRIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5068, 'TRINITY GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5069, 'COLLEGE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5069, 'EVANDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5069, 'HACKNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5069, 'MAYLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5069, 'ST PETERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5069, 'STEPNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5070, 'FELIXSTOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5070, 'FIRLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5070, 'GLYNDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5070, 'GLYNDE PLAZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5070, 'JOSLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5070, 'MARDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5070, 'PAYNEHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5070, 'ROYSTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5071, 'KENT TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5072, 'AULDANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5072, 'MAGILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5072, 'MAGILL NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5072, 'ROSSLYN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5072, 'SKYE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5072, 'TERINGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5072, 'WOODFORDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5073, 'HECTORVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5073, 'ROSTREVOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5073, 'TRANMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5073, 'TRANMERE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5074, 'CAMPBELLTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5074, 'NEWTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5075, 'DERNANCOURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5075, 'PARADISE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5076, 'ATHELSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5076, 'CASTAMBUL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5081, 'COLLINSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5081, 'GILBERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5081, 'MEDINDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5081, 'VALE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5081, 'WALKERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5082, 'FITZROY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5082, 'OVINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5082, 'PROSPECT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5082, 'PROSPECT EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5082, 'THORNGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5083, 'BROADVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5083, 'NAILSWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5083, 'SEFTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5084, 'BLAIR ATHOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5084, 'BLAIR ATHOL WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5084, 'KILBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5084, 'KILBURN NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5085, 'CLEARVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5085, 'ENFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5085, 'ENFIELD PLAZA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5085, 'NORTHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5085, 'NORTHGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5086, 'GILLES PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5086, 'GREENACRES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5086, 'HAMPSTEAD GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5086, 'HILLCREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5086, 'MANNINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5086, 'OAKDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5087, 'KLEMZIG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5087, 'WINDSOR GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5088, 'HOLDEN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5089, 'HIGHBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5090, 'HOPE VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5091, 'BANKSIA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5091, 'TEA TREE GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5091, 'VISTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5092, 'MODBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5092, 'MODBURY NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5093, 'PARA VISTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5093, 'VALLEY VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5094, 'CAVAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5094, 'DRY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5094, 'GEPPS CROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5095, 'MAWSON LAKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5095, 'POORAKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5095, 'THE LEVELS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5096, 'GULFVIEW HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5096, 'PARA HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5097, 'REDWOOD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5097, 'RIDGEHAVEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5097, 'ST AGNES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5098, 'INGLE FARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5098, 'WALKLEY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5106, 'PARAFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5106, 'SALISBURY SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5107, 'GREEN FIELDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5107, 'PARAFIELD GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5108, 'PARALOWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5108, 'SALISBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5108, 'SALISBURY DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5108, 'SALISBURY NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5109, 'BRAHMA LODGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5109, 'SALISBURY EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5109, 'SALISBURY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5109, 'SALISBURY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5109, 'SALISBURY PLAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5110, 'BOLIVAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5110, 'BURTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5110, 'DIREK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5110, 'GLOBE DERBY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5110, 'ST KILDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5110, 'WATERLOO CORNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5111, 'EDINBURGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5112, 'ELIZABETH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5112, 'ELIZABETH EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5112, 'ELIZABETH SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5112, 'ELIZABETH VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5112, 'HILLBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5113, 'DAVOREN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5113, 'ELIZABETH DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5113, 'ELIZABETH NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5113, 'ELIZABETH PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5113, 'ELIZABETH WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5114, 'ANDREWS FARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5114, 'BLAKEVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5114, 'CRAIGMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5114, 'ONE TREE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5114, 'SMITHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5114, 'SMITHFIELD PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5114, 'ULEYBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5115, 'KUDLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5115, 'MUNNO PARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5116, 'EVANSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5116, 'HILLIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5117, 'ANGLE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5118, 'BUCHFELDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5118, 'GAWLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5118, 'GAWLER BELT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5118, 'HEWETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5118, 'KALBEEBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5118, 'KINGSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5118, 'WILLASTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5120, 'BUCKLAND PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5120, 'VIRGINIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5121, 'MACDONALD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5121, 'PENFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5125, 'GOLDEN GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5125, 'GOLDEN GROVE VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5125, 'GREENWITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5126, 'FAIRVIEW PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5126, 'SURREY DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5126, 'YATALA VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5127, 'WYNN VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5131, 'HOUGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5131, 'LOWER HERMITAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5131, 'UPPER HERMITAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5132, 'PARACOMBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5133, 'INGLEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5134, 'CHERRYVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5134, 'MONTACUTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5136, 'NORTON SUMMIT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5137, 'ASHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5138, 'BASKET RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5139, 'FOREST RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5140, 'GREENHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5141, 'SUMMERTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5142, 'URAIDLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5144, 'CAREY GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5150, 'EAGLE ON THE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5150, 'LEAWOOD GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5151, 'PICCADILLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5152, 'CRAFERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5152, 'STIRLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'BIGGS FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'BRADBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'ECHUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'FLAXLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'HEATHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'IRONBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'LONGWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'MACCLESFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'MYLOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5153, 'SCOTT CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5154, 'ALDGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5155, 'BRIDGEWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5155, 'MOUNT GEORGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5156, 'UPPER STURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5157, 'ASHBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5157, 'CHERRY GARDENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5157, 'CLARENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5157, 'COROMANDEL EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5157, 'KANGARILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5158, 'HALLETT COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5158, 'O''HALLORAN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5158, 'SHEIDOW PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5158, 'TROTT PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5159, 'ABERFOYLE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5159, 'CHANDLERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5159, 'FLAGSTAFF HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5159, 'HAPPY VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5160, 'LONSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5161, 'REYNELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5162, 'MORPHETT VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5162, 'WOODCROFT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5163, 'HACKHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5163, 'HUNTFIELD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5163, 'ONKAPARINGA HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5164, 'CHRISTIE DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5165, 'CHRISTIES BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5165, 'CHRISTIES BEACH NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5166, 'O''SULLIVAN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5167, 'PORT NOARLUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5168, 'NOARLUNGA CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5168, 'NOARLUNGA DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5168, 'OLD NOARLUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5169, 'MOANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5169, 'SEAFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5169, 'SEAFORD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5169, 'SEAFORD MEADOWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5170, 'MASLIN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5171, 'MCLAREN FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5171, 'MCLAREN VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5171, 'PEDLER CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5172, 'WILLUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5173, 'ALDINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5173, 'ALDINGA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5173, 'PORT WILLUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5174, 'SELLICKS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5174, 'SELLICKS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5201, 'MEADOWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5202, 'MYPONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5203, 'YANKALILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5204, 'CARRICKALINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5204, 'DELAMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5204, 'NORMANVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5204, 'RAPID BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5204, 'SECOND VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5210, 'MOUNT COMPASS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5211, 'ENCOUNTER BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5211, 'HAYBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5211, 'INMAN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5211, 'MCCRACKEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5211, 'VICTOR HARBOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5212, 'PORT ELLIOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5213, 'MIDDLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5214, 'CURRENCY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5214, 'GOOLWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5220, 'PARNDANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5221, 'AMERICAN RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5222, 'PENNESHAW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5223, 'KINGSCOTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5231, 'KERSBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5232, 'CUDLEE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5233, 'GUMERACHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5234, 'BIRDWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5235, 'EDEN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5235, 'MOUNT PLEASANT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5235, 'SPRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5236, 'TUNGKILLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5237, 'PALMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5237, 'SANDERSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5238, 'BOWHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5238, 'MANNUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5238, 'NILDOTTIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5240, 'LENSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5241, 'LOBETHAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5242, 'BALHANNAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5243, 'OAKBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5244, 'CHARLESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5244, 'MOUNT TORRENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5244, 'WOODSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5245, 'HAHNDORF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5245, 'VERDUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5250, 'LITTLEHAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5251, 'MOUNT BARKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5251, 'WISTOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5252, 'BRUKUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5252, 'KANMANTOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5252, 'NAIRNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5253, 'MURRAY BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5253, 'MURRAY BRIDGE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5253, 'MURRAY BRIDGE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5254, 'CALLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5254, 'MONARTO SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5254, 'MURRAY BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5254, 'MYPOLONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5255, 'FINNISS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5255, 'LANGHORNE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5255, 'STRATHALBYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5256, 'CLAYTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5256, 'MILANG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5259, 'JERVOIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5259, 'NARRUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5259, 'POINT MCLEAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5259, 'RAUKKAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5259, 'WELLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5260, 'TAILEM BEND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5261, 'COOKE PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5261, 'COOMANDOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5261, 'CULBURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5261, 'KI KI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5261, 'YUMALI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5262, 'BINNUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5262, 'FRANCES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5262, 'HYNAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5262, 'KYBYBOLITE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5263, 'COONAWARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5264, 'MENINGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5265, 'COONALPYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5266, 'TINTINARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5267, 'KEITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5268, 'BORDERTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5269, 'WOLSELEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5270, 'MUNDULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5271, 'NARACOORTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5271, 'PADTHAWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5272, 'GREENWAYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5272, 'LUCINDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5273, 'AVENUE RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5275, 'KINGSTON SE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5276, 'ROBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5277, 'NANGWARRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5277, 'PENOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5277, 'TARPEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5278, 'KALANGADOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5279, 'MOUNT BURR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5279, 'TRIHI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5280, 'BEACHPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5280, 'HATHERLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5280, 'MILLICENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5280, 'RENDELSHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5280, 'SOUTHEND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5280, 'TANTANOOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5290, 'MOUNT GAMBIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'ALLENDALE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'CARPENTER ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'GLENCOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'KONGORONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'MIL LEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'MOORAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'MOUNT GAMBIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'MOUNT GAMBIER EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'MOUNT GAMBIER WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'O B FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'PORT MACDONNELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5291, 'YAHL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5301, 'GERANIUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5301, 'JABUK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5301, 'MOORLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5301, 'PARRAKIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5301, 'PEAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5301, 'SHERLOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5302, 'LAMEROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5303, 'PARILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5304, 'PEEBINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5304, 'PINNAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5306, 'WYNARKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5307, 'KAROONDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5307, 'MARAMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5308, 'COPEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5308, 'GALGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5308, 'MANTUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5308, 'MERCUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5308, 'PERPONDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5309, 'BORRIKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5309, 'HALIDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5309, 'MINDARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5309, 'SANDALWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5310, 'WANBI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5311, 'ALAWOONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5311, 'PARUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5311, 'TALDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5312, 'VEITCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5320, 'MORGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5321, 'CADELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5322, 'RAMCO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5330, 'LOWBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5330, 'WAIKERIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5331, 'KINGSTON-ON-MURRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5332, 'MOOROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5333, 'LOXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5333, 'LOXTON NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5333, 'TAPLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5340, 'PARINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5341, 'COOLTONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5341, 'RENMARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5341, 'RENMARK SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5342, 'MONASH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5343, 'BERRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5343, 'LYRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5343, 'WINKIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5344, 'GLOSSOP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5345, 'BARMERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5345, 'LOVEDAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5346, 'COBDOGLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5350, 'SANDY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5351, 'COCKATOO VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5351, 'LYNDOCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5351, 'WILLIAMSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5352, 'ROWLAND FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5352, 'STONE WELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5352, 'TANUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5353, 'ANGASTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5353, 'BLACK HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5353, 'CAMBRAI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5353, 'KEYNETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5353, 'MOCULTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5353, 'SEDAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5354, 'SWAN REACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5355, 'MARANANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5355, 'NURIOOTPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5355, 'SEPPELTSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5355, 'STOCKWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5356, 'TRURO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5357, 'BLANCHETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5357, 'NEW WELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5360, 'GREENOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5360, 'NAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5371, 'ROSEWORTHY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5371, 'SHEA-OAK LOG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5371, 'TEMPLERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5372, 'FREELING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5373, 'HAMILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5373, 'KAPUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5374, 'BOWER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5374, 'EUDUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5374, 'SUTHERLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5381, 'ROBERTSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5400, 'PINKERTON PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5400, 'WASLEYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5401, 'HAMLEY BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5410, 'LINWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5410, 'STOCKPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5411, 'TARLEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5412, 'RIVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5413, 'MARRABEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5413, 'SADDLEWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5414, 'MANOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5415, 'MINTARO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5416, 'FARRELL FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5417, 'BOOBOROWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5417, 'BURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5418, 'MOUNT BRYAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5419, 'HALLETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5420, 'WHYTE YARCOWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5421, 'TEROWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5422, 'PETERBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5431, 'HAMMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5431, 'MORCHARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5431, 'ORROROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5431, 'TARCOWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5432, 'CARRIETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5432, 'CRADOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5433, 'QUORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5434, 'HAWKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5440, 'COCKBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5440, 'MANNA HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5440, 'OLARY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5440, 'YUNTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5451, 'AUBURN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5452, 'WATERVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5453, 'CLARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5453, 'HOYLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5454, 'SPALDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5455, 'HILLTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5460, 'OWEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5461, 'BALAKLAVA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5462, 'BLYTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5464, 'BRINKWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5464, 'KOOLUNGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5470, 'YACKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5471, 'GULNARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5472, 'GEORGETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5473, 'GLADSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5480, 'APPILA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5480, 'LAURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5481, 'MURRAY TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5481, 'WIRRABARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5482, 'BOOLEROO CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5483, 'MELROSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5485, 'WILMINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5490, 'CALTOWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5491, 'JAMESTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5493, 'YONGALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5495, 'MAMBRAY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5495, 'PORT GERMEIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5501, 'DUBLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5501, 'LEWISTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5501, 'LOWER LIGHT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5501, 'MIDDLE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5501, 'PORT GAWLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5501, 'TWO WELLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5501, 'WINDSOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5502, 'MALLALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5502, 'REEVES PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5510, 'LOCHIEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5520, 'SNOWTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5521, 'REDHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5522, 'PORT BROUGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5523, 'CRYSTAL BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5523, 'MERRITON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5540, 'PORT PIRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5540, 'PORT PIRIE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5540, 'PORT PIRIE WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5540, 'RISDON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5540, 'RISDON PARK SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5540, 'SOLOMONTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5550, 'BOWMANS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5550, 'PORT WAKEFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5552, 'PASKEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5554, 'KADINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5555, 'ALFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5555, 'LAKE VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5555, 'MUNDOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5556, 'WALLAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5558, 'MOONTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5558, 'PORT HUGHES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5560, 'BUTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5570, 'CLINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5570, 'PORT CLINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5570, 'PRICE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5571, 'ARDROSSAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5571, 'PINE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5572, 'ARTHURTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5573, 'BALGOWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5573, 'MAITLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5573, 'POINT PEARCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5573, 'PORT VICTORIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5573, 'SOUTH KILKERRAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5573, 'WEETULTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5575, 'BRENTWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5575, 'CORNY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5575, 'MARION BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5575, 'MINLATON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5575, 'POINT TURTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5575, 'STENHOUSE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5575, 'WOOL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5576, 'YORKETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5577, 'WAROOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5580, 'CURRAMULKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5581, 'PORT VINCENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5582, 'STANSBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5583, 'COOBOWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5583, 'EDITHBURGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5600, 'IRON BARON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5600, 'WHYALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5600, 'WHYALLA PLAYFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5601, 'IRON KNOB');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5602, 'COWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5603, 'ARNO BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5603, 'WHARMINDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5604, 'PORT NEILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5605, 'BUTLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5605, 'TUMBY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5606, 'PORT LINCOLN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'COFFIN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'COULTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'KARKOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'LIPSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'LOUTH BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'MURDINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'NORTH SHIELDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'PORT LINCOLN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'UNGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'VENUS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'WANGARY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'WANILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'WARRACHIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5607, 'WARROW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5608, 'WHYALLA NORRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5608, 'WHYALLA NORRIE EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5608, 'WHYALLA NORRIE NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5608, 'WHYALLA STUART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5609, 'WHYALLA JENKINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5630, 'EDILLILIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5631, 'CUMMINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5632, 'YEELANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5633, 'LOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5640, 'CLEVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5641, 'BUCKLEBOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5641, 'KIMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5642, 'DARKE PEAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5642, 'KIELPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5642, 'RUDALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5650, 'WARRAMBOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5651, 'KYANCUTTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5652, 'WUDINNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5653, 'YANINEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5654, 'MINNIPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5655, 'POOCHERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5660, 'CUNGENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5661, 'WIRRULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5670, 'ELLISTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5671, 'CALCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5671, 'PORT KENNY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5680, 'HASLAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5680, 'SMOKY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5680, 'STREAKY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5690, 'CEDUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5690, 'COORABIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5690, 'PENONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5690, 'THEVENARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5690, 'YALATA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5700, 'PORT AUGUSTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5700, 'PORT AUGUSTA NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5700, 'PORT AUGUSTA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5710, 'COOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5710, 'KINGOONYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5710, 'NONNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5710, 'PORT AUGUSTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5710, 'STIRLING NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5710, 'TARCOOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5720, 'WOOMERA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5722, 'ANDAMOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5723, 'COOBER PEDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5724, 'MARLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5724, 'MINTABIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5725, 'OLYMPIC DAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5725, 'ROXBY DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5730, 'BELTANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5730, 'BLINMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5730, 'PARACHILNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5731, 'LEIGH CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5731, 'LYNDHURST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5732, 'COPLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5733, 'MARREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5734, 'OODNADATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5942, 'REGENCY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5950, 'ADELAIDE AIRPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='SA'), 5950, 'EXPORT PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6000, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6003, 'HIGHGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6003, 'NORTHBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6004, 'EAST PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6005, 'KINGS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6005, 'WEST PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6006, 'NORTH PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6007, 'LEEDERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6007, 'WEST LEEDERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6008, 'DAGLISH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6008, 'SHENTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6008, 'SUBIACO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6009, 'BROADWAY NEDLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6009, 'CRAWLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6009, 'DALKEITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6009, 'NEDLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6010, 'CLAREMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6010, 'CLAREMONT NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6010, 'KARRAKATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6010, 'MOUNT CLAREMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6010, 'SWANBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6011, 'COTTESLOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6011, 'PEPPERMINT GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6012, 'MOSMAN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6014, 'FLOREAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6014, 'JOLIMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6014, 'WEMBLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6015, 'CITY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6016, 'GLENDALOUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6016, 'MOUNT HAWTHORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6017, 'OSBORNE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6018, 'CHURCHLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6018, 'DOUBLEVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6018, 'GWELUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6018, 'INNALOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6018, 'KARRINYUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6018, 'WOODLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6019, 'SCARBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6019, 'WEMBLEY DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6020, 'CARINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6020, 'MARMION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6020, 'NORTH BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6020, 'SORRENTO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6020, 'WATERMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6021, 'BALCATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6021, 'STIRLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6022, 'HAMERSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6023, 'DUNCRAIG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6023, 'GLENGARRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6024, 'GREENWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6024, 'WARWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6025, 'CRAIGIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6025, 'HILLARYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6025, 'KALLAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6025, 'PADBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6026, 'KINGSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6026, 'WOODVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6027, 'BELDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6027, 'CONNOLLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6027, 'EDGEWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6027, 'HEATHRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6027, 'JOONDALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6027, 'MULLALOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6027, 'OCEAN REEF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6028, 'BURNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6028, 'CURRAMBINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6028, 'ILUKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6028, 'KINROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6029, 'TRIGG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6030, 'CLARKSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6030, 'MERRIWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6030, 'MINDARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6030, 'QUINNS ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6030, 'RIDGEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6030, 'TAMALA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6031, 'BANKSIA GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6031, 'CARRAMAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6031, 'NEERABUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6032, 'NOWERGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6033, 'CARABOODA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6034, 'EGLINTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6035, 'YANCHEP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6036, 'BUTLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6036, 'JINDALEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6037, 'TWO ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6038, 'ALKIMOS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6041, 'CARABAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6041, 'GUILDERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6041, 'WILBINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6041, 'WOODRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6042, 'GABBADAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6042, 'SEABIRD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6043, 'BRETON BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6043, 'LEDGE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6044, 'KARAKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6044, 'LANCELIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6044, 'NILGEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6050, 'COOLBINIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6050, 'MENORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6050, 'MOUNT LAWLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6051, 'MAYLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6052, 'BEDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6052, 'INGLEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6053, 'BAYSWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6054, 'ASHFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6054, 'BASSENDEAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6054, 'EDEN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6054, 'KIARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6054, 'LOCKRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6055, 'CAVERSHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6055, 'GUILDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6055, 'HAZELMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6055, 'HENLEY BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6055, 'SOUTH GUILDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6055, 'WEST SWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'BASKERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'BELLEVUE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'BOYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'GREENMOUNT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'HELENA VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'HERNE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'JANE BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'KOONGAMIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'MIDDLE SWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'MIDLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'MIDVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'MILLENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'RED HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'STRATTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'SWAN VIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'VIVEASH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6056, 'WOODBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6057, 'HIGH WYCOMBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6057, 'MAIDA VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6058, 'FORRESTFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6059, 'DIANELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6060, 'DOG SWAMP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6060, 'JOONDANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6060, 'TUART HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6060, 'YOKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6061, 'BALGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6061, 'MIRRABOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6061, 'NOLLAMARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6061, 'WESTMINSTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6062, 'EMBLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6062, 'MORLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6062, 'NORANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6063, 'BEECHBORO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6064, 'ALEXANDER HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6064, 'GIRRAWHEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6064, 'KOONDOOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6064, 'MARANGAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'ASHBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'DARCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'GNANGARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'HOCKING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'JANDABUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'KINGSWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'LANDSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'LEXIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'MADELEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'MARIGINIUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'PEARSALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'PINJAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'SINAGRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'TAPPING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'WANGARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6065, 'WANNEROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6066, 'BALLAJURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6067, 'CULLACABARDEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6068, 'WHITEMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6069, 'BELHUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6069, 'BRIGADOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6069, 'ELLENBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6069, 'ELLENBROOK EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6069, 'THE VINES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6069, 'UPPER SWAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6070, 'DARLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6071, 'GLEN FORREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6071, 'HOVEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6072, 'MAHOGANY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6073, 'MUNDARING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6074, 'SAWYERS VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'BICKLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'CARMEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'GOOSEBERRY HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'HACKETTS GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'KALAMUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'LESMURDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'PAULLS VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'PICKERING BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'PIESSE BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'RESERVOIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6076, 'WALLISTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6081, 'PARKERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6081, 'STONEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6082, 'MOUNT HELENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6083, 'GIDGEGANNUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6083, 'MORANGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6084, 'BULLSBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6084, 'CHITTERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6084, 'LOWER CHITTERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6090, 'MALAGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6100, 'BURSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6100, 'LATHLAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6100, 'VICTORIA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6101, 'CARLISLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6101, 'EAST VICTORIA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6102, 'BENTLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6102, 'ST JAMES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6103, 'RIVERVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6104, 'ASCOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6104, 'BELMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6104, 'REDCLIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6105, 'CLOVERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6105, 'KEWDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6105, 'PERTH AIRPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6106, 'WELSHPOOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6107, 'BECKENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6107, 'CANNINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6107, 'KENWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6107, 'QUEENS PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6107, 'WATTLE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6107, 'WILSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6108, 'THORNLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6109, 'MADDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6109, 'ORANGE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6110, 'GOSNELLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6110, 'HUNTINGDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6110, 'MARTIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6110, 'SOUTHERN RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6111, 'CANNING MILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6111, 'KARRAGULLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6111, 'KELMSCOTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6111, 'ROLEYSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6111, 'WESTFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6112, 'ARMADALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6112, 'BEDFORDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6112, 'BROOKDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6112, 'FORRESTDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6112, 'MOUNT NASURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6112, 'WUNGONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6121, 'OAKFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6121, 'OLDBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6122, 'BYFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6122, 'CARDUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6122, 'DARLING DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6122, 'KARRAKUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6123, 'MUNDIJONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6123, 'WHITBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6124, 'JARRAHDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6125, 'HOPELAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6125, 'MARDELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6125, 'SERPENTINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6126, 'KEYSBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6147, 'LANGFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6147, 'LYNWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6147, 'PARKWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6148, 'FERNDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6148, 'RIVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6148, 'ROSSMOYNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6148, 'SHELLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6149, 'BULL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6149, 'LEEMING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6150, 'BATEMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6150, 'MURDOCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6150, 'WINTHROP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6151, 'KENSINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6151, 'SOUTH PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6152, 'COMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6152, 'KARAWARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6152, 'MANNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6152, 'SALTER POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6152, 'WATERFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6153, 'APPLECROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6153, 'ARDROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6153, 'BRENTWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6153, 'CANNING BRIDGE APPLECROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6153, 'MOUNT PLEASANT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6154, 'ALFRED COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6154, 'BOORAGOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6154, 'MYAREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6155, 'CANNING VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6155, 'CANNING VALE SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6155, 'WILLETTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6156, 'ATTADALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6156, 'MELVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6156, 'WILLAGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6156, 'WILLAGEE CENTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6157, 'BICTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6157, 'PALMYRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6158, 'EAST FREMANTLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6159, 'NORTH FREMANTLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6160, 'FREMANTLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6161, 'ROTTNEST ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6162, 'BEACONSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6162, 'SOUTH FREMANTLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6162, 'WHITE GUM VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'BIBRA LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'COOLBELLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'HAMILTON HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'HILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'KARDINYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'NORTH LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'O''CONNOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'SAMSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6163, 'SPEARWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6164, 'ATWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6164, 'BANJUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6164, 'BEELIAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6164, 'JANDAKOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6164, 'SOUTH LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6164, 'SUCCESS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6164, 'YANGEBUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6165, 'HOPE VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6165, 'NAVAL BASE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6166, 'COOGEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6166, 'HENDERSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6166, 'MUNSTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6166, 'WATTLEUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'ANKETELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'BERTRAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'CALISTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'CASUARINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'KWINANA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'KWINANA TOWN CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'MANDOGALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'MEDINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'ORELIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'PARMELIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'POSTANS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'THE SPECTACLES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6167, 'WANDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6168, 'COOLOONGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6168, 'EAST ROCKINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6168, 'GARDEN ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6168, 'HILLMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6168, 'PERON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6168, 'ROCKINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6169, 'SAFETY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6169, 'SHOALWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6169, 'WAIKIKI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6169, 'WARNBRO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6170, 'LEDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6170, 'WELLARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6171, 'BALDIVIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6172, 'PORT KENNEDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6173, 'SECRET HARBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6174, 'GOLDEN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6175, 'SINGLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6176, 'KARNUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6207, 'MYARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6207, 'NAMBEELUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6207, 'NORTH DANDALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6207, 'SOLUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6207, 'WHITTAKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'BLYTHEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'FAIRBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'NIRIMBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'NORTH YUNDERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'OAKLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'PINJARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'POINT GREY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'RAVENSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'SOUTH YUNDERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6208, 'WEST PINJARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'BARRAGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'BOUVARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'CLIFTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'COODANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'DAWESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'DUDLEY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'ERSKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'FALCON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'FURNISSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'GEOGRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'GREENFIELDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'HALLS HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'HERRON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'LAKELANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'MADORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'MANDURAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'MANDURAH EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'MANDURAH NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'MEADOW SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'PARKLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'SAN REMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'SILVER SANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'STAKE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6210, 'WANNANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6213, 'BANKSIADALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6213, 'DWELLINGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6213, 'ETMILYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6213, 'HOLYOAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6213, 'INGLEHOPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6213, 'MARRINUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6213, 'TEESDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6213, 'WURAMING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6214, 'BIRCHMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6214, 'COOLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6214, 'KOOLJERRENUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6215, 'HAMEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6215, 'LAKE CLIFTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6215, 'NANGA BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6215, 'PRESTON BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6215, 'WAGERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6215, 'WAROONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6218, 'YARLOOP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6220, 'COOKERNUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6220, 'HARVEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6220, 'HOFFMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6220, 'MYALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6220, 'UDUC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6220, 'WARAWARRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6221, 'MORNINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6221, 'WOKALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6223, 'BENGER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6224, 'BEELA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6224, 'BRUNSWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'ALLANSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'BOWELLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'COLLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'MCALINDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'MUMBALLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'NOGGERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'SHOTTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'TREESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6225, 'WORSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6226, 'ROELANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6227, 'BUREKUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6228, 'WATERLOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6229, 'PICTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6229, 'PICTON EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'BUNBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'CAREY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'COLLEGE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'DALYELLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'DAVENPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'EAST BUNBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'GELORUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'GLEN IRIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'PELICAN POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'SOUTH BUNBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'USHER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'VITTORIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6230, 'WITHERS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6231, 'BUNBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6232, 'EATON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6233, 'AUSTRALIND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6233, 'BINNINGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6233, 'LESCHENAULT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6233, 'PARKFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6233, 'WELLESLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6236, 'CROOKED BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6236, 'DARDANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6236, 'DARDANUP WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6236, 'FERGUSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6236, 'HENTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6236, 'PARADISE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6236, 'WELLINGTON FORREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6236, 'WELLINGTON MILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6237, 'BOYANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6237, 'ELGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6237, 'GWINDINUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6237, 'NORTH BOYANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6237, 'STRATHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6237, 'THE PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'ARGYLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'BEELERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'BROOKHAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'CHARLEY CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'DONNYBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'GLEN MERVYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'PAYNEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'QUEENWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'THOMSON BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'UPPER CAPEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6239, 'YABBERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6240, 'LOWDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6243, 'WILGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6243, 'WILGA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6244, 'BOYUP BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6244, 'CHOWERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6244, 'DINNINUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6244, 'KULIKUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6244, 'MAYANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6244, 'SCOTTS BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6244, 'TONEBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6251, 'BRAZIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6251, 'KIRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6251, 'NEWLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6252, 'MULLALYUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6253, 'BALINGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6253, 'GRIMWADE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6253, 'SOUTHAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6254, 'GREENBUSHES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6254, 'NORTH GREENBUSHES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6255, 'BENJINUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6255, 'BRIDGETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6255, 'CATTERICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6255, 'DONNELLY RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6255, 'HESTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6255, 'HESTER BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6255, 'KANGAROO GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6255, 'WINNEJUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6256, 'GLENLYNN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6256, 'KINGSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6256, 'MARANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6256, 'SUNNYSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6256, 'WANDILLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6256, 'YORNUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6258, 'JARDEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6258, 'MANJIMUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6258, 'MORDALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6258, 'NYAMUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6258, 'QUINNINUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6258, 'SHANNON RIVER MILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6258, 'WHEATLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6260, 'BIDDELIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6260, 'EASTBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6260, 'LAKE JASPER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6260, 'PEERABEELUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6260, 'PEMBERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6262, 'NORTHCLIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6271, 'CAPEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6271, 'CAPEL RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6271, 'FORREST BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6271, 'PEPPERMINT GROVE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6271, 'STIRLING ESTATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'BARRABUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'CARLOTTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'CUNDINUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'DARRADUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'EAST NANNUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'JALBARRAGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'JARRAHWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'NANNUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'SCOTT RIVER EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6275, 'YOGANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'ABBA RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'ABBEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'ACTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'AMBERGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'ANNIEBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'BOALLIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'BOVELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'BROADWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'BUSSELTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'CARBUNUP RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'CHAPMAN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'GEOGRAPHE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'HITHERGREEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'JINDONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'KALGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'KALOORUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'KEALY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'LUDLOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'MARYBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'METRICUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'NORTH JINDONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'REINSCOURT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'RUABON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'SABINA RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'SIESTA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'TUTUNUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'VASSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'WALSALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'WEST BUSSELTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'WILYABRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'WONNERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'YALYALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'YELVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6280, 'YOONGARILLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6281, 'DUNSBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6281, 'EAGLE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6281, 'NATURALISTE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6281, 'QUEDJINUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6281, 'QUINDALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6281, 'YALLINGUP SIDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6282, 'YALLINGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6284, 'BAUDIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6284, 'COWARAMUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6284, 'GRACETOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6284, 'TREETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'BRAMLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'BURNSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'GNARABUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'MARGARET RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'OSMINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'PREVELLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'REDGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'ROSA BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'ROSA GLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6285, 'SCHROEDER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6286, 'BORANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6286, 'FOREST GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6286, 'WITCHCLIFFE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6288, 'ALEXANDRA BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6288, 'COURTENAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6288, 'HAMELIN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6288, 'KARRIDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6288, 'NILLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6288, 'SCOTT RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6288, 'WARNER GLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6290, 'AUGUSTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6290, 'DEEPDENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6290, 'EAST AUGUSTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6290, 'KUDARDUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6290, 'LEEUWIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6290, 'MOLLOY ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'BADGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'BALLADONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'BURGES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'CALJIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'COLD HARBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'DALIAK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'FLINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'FLYNN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'GILGERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'GREENHILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'GWAMBYGINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'INKPEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'KAURING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'MALEBELLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'MOUNT HARDEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'MOUNT OBSERVATION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'NARRALOGGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'QUELLINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'SAINT RONANS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'TALBOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'TALBOT WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'WILBERFORCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6302, 'YORK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6304, 'BALLY BALLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6304, 'BEVERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6304, 'DALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6304, 'EAST BEVERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6304, 'KOKEBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6304, 'MORBINNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6304, 'WESTDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6306, 'ALDERSYDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6306, 'BROOKTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6306, 'BULYEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6306, 'JELCOBINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6306, 'KWEDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'BOYAGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'CODJATOTINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'DWARDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'GILLIMANINNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'HASTINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'HOTHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'JINGARING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'MOORUMBINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'NOONEBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'PINGELLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'PUMPHREYS BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'TUTANNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6308, 'WANDERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6309, 'EAST POPANYINNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6309, 'POPANYINNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6309, 'STRATHERNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6309, 'WEST POPANYINNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6311, 'COMMODINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6311, 'CONTINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6311, 'CUBALLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6311, 'DRYANDRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6311, 'LOL GRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6311, 'TOWNSENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6311, 'WARDERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6311, 'YORNANING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'BOUNDAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'DUMBERNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'HILLSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'MINIGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'NARROGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'NARROGIN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'NOMANS LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'TOOLIBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6312, 'YILLIMINNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6313, 'HIGHBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'ARTHUR RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'BALLAYING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'CANCANNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'COLLANILLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'JALORAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'LIME LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'PIESSEVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'WAGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6315, 'WEDGECARRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6316, 'BOYERINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6316, 'CARTMETICUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6316, 'GLENCOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6316, 'KENMARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6316, 'WESTWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6316, 'WOODANILLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6317, 'KATANNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6318, 'BROOMEHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6318, 'BROOMEHILL EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6318, 'BROOMEHILL VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6318, 'BROOMEHILL WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6320, 'BOBALONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6320, 'BORDERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6320, 'DARTNALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6320, 'LAKE TOOLBRUNUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6320, 'MOONIES HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6320, 'TAMBELLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6320, 'WANSBROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6321, 'CRANBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6322, 'TENTERDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6323, 'KENDENUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'CARBARUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'DENBARKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'FOREST HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'MOUNT BARKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'PERILLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'PORONGURUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'SAINT WERBURGHS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'SOUTH STIRLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'TAKALARUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'TEDDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6324, 'WOOGENILUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6326, 'NARRIKUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6326, 'YELLANUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6327, 'REDMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6327, 'REDMOND WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'CAPE RICHE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'CHEYNES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'GNOWELLEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'GREEN RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'KOJANEERUP SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'MANYPEAKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'METTLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'PALMDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6328, 'WELLSTEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'ALBANY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'BAYONET HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'BIG GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'BORNHOLM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'CENTENNIAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'COLLINGWOOD HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'COLLINGWOOD PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'CUTHBERT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'DROME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'ELLEKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'EMU POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'FRENCHMAN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'GLEDHOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'GREEN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'HUNWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'KALGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'KING RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'KRONKUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'LANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'LITTLE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'LOCKYER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'LOWER KING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'LOWLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MARBELLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MCKAIL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MIDDLETON BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MILLBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MILPARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MINDIJUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MIRA MAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MOUNT CLARENCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MOUNT ELPHINSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'MOUNT MELVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'NANARUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'NAPIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'NULLAKI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'ORANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'PORT ALBANY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'ROBINSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'ROCKY CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'SANDPATCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'SEPPINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'SPENCER PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'TORBAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'TORNDIRRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'VANCOUVER PENINSULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'WALMSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'WARRENUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'WEST CAPE HOWE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'WILLYUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'YAKAMIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6330, 'YOUNGS SIDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6331, 'ALBANY DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6332, 'ALBANY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6333, 'DENMARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6333, 'GOLDEN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6333, 'NORNALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6333, 'TINGLEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6335, 'GNOWANGERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6335, 'JACKITUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6335, 'KEBARINGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6335, 'PALINUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6336, 'COWALELLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6336, 'MILLS LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6336, 'MINDARABIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6336, 'NEEDILUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6336, 'ONGERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6336, 'TOOMPUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6337, 'GAIRDNER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6337, 'JACUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6337, 'JERRAMUNGUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'AMELUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'BORDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'BOXWOOD HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'BREMER BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'FITZGERALD RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'MAGITUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'MONJEBUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'NALYERLUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'NORTH STIRLINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6338, 'STIRLING RANGE NATIONAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6341, 'NYABING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6343, 'PINGRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6346, 'JERDACUTTUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6346, 'RAVENSTHORPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6348, 'HOPETOUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6350, 'DUMBLEYUNG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6352, 'KUKERIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6353, 'LAKE GRACE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6353, 'TARIN ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6355, 'HOLT ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6355, 'LAKE BIDDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6355, 'NEWDEGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6355, 'VARLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6356, 'LAKE KING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6356, 'MOUNT MADDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6357, 'PINGARING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6358, 'KARLGARIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6359, 'FORRESTANIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6359, 'HYDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6361, 'HARRISMITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6361, 'TINCURRIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6363, 'DUDININ');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6365, 'JITARNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6365, 'KULIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6367, 'BENDERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6367, 'KONDININ');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6368, 'SOUTH KUMMININ');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6369, 'MOUNT WALKER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6369, 'NAREMBEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6370, 'EAST WICKEPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6370, 'KIRK ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6370, 'MALYALLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6370, 'WICKEPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6370, 'WOGOLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6372, 'YEALERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6373, 'BULLARING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6375, 'ADAMSVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6375, 'BILBARIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6375, 'CORRIGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6375, 'GORGE ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6375, 'KUNJIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6375, 'KURRENKUTTEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6383, 'DANGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6383, 'MAWSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6383, 'QUAIRADING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6383, 'YOTING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6384, 'PANTAPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6385, 'KWOLYIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6386, 'SHACKLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6390, 'BANNISTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6390, 'BODDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6390, 'CROSSMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6390, 'MOUNT WELLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6390, 'RANFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'BORANING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'CONGELIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'CULBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'HILLMAN RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'LOWER HOTHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'MARRADONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'MOUNT COOKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'NARRAKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'NORTH BANNISTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'QUINDANNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'TARWONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6391, 'WILLIAMS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6392, 'BOKAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6392, 'BOOLADING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6392, 'DARKAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6393, 'CORDERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6393, 'DURANILLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6393, 'MOODIARRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6393, 'TRIGWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6394, 'BEAUFORT RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6394, 'BOILUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6394, 'BOSCABEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6394, 'CHANGERUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6394, 'MURADUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6394, 'ORCHID VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6394, 'QUALEUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6395, 'CHERRY TREE POOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6395, 'JINGALUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6395, 'KOJONUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6395, 'LUMEAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6395, 'MOBRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6395, 'RYANSBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6396, 'FRANKLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6397, 'ROCKY GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6398, 'WALPOLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'BUCKLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'BURLONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'CUNJARDINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'IRISHTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'JENNACUBBINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'JENNAPULLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'MALABAINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'MEENAAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'MOKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'MULUCKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'MUMBERKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'MURESK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'NORTHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'ROSSMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'SOUTHERN BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'SPENCERS BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'THROSSELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6401, 'WONGAMINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6403, 'GRASS VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6405, 'GREENWOODS VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6405, 'MECKERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6405, 'QUELAGETTING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6405, 'WARDING EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6407, 'CUNDERDIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6407, 'WAEEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6407, 'WATERCARRIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6407, 'WYOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6407, 'WYOLA WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6407, 'YOUNDEGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6409, 'DOONGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6409, 'TAMMIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6409, 'YORKRAKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6410, 'BUNGULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6410, 'DAADENNING CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6410, 'KELLERBERRIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6410, 'MOUNT CAROLINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6410, 'NORTH KELLERBERRIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6411, 'DOODLAKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6411, 'SOUTH DOODLAKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6412, 'BAANDEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6412, 'NORTH BAANDEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6413, 'BUNGULLUPING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6413, 'HINES HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6414, 'NANGEENAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6415, 'GOOMARIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6415, 'KORBEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6415, 'MERREDIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6415, 'NOKANING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6415, 'NORPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6415, 'TANDEGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6418, 'BRUCE ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6418, 'YARDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6419, 'ARDATH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6420, 'MUNTADGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6421, 'BURRACOPPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6421, 'SOUTH BURRACOPPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6422, 'WALGOOLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6423, 'WESTONIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6424, 'BODALLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6424, 'NORTH BODALLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6424, 'SOUTH BODALLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6425, 'DULYALBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6425, 'MOORINE ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'CORINTHIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'GHOOLI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'HOLLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'MARVEL LOCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'MOUNT HAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'MOUNT HOLLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'MOUNT JACKSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'MOUNT PALMER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'PARKER RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'SKELETON ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'SOUTH YILGARN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'SOUTHERN CROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'TURKEY HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6426, 'YELLOWDINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6427, 'KOOLYANOBBING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6428, 'BABAKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6429, 'BOORABBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6429, 'BULLABULLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6429, 'COOLGARDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6429, 'KARRAMINDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6429, 'LONDONDERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6429, 'MOUNT BURGES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6429, 'VICTORIA ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6429, 'WALLAROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'BINDULI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'BROADWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'HANNANS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'KALGOORLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'KARLKURLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'MULLINGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'PICCADILLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'SOUTH KALGOORLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'WEST KALGOORLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'WEST LAMINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'WILLIAMSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6430, 'YILKARI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'BOORARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'BROAD ARROW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'BROWN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'BULONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'EMU FLAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'FEYSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'KANOWNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'KURNALPI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'LAKEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'ORA BANDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'PLUMRIDGE LAKES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6431, 'TRAFALGAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6432, 'BOULDER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6432, 'FIMISTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6432, 'SOUTH BOULDER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6432, 'VICTORY HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6433, 'HANNANS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6433, 'KALGOORLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6434, 'CUNDEELEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6434, 'FORREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6434, 'RAWLINNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6434, 'REID');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6434, 'ZANTHUS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6436, 'MENZIES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6436, 'ULARRING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6437, 'LEINSTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6438, 'LEONORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6438, 'TEUTONIC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6440, 'BANDYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6440, 'BEADELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6440, 'BURTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6440, 'COSMO NEWBERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6440, 'LAKE WELLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6440, 'LAVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6440, 'NEALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6442, 'KAMBALDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'BALLADONIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'CAIGUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'COCKLEBIDDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'DUNDAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'EUCLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'FRASER RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'HIGGINSVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'MADURA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'MUNDRABILLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'NORSEMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6443, 'WIDGIEMOOLTHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6445, 'SALMON GUMS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6446, 'GRASS PATCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6448, 'GIBSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6450, 'ESPERANCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6450, 'NERIDUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6450, 'SINCLAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6460, 'GOOMALLING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6460, 'KARRANADGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6460, 'UCARTY WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6460, 'WALYORMOURING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6461, 'DOWERIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6461, 'KOOMBERKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6462, 'HINDMARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6462, 'MINNIVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6462, 'UCARTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6465, 'MANMANNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6466, 'CADOUX');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6467, 'BURAKIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6468, 'GOODLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6468, 'KALANNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6468, 'PETRUDOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6470, 'KULJA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6472, 'BEACON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6472, 'BIMBIJY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6472, 'CLEARY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6472, 'KARROUN HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6472, 'MOUROUBRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6472, 'REMLAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6473, 'NORTH WIALKI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6473, 'WIALKI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6475, 'BOORALAMING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6475, 'KOORDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6475, 'MOLLERIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6475, 'NEWCARLBEON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6476, 'GABBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6477, 'BENCUBBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6479, 'BARBALIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6479, 'BONNIE ROCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6479, 'DANDANNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6479, 'KARLONING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6479, 'LAKE BROWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6479, 'MUKINBUDIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6479, 'WATTONING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6479, 'WILGOYNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6484, 'BULLFINCH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6484, 'ENNUIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6484, 'LAKE DEBORAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6485, 'WYALKATCHEM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6488, 'TRAYNING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6489, 'KUNUNOPPIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6490, 'NUNGARIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6501, 'MUCHEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6502, 'BINDOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6503, 'GINGIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6505, 'WANNAMAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6506, 'MOGUMBER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6507, 'DANDARAGAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6509, 'GLENTROMIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6509, 'NEW NORCIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6509, 'WADDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6509, 'YARAWINDAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6510, 'GILLINGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6510, 'KOOJAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6510, 'MOORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6510, 'ROUND HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6511, 'CERVANTES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6512, 'COOMBERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6513, 'WATHEROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6514, 'GREEN HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6514, 'LEEMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6515, 'COOROW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6516, 'JURIEN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6517, 'CARNAMAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6518, 'ENEABBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6518, 'WARRADARGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6519, 'ARRINO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6519, 'ARROWSMITH EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6519, 'DUDAWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6519, 'KADATHINNI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6519, 'THREE SPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6519, 'WOMARDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6521, 'BADGINGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'BUNDANOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'HOLMWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'IKEWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'LOCKIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'MINGENEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'MOORIARY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'MOUNT BUDD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'NANGETTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'YANDANOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6522, 'YARRAGADEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6525, 'DONGARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6528, 'MOUNT HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6528, 'SOUTH GREENOUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6528, 'WALKAWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'BEACHLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'BERESFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'BLUFF POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'GERALDTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'KARLOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'MAHOMETS FLATS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'MERU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'MORESBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'MOUNT TARCOOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'RANGEWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'SPALDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'STRATHALBYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'SUNSET BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'TARCOOLA BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'UTAKARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'WAGGRAKINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'WANDINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'WEBBERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'WONTHELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6530, 'WOORREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6531, 'GERALDTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'AJANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'BINNU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'BOOTENAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'BRINGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'BURMA ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'CAPE BURNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'COOLCALALAYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'DARTMOOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'DEEPDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'DRUMMOND COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'DRUMMOND NORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'DURAWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'EAST CHAPMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'EAST NABAWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'EAST YUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'ELLENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'ERADU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'ERADU SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'GEORGINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'GLENFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'GREENOUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'HAMELIN POOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'HICKETY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'KOJARENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'MARRAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'MINNENOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'MOONYOONOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'NABAWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'NARALING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'NARNGULU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'NORTH ERADU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'NORTHERN GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'RUDDS GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'SANDSPRINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'SOUTH YUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'TIBRADDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'VALENTINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'WEST BINNU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'WICHERINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'WICHERINA SOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'YETNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6532, 'YUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'ALMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'BOWES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'EAST BOWES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'GREGORY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'HORROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'ISSEKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'NORTHAMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'OGILVIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'SANDY GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6535, 'YALLABATHARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6536, 'KALBARRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6536, 'KALBARRI NATIONAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6536, 'ZUYTDORP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6537, 'DENHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6556, 'CHIDLOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6558, 'WOOROLOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6560, 'WUNDOWIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6562, 'BAKERS HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6562, 'COPLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6562, 'WOOTTATING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6564, 'CLACKLINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6566, 'TOODYAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6567, 'JULIMAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6568, 'BOLGART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6569, 'CALINGIRI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6569, 'OLD PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6571, 'YERECOIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6572, 'PIAWANING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6574, 'BINDI BINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6575, 'MILING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6603, 'KONNONGORRING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6603, 'WONGAN HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6605, 'KONDUT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6606, 'BALLIDU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6608, 'EAST DAMBORING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6608, 'MARNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6608, 'PITHARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6609, 'DALWALLINU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6609, 'NUGADONG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6609, 'XANTIPPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6612, 'JIBBERDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6612, 'MIAMOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6612, 'WUBIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6613, 'BUNTINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6614, 'MAYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6616, 'LATHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6620, 'PERENJORI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6623, 'GUTHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6623, 'KOOLANOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6623, 'MORAWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6623, 'PINTHARUKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6625, 'MERKANOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6627, 'CANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6628, 'TARDUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6630, 'MULLEWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6632, 'TENINDEWA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6635, 'YALGOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6638, 'COOLADAR HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6638, 'DAGGAR HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6638, 'MOUNT MAGNET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6638, 'PAYNESVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6639, 'SANDSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6640, 'CUE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6640, 'REEDY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6642, 'ANGELO RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6642, 'CAPRICORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6642, 'KUMARINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6642, 'MEEKATHARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6642, 'PEAK HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6646, 'WILUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'BABBAGE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'BERNIER ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'BROCKMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'BROWN RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'CARNARVON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'CORAL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'DORRE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'EAST CARNARVON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'GREYS PLAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'INGGARDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'KENNEDY RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'KINGSFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'LYNDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'MACLEOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'MASSEY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'MAUDS LANDING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'MINILYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'MORGANTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'NINGALOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'NORTH PLANTATIONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'SOUTH CARNARVON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'SOUTH PLANTATIONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'WOORAMEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6701, 'YANDOO CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6705, 'EAST LYONS RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6705, 'GASCOYNE JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6705, 'GASCOYNE RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6705, 'WEST LYONS RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6707, 'CAPE RANGE NATIONAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6707, 'EXMOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6707, 'EXMOUTH GULF');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6707, 'LEARMONTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6707, 'NORTH WEST CAPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6710, 'CANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6710, 'ONSLOW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6710, 'PEEDAMULLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6710, 'TALANDJI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6710, 'YANNARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6711, 'THEVENARD ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6712, 'BARROW ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6713, 'DAMPIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'ANTONYMYRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'BALLA BALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'BAYNTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'BULGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'BURRUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'CLEAVERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'COOYA POOYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'GAP RIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'GNOOREA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'KARRATHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'KARRATHA INDUSTRIAL ESTATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'MAITLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'MARDIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'MILLARS WELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'MOUNT ANKETELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'MULATAGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'NICKOL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'PEGS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'SHERLOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6714, 'STOVE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6716, 'FORTESCUE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6716, 'HAMERSLEY RANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6716, 'MILLSTREAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6716, 'PANNAWONICA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6718, 'ROEBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6720, 'COSSACK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6720, 'WICKHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6721, 'PORT HEDLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6722, 'BOODARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6722, 'DE GREY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6722, 'FINUCANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6722, 'PIPPINGARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6722, 'SOUTH HEDLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6723, 'GOLDSWORTHY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6725, 'BROOME');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6725, 'DAMPIER PENINSULA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6725, 'EIGHTY MILE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6725, 'GINGERAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6725, 'LAGRANGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6725, 'ROEBUCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6725, 'WATERBANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6726, 'CABLE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6728, 'DERBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6733, 'KOOLAN ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6740, 'WYNDHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6743, 'KUNUNURRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6743, 'WARMUN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6751, 'INNAWANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6751, 'JUNA DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6751, 'KARIJINI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6751, 'MOUNT SHEILA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6751, 'MULGA DOWNS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6751, 'NANUTARRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6751, 'ROCKLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6751, 'TOM PRICE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6753, 'MUNDIWINDI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6753, 'NEWMAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6754, 'CHICHESTER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6754, 'PARABURDOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6754, 'WITTENOOM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6758, 'NULLAGINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6760, 'MARBLE BAR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6761, 'SHAY GAP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6762, 'TELFER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6765, 'FITZROY CROSSING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6770, 'HALLS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6770, 'MCBEATH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6798, 'CHRISTMAS ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6799, 'HOME ISLAND COCOS (KEELING) ISLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6799, 'WEST ISLAND COCOS (KEELING) ISLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6831, 'PERTH ST GEORGES TCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6832, 'PERTH EAST ST GEORGES TCE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6837, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6838, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6839, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6840, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6841, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6842, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6843, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6844, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6845, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6846, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6847, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6848, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6849, 'PERTH BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6850, 'CLOISTERS SQUARE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6865, 'NORTHBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6872, 'WEST PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6892, 'EAST PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6901, 'WEST LEEDERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6902, 'LEEDERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6903, 'LEEDERVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6904, 'SUBIACO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6905, 'NORTHLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6906, 'NORTH PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6907, 'NEDLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6909, 'NEDLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6910, 'CLAREMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6911, 'COTTESLOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6912, 'MOSMAN PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6913, 'WEMBLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6914, 'BALCATTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6915, 'MOUNT HAWTHORN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6916, 'OSBORNE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6916, 'OSBORNE PARK DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6917, 'OSBORNE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6918, 'INNALOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6919, 'JOONDALUP DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6920, 'NORTH BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6921, 'KARRINYUP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6922, 'SCARBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6923, 'HILLARYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6924, 'GREENWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6925, 'WALLISTON DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6926, 'KALAMUNDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6929, 'MOUNT LAWLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6931, 'MAYLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6932, 'INGLEWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6933, 'BAYSWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6934, 'BASSENDEAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6935, 'GUILDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6936, 'MIDLAND DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6939, 'TUART HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6941, 'MIRRABOOKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6942, 'BASSENDEAN DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6943, 'MORLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6944, 'MALAGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6945, 'MALAGA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6946, 'WANNEROO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6947, 'WANGARA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6951, 'SOUTH PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6952, 'COMO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6953, 'APPLECROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6954, 'BOORAGOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6955, 'WILLETTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6956, 'MELVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6957, 'PALMYRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6958, 'ROYAL AUSTRALIAN NAVY WARSHIPS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6959, 'FREMANTLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6960, 'MYAREE BC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6961, 'PALMYRA DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6963, 'HAMILTON HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6964, 'SUCCESS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6965, 'BIBRA LAKE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6966, 'KWINANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6967, 'ROCKINGHAM DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6968, 'ROCKINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6969, 'ROCKINGHAM BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6970, 'CANNING VALE DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6979, 'VICTORIA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6981, 'EAST VICTORIA PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6982, 'BENTLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6983, 'BENTLEY DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6984, 'BELMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6985, 'CLOVERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6986, 'WELSHPOOL DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6987, 'CANNINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6988, 'THORNLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6989, 'MADDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6990, 'GOSNELLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6991, 'KELMSCOTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6992, 'ARMADALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='WA'), 6997, 'KELMSCOTT DC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7000, 'GLEBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7000, 'HOBART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7000, 'MOUNT STUART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7000, 'NORTH HOBART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7000, 'PARLIAMENT HOUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7000, 'WEST HOBART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7001, 'HOBART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7001, 'MAATSUYKER ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7001, 'PORT DAVEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7002, 'NORTH HOBART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7004, 'BATTERY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7004, 'SOUTH HOBART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7005, 'DYNNYRNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7005, 'SANDY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7005, 'UNIVERSITY OF TASMANIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7006, 'SANDY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7007, 'MOUNT NELSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7008, 'CORNELIAN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7008, 'LENAH VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7008, 'NEW TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7009, 'DERWENT PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7009, 'LUTANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7009, 'MOONAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7010, 'DOWSING POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7010, 'ELWICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7010, 'GLENORCHY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7010, 'GOODWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7010, 'MONTROSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7010, 'ROSETTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7011, 'AUSTINS FERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7011, 'BERRIEDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7011, 'CHIGWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7011, 'CLAREMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7012, 'COLLINSVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7012, 'GLENLUSK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7015, 'FLAGSTAFF GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7015, 'GEILSTON BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7015, 'LINDISFARNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7015, 'ROSE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7016, 'RISDON VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7017, 'GRASSTREE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7017, 'HONEYWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7017, 'OLD BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7017, 'OTAGO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7017, 'TEA TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7018, 'BELLERIVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7018, 'HOWRAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7018, 'MONTAGU BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7018, 'MORNINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7018, 'ROSNY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7018, 'TRANMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7018, 'WARRANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7019, 'CLARENDON VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7019, 'ROKEBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7020, 'CLIFTON BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7020, 'SANDFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7021, 'LAUDERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7022, 'SOUTH ARM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7023, 'OPOSSUM BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7024, 'CREMORNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7025, 'DULCOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7025, 'RICHMOND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7026, 'CAMPANIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7026, 'LOWDINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7026, 'REKUNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7027, 'COLEBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7027, 'ELDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'APSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'BAGDAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'BOTHWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'BRIDGEWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'BRIGHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'BROADMARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'CLIFTON VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'DROMEDARY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'DYSART');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'ELDERSLIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'GAGEBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'GRANTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'INTERLAKEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'JERICHO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'KEMPTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'LOWER MARSHES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'MANGALORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'MELTON MOWBRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'MIENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'PELHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'PONTVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'RUTLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'SHANNON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'SPRING HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'STEPPES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'WADDAMANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7030, 'WIHAREJA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7050, 'ALBION HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7050, 'KINGSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7050, 'KINGSTON BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7050, 'MARANOA HEIGHTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7051, 'KINGSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7052, 'BLACKMANS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7053, 'BONNET HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7053, 'TARONGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7053, 'TAROONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'BARRETTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'CONINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'ELECTRONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'FERN TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'HOWDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'LESLIE VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'MARGATE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'NEIKA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'NIERINNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'PIERSONS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'RIDGEWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'SNUG');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7054, 'TINDERBOX');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7055, 'HUNTINGFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'CATAMARAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'CRABTREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'CRADOC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'GLAZIERS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'GLEN HUON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'GLENDEVIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'HASTINGS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'HUONVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'JUDBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'LOLLARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'LONNAVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'LOWER LONGLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'LUCASTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'LUNE RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'LYMINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'MOUNTAIN RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'PETCHEYS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'RAMINEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'RANELAGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'SOUTHPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'STRATHBLANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'WATERLOO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'WATTLE GROVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7109, 'WOODSTOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'ABELS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'CYGNET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'DEEP BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'EGGS AND BACON BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'GARDEN ISLAND CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'GARDNERS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'NICHOLLS RIVULET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'RANDALLS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7112, 'VERONA SANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7113, 'FRANKLIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7116, 'CAIRNS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7116, 'CASTLE FORBES BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7116, 'GEEVESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7116, 'POLICE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7116, 'PORT HUON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7116, 'SHIPWRIGHTS POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7116, 'SURGES BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7117, 'DOVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7119, 'STONOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'ANDOVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'ANTILL PONDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'BADEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'LAKE CRESCENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'LEMONT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'LEVENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'MOUNT SEYMOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'NALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'OATLANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'PARATTAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'PAWTELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'RHYNDASTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'ST PETERS PASS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'STONEHENGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'TIBERIAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'TUNBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'TUNNACK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'WHITEFOORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'WOODBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'WOODSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7120, 'YORK PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7139, 'STRATHGORDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'BLACK HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'BOYER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'BRADYS LAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'BRONTE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'BUSHY PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'BUTLERS GORGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'CATAGUNYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'DEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'DERWENT BRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'ELLENDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'FENTONBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'FITZGERALD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'GLENFERN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'GLENORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'GRETNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'HAMILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'HAYES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'HOLLOW TREE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'KARANJA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'LACHLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'LAKE ST CLAIR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'LIAPOOTAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'MACQUARIE PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'MAGRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'MALBINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'MAYDENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'MOLESWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'MOOGARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'MOUNT FIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'MOUNT LLOYD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'NATIONAL PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'NEW NORFOLK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'OSTERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'OUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'PLENTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'ROSEGARLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'SORELL CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'STRICKLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'TARRALEAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'TUNGATINAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'TYENNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'UXBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'VICTORIA VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'WAYATINAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7140, 'WESTERWAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'ADVENTURE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'ALLENS RIVULET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'ALONNAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'BARNES BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'DENNES POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'GORDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'GREAT BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'KAOOTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'KILLORA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'LONGLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'LUNAWANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'OYSTER COVE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'PELVERATA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'SANDFLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'SIMPSONS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7150, 'UPPER WOODSTOCK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7151, 'CASEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7151, 'DAVIS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7151, 'MACQUARIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7151, 'MACQUARIE ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7151, 'MAWSON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7155, 'KETTERING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7162, 'BIRCHS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7162, 'WOODBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7163, 'FLOWERPOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7163, 'MIDDLETON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7170, 'ACTON PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7170, 'CAMBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7170, 'LLANHERNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7170, 'MOUNT RUMNEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7170, 'ROCHES BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7170, 'SEVEN MILE BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7171, 'MIDWAY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7171, 'PENNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7171, 'SHARK POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7172, 'NUGENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7172, 'ORIELTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7172, 'PAWLEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7172, 'SORELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7172, 'WATTLE HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7173, 'CARLTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7173, 'CONNELLYS MARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7173, 'DODGES FERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7173, 'FORCETT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7173, 'LEWISHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7173, 'PRIMROSE SANDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7174, 'COPPING');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7175, 'BREAM CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7175, 'MARION BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7176, 'KELLEVIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7177, 'DUNALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7178, 'MURDUNNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7179, 'EAGLEHAWK NECK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7180, 'TARANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7182, 'FORTESCUE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7182, 'OAKWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7182, 'PORT ARTHUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7182, 'RADNOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7182, 'STEWARTS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7183, 'HIGHCROFT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7184, 'NUBEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7184, 'STORMLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7185, 'PREMAYDENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7186, 'SALTWATER RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7186, 'SLOPEN MAIN BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7187, 'KOONYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'APSLAWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'BUCKLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'CRANBROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'LITTLE SWANPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'LOUISVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'MARIA ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'ORFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'RUNNYMEDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'SPRING BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'SPRING BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'SWANSEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7190, 'TRIABUNNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7209, 'ROSS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7210, 'CAMPBELL TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7210, 'LAKE LEAKE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7211, 'CLEVELAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7211, 'CONARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7211, 'EPPING FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'BLESSINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'BURNS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'CLARENDON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'DEDDINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'ENGLISH TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'EVANDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'MUSSELBORO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'NILE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'ROSES TIER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7212, 'WESTERN JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7213, 'AVOCA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7213, 'LLEWELLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7213, 'ROSSARDEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7213, 'ROYAL GEORGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7213, 'STORYS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7214, 'FINGAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7214, 'FRODSLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7214, 'MANGANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7214, 'MATHINNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7214, 'ORMLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7214, 'TOWER HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7214, 'TULLOCHGORUM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7214, 'UPPER ESK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'BICHENO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'CHAIN OF LAGOONS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'COLES BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'CORNWALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'CULLENSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'DIANAS BASIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'DOUGLAS RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'FALMOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'FOUR MILE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'GRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'MOUNT NICHOLAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'SCAMANDER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'SEYMOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7215, 'ST MARYS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'AKAROA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'ANSONS BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'BINALONG BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'GOSHEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'GOULDS COUNTRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'LOTTAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'PRIORY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'PYENGANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'ST HELENS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7216, 'STIEGLITZ');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7248, 'INVERESK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7248, 'INVERMAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7248, 'MAYFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7248, 'MOWBRAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7248, 'NEWNHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7248, 'ROCHERLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7249, 'FRANKLIN VILLAGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7249, 'GLEN DHU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7249, 'KINGS MEADOWS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7249, 'PUNCHBOWL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7249, 'SANDHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7249, 'SOUTH LAUNCESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7249, 'YOUNGTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'CORRA LINN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'EAST LAUNCESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'ELPHIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'LAUNCESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'NEWSTEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'NORWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'PROSPECT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'PROSPECT VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'RAVENSWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'RIVERSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'ST LEONARDS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'SUMMERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'SUMMERHILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'TRAVELLERS REST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'TREVALLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'WAVERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'WEST LAUNCESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7250, 'WINDMILL HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'BACK CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'BEECHFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'DILSTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'HILLWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'LEFROY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'LULWORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'MOUNT DIRECTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'PIPERS RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'SWAN BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'WEYMOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7252, 'WINDERMERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7253, 'BELL BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7253, 'GEORGE TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7253, 'LOW HEAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7253, 'PIPE CLAY BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7254, 'BACALA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7254, 'BELLINGHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7254, 'GOLCONDA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7254, 'LEBRINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7254, 'PIPERS BROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7254, 'RETREAT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7254, 'TUNNEL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7254, 'WYENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'BLUE ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'EMITA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'FLINDERS ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'KILLIECRANKIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'LACKRANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'LADY BARRON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'LOCCOTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'LUGHRATA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'MEMANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'PALANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'RANGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7255, 'WHITEMARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7256, 'CURRIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7256, 'EGG LAGOON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7256, 'GRASSY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7256, 'KING ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7257, 'CAPE BARREN ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7258, 'BREADALBANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7258, 'RELBIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7258, 'WHITE HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7259, 'DIDDLEUM PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7259, 'MOUNT BARROW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7259, 'MYRTLE BANK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7259, 'NUNAMARA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7259, 'PATERSONIA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7259, 'TARGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7259, 'TAYENE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7260, 'JETSONVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7260, 'LIETINNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7260, 'LISLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7260, 'NABOWLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7260, 'SCOTTSDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7260, 'SPRINGFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7260, 'TONGANAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7260, 'TULENDEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7261, 'BRANXHOLM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7262, 'BRIDPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7262, 'TOMAHAWK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7262, 'WATERHOUSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7263, 'LEGERWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7263, 'RINGAROOMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'CAPE PORTLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'DERBY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'GLADSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'HERRICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'MOORINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'MUSSELROE BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'PIONEER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'SOUTH MOUNT CAMERON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7264, 'WELDBOROUGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7265, 'WINNALEAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7267, 'BANGOR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7267, 'KAROOLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7267, 'LALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7267, 'TURNERS MARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7268, 'LILYDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7268, 'NORTH LILYDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7268, 'UNDERWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'BEACONSFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'BEAUTY POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'CLARENCE POINT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'FLOWERY GULLY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'GREENS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'ILFRAVILLE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'KAYENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'KELSO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'RICHMOND HILL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'ROWELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7270, 'SIDMOUTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'BLACKWALL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'DEVIOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'EXETER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'FRANKFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'GLENGARRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'HOLWELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'LANENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'LOIRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'NOTLEY HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'PAPER BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'ROBIGANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'TATANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7275, 'WINKLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7276, 'GRAVELLY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7277, 'BRIDGENORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7277, 'GRINDELWALD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7277, 'LEGANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7277, 'ROSEVEARS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7290, 'HADSPEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7291, 'CARRICK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7292, 'HAGLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7292, 'ROSEVALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7292, 'SELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7292, 'WESTWOOD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7300, 'DEVON HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7300, 'PERTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7300, 'POWRANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7301, 'BISHOPSBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7301, 'BLACKWOOD CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7301, 'LIFFEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7301, 'LONGFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7301, 'PATEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7301, 'TOIBERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7302, 'BRACKNELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7302, 'CRESSY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7302, 'POATINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7303, 'BIRRALEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7303, 'EXTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7303, 'WESTBURY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7303, 'WHITEMORE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'BREONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'CAVESIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'CHUDLEIGH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'DAIRY PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'DELORAINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'DUNORLAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'ELIZABETH TOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'GOLDEN VALLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'JACKEYS MARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'KIMBERLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'LEMANA JUNCTION');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'MAYBERRY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'MEANDER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'MERSEY FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'MOLE CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'MOLTEMA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'MONTANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'NEEDLES');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'PARKHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'RED HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'REEDY MARSH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'WEEGENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'WEETAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7304, 'WESTERN CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7305, 'MERSEYLEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7305, 'RAILTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7305, 'SUNNYSIDE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'BARRINGTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'BEULAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'CLAUDE ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'CRADLE MOUNTAIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'GOWRIE PARK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'KENTISH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'LORINNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'NOOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'PARADISE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'ROLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'SHEFFIELD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'STAVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7306, 'STOODLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'DULVERTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'HARFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'HAWLEY BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'LATROBE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'MORIARTY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'NORTHDOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'PORT SORELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'SASSAFRAS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'SHEARWATER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'THIRLSTANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7307, 'WESLEY VALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'ABERDEEN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'DEVONPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'DON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'ERRIBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'EUGENANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'FORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'KINDRED');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'LILLICO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'MELROSE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'MIANDETTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'PALOONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'QUOIBA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'SPREYTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'WEST DEVONPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7310, 'WILMOT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'ABBOTSHAM');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'CENTRAL CASTRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'GAWLER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'GUNNS PLAINS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'LEITH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'NIETTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'NORTH MOTTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'PRESTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'SPALFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'SPRENT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'TURNERS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'ULVERSTONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'UPPER CASTRA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7315, 'WARRINGA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'BLYTHE HEADS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'CAMENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'CUPRONA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'HEYBRIDGE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'HOWTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'LOYETEA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'PENGUIN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'PRESERVATION BAY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'RIANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'SOUTH RIANA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'SULPHUR CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7316, 'WEST PINE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7320, 'BROOKLYN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7320, 'BURNIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7320, 'COOEE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7320, 'HAVENVIEW');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7320, 'HILLCREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7320, 'MONTELLO');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7320, 'WIVENHOE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'BLACK RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'BOAT HARBOUR');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'HAMPSHIRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'HIGHCLERE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'MAWBANNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'NATONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'PARRAWE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'RIDGLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'ROCKY CAPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'SAVAGE RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'SISTERS BEACH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'STOWPORT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'TULLAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7321, 'WARATAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7322, 'SOMERSET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'CALDER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'DOCTORS ROCKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'ELLIOTT');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'FLOWERDALE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'LAPOINYA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'MEUNNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'MILABENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'MOORLEAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'MOUNT HICKS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'MYALLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'OLDINA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'PREOLENNA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'SEABROOK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'SISTERS CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'TABLE CAPE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'TAKONE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'WYNYARD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7325, 'YOLLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'ALCOMIE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'ARTHUR RIVER');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'BRITTONS SWAMP');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'CHRISTMAS HILLS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'EDITH CREEK');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'FOREST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'IRISHTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'LILEAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'MARRAWAH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'MELLA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'MENGHA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'MONTAGU');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'NABAGEENA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'REDPA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'SMITHTON');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'THREE HUMMOCK ISLAND');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'TOGARI');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'TROWUTTA');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7330, 'WOOLNORTH');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7331, 'STANLEY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7467, 'LYNCHFORD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7467, 'QUEENSTOWN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7468, 'STRAHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7469, 'RENISON BELL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7469, 'ZEEHAN');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='TAS'), 7470, 'ROSEBERY');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8001, 'MELBOURNE CITY MC');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8002, 'EAST MELBOURNE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8003, 'COLLINS STREET EAST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8004, 'ST KILDA ROAD');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8005, 'WORLD TRADE CENTRE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8006, 'ABECKETT STREET');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8007, 'COLLINS STREET WEST');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8008, 'ST KILDA ROAD CENTRAL');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8009, 'FLINDERS LANE');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='VIC'), 8010, 'LAW COURTS');
insert into dem.urb (id_state, postcode, name) values ((select id from dem.state where country='AU' and code='QLD'), 9726, 'GOLD COAST MC');

select dem.gm_upd_default_states();
